/* -*- mode: c -*- */
/*
    Copyright (c) 1990, Giuseppe Attardi and William F. Schelter.
    Copyright (c) 2001, Juan Jose Garcia Ripoll.
    Copyright (c) 2010-2012, Jean-Claude Beaudoin.

    MKCL is free software; you can redistribute it and/or
    modify it under the terms of the GNU Lesser General Public
    License as published by the Free Software Foundation; either
    version 3 of the License, or (at your option) any later version.

    See file '../../Copyright' for full details.
*/


#define MKCL_NAME_PPRINT(x) MKCL_IN_LISP(x)

#ifdef MKCL_FINAL
#define MKCL_IN_LISP(x) x
#else
#define MKCL_IN_LISP(x) NULL
#endif

#ifdef MKCL_RELATIVE_PACKAGE_NAMES
# define RELATIVE_PACKAGES_P mk_cl_Ct
#else
# define RELATIVE_PACKAGES_P mk_cl_Cnil
#endif

#ifdef DPP
# define CLOS_ "CLOS::"
# define MKCL_EXT_ "MKCL::"
# define SYS_ "SI::"
# define MT_ "MT::"
# define KEY_ ":"
# define GRAY_ "GRAY::"
typedef struct
{
  const char *name, *translation;
  const int narg;
} mkcl_symbol_initializer;
#else
# define CLOS_
# define MKCL_EXT_
# define SYS_
# define MT_
# define KEY_
# define GRAY_
#endif

mkcl_symbol_initializer mkcl_root_symbols[] = {

  {{"NIL", CL_ORDINARY, NULL, -1, MKCL_OBJNULL}},
  {{"T", CL_ORDINARY, NULL, -1, MKCL_OBJNULL}},
  {{SYS_ "UNBOUND", SI_CONSTANT, mk_si_unbound, 0, MKCL_UNBOUND}},
  {{SYS_ "PROTECT-TAG", SI_ORDINARY, NULL, -1, MKCL_OBJNULL}},

  /* LISP PACKAGE */
  {{"&ALLOW-OTHER-KEYS", CL_ORDINARY, NULL, -1, MKCL_OBJNULL}},
  {{"&AUX", CL_ORDINARY, NULL, -1, MKCL_OBJNULL}},
  {{"&BODY", CL_ORDINARY, NULL, -1, MKCL_OBJNULL}},
  {{"&ENVIRONMENT", CL_ORDINARY, NULL, -1, MKCL_OBJNULL}},
  {{"&KEY", CL_ORDINARY, NULL, -1, MKCL_OBJNULL}},
  {{"&OPTIONAL", CL_ORDINARY, NULL, -1, MKCL_OBJNULL}},
  {{"&REST", CL_ORDINARY, NULL, -1, MKCL_OBJNULL}},
  {{"&WHOLE", CL_ORDINARY, NULL, -1, MKCL_OBJNULL}},
  {{"+", CL_SPECIAL, mk_cl_P, -1, mk_cl_Cnil}},
  {{"++", CL_SPECIAL, NULL, -1, mk_cl_Cnil}},
  {{"+++", CL_SPECIAL, NULL, -1, mk_cl_Cnil}},
  {{"-", CL_SPECIAL, mk_cl_M, -1, mk_cl_Cnil}},
  {{"*", CL_SPECIAL, mk_cl_X, -1, mk_cl_Cnil}},
  {{"**", CL_SPECIAL, NULL, -1, mk_cl_Cnil}},
  {{"***", CL_SPECIAL, NULL, -1, mk_cl_Cnil}},
  {{"/", CL_SPECIAL, mk_cl_N, -1, mk_cl_Cnil}},
  {{"//", CL_SPECIAL, NULL, -1, mk_cl_Cnil}},
  {{"///", CL_SPECIAL, NULL, -1, mk_cl_Cnil}},
  {{"/=", CL_ORDINARY, mk_cl_NE, -1, MKCL_OBJNULL}},
  {{"*BREAK-ON-SIGNALS*", CL_SPECIAL, NULL, -1, mk_cl_Cnil}},
  {{"*COMPILE-FILE-PATHNAME*", CL_SPECIAL, NULL, -1, mk_cl_Cnil}},
  {{"*COMPILE-FILE-TRUENAME*", CL_SPECIAL, NULL, -1, mk_cl_Cnil}},
  {{"*COMPILE-PRINT*", CL_SPECIAL, NULL, -1, mk_cl_Cnil}},
  {{"*COMPILE-VERBOSE*", CL_SPECIAL, NULL, -1, mk_cl_Cnil}},
  {{"*DEBUG-IO*", CL_SPECIAL, NULL, -1, MKCL_OBJNULL}},
  {{"*DEBUGGER-HOOK*", CL_SPECIAL, NULL, -1, mk_cl_Cnil}},
  {{"*DEFAULT-PATHNAME-DEFAULTS*", CL_SPECIAL, NULL, -1, MKCL_OBJNULL}},
  {{"*ERROR-OUTPUT*", CL_SPECIAL, NULL, -1, MKCL_OBJNULL}},
  {{"*FEATURES*", CL_SPECIAL, NULL, -1, MKCL_OBJNULL}},
  {{"*GENSYM-COUNTER*", CL_SPECIAL, NULL, -1, MKCL_MAKE_FIXNUM(0)}},
  {{"*LOAD-PATHNAME*", CL_SPECIAL, NULL, -1, mk_cl_Cnil}},
  {{"*LOAD-PRINT*", CL_SPECIAL, NULL, -1, mk_cl_Cnil}},
  {{"*LOAD-TRUENAME*", CL_SPECIAL, NULL, -1, mk_cl_Cnil}},
  {{"*LOAD-VERBOSE*", CL_SPECIAL, NULL, -1, mk_cl_Ct}},
  {{"*MACROEXPAND-HOOK*", CL_SPECIAL, NULL, -1, MKCL_OBJNULL}},
  {{"*MODULES*", CL_SPECIAL, NULL, -1, MKCL_OBJNULL}},
  {{MKCL_EXT_ "*MODULE-PROVIDER-FUNCTIONS*", MKCL_EXT_SPECIAL, NULL, -1, MKCL_OBJNULL}},
  {{"*PACKAGE*", CL_SPECIAL, NULL, -1, MKCL_OBJNULL}},
  {{"*PRINT-ARRAY*", CL_SPECIAL, NULL, -1, mk_cl_Ct}},
  {{"*PRINT-BASE*", CL_SPECIAL, NULL, -1, MKCL_MAKE_FIXNUM(10)}},
  {{"*PRINT-CASE*", CL_SPECIAL, NULL, -1, MKCL_OBJNULL}},
  {{"*PRINT-CIRCLE*", CL_SPECIAL, NULL, -1, mk_cl_Cnil}},
  {{"*PRINT-ESCAPE*", CL_SPECIAL, NULL, -1, mk_cl_Ct}},
  {{"*PRINT-GENSYM*", CL_SPECIAL, NULL, -1, mk_cl_Ct}},
  {{"*PRINT-LENGTH*", CL_SPECIAL, NULL, -1, mk_cl_Cnil}},
  {{"*PRINT-LEVEL*", CL_SPECIAL, NULL, -1, mk_cl_Cnil}},
  {{"*PRINT-LINES*", CL_SPECIAL, NULL, -1, mk_cl_Cnil}},
  {{"*PRINT-MISER-WIDTH*", CL_SPECIAL, NULL, -1, mk_cl_Cnil}},
  {{"*PRINT-PPRINT-DISPATCH*", CL_SPECIAL, NULL, -1, mk_cl_Cnil}},
  {{"*PRINT-PRETTY*", CL_SPECIAL, NULL, -1, mk_cl_Cnil}},
  {{"*PRINT-RADIX*", CL_SPECIAL, NULL, -1, mk_cl_Cnil}},
  {{"*PRINT-READABLY*", CL_SPECIAL, NULL, -1, mk_cl_Cnil}},
  {{"*PRINT-RIGHT-MARGIN*", CL_SPECIAL, NULL, -1, mk_cl_Cnil}},
  {{"*QUERY-IO*", CL_SPECIAL, NULL, -1, MKCL_OBJNULL}},
  {{"*RANDOM-STATE*", CL_SPECIAL, NULL, -1, MKCL_OBJNULL}},
  {{"*READ-BASE*", CL_SPECIAL, NULL, -1, MKCL_MAKE_FIXNUM(10)}},
  {{"*READ-DEFAULT-FLOAT-FORMAT*", CL_SPECIAL, NULL, -1, MKCL_OBJNULL}},
  {{"*READ-EVAL*", CL_SPECIAL, NULL, -1, mk_cl_Ct}},
  {{"*READ-SUPPRESS*", CL_SPECIAL, NULL, -1, mk_cl_Cnil}},
  {{"*READTABLE*", CL_SPECIAL, NULL, -1, MKCL_OBJNULL}},
  {{"*STANDARD-INPUT*", CL_SPECIAL, NULL, -1, MKCL_OBJNULL}},
  {{"*STANDARD-OUTPUT*", CL_SPECIAL, NULL, -1, MKCL_OBJNULL}},
  {{"*TERMINAL-IO*", CL_SPECIAL, NULL, -1, MKCL_OBJNULL}},
  {{"*TRACE-OUTPUT*", CL_SPECIAL, NULL, -1, MKCL_OBJNULL}},
  {{"1+", CL_ORDINARY, mk_cl_1P, 1, MKCL_OBJNULL}},
  {{"1-", CL_ORDINARY, mk_cl_1M, 1, MKCL_OBJNULL}},
  {{"<", CL_ORDINARY, mk_cl_L, -1, MKCL_OBJNULL}},
  {{"<=", CL_ORDINARY, mk_cl_LE, -1, MKCL_OBJNULL}},
  {{"=", CL_ORDINARY, mk_cl_E, -1, MKCL_OBJNULL}},
  {{">", CL_ORDINARY, mk_cl_G, -1, MKCL_OBJNULL}},
  {{">=", CL_ORDINARY, mk_cl_GE, -1, MKCL_OBJNULL}},
  {{"ABORT", CL_ORDINARY, NULL, -1, MKCL_OBJNULL}},
  {{"ABS", CL_ORDINARY, mk_cl_abs, 1, MKCL_OBJNULL}},
  {{"ACONS", CL_ORDINARY, mk_cl_acons, 3, MKCL_OBJNULL}},
  {{"ACOS", CL_ORDINARY, MKCL_IN_LISP(mk_cl_acos), -1, MKCL_OBJNULL}},
  {{"ACOSH", CL_ORDINARY, MKCL_IN_LISP(mk_cl_acosh), -1, MKCL_OBJNULL}},
  {{"ADJOIN", CL_ORDINARY, mk_cl_adjoin, -1, MKCL_OBJNULL}},
  {{"ADJUST-ARRAY", CL_ORDINARY, MKCL_IN_LISP(mk_cl_adjust_array), -1, MKCL_OBJNULL}},
  {{"ADJUSTABLE-ARRAY-P", CL_ORDINARY, mk_cl_adjustable_array_p, 1, MKCL_OBJNULL}},
  {{"ALPHA-CHAR-P", CL_ORDINARY, mk_cl_alpha_char_p, 1, MKCL_OBJNULL}},
  {{"ALPHANUMERICP", CL_ORDINARY, mk_cl_alphanumericp, 1, MKCL_OBJNULL}},
  {{"AND", CL_ORDINARY, NULL, -1, MKCL_OBJNULL}},
  {{"APPEND", CL_ORDINARY, mk_cl_append, -1, MKCL_OBJNULL}},
  {{"APPLY", CL_ORDINARY, mk_cl_apply, -1, MKCL_OBJNULL}},
  {{"APROPOS", CL_ORDINARY, MKCL_IN_LISP(mk_cl_apropos), -1, MKCL_OBJNULL}},
  {{"APROPOS-LIST", CL_ORDINARY, MKCL_IN_LISP(mk_cl_apropos_list), -1, MKCL_OBJNULL}},
  {{"AREF", CL_ORDINARY, mk_cl_aref, -1, MKCL_OBJNULL}},
  {{"ARITHMETIC-ERROR", CL_ORDINARY, NULL, -1, MKCL_OBJNULL}},
  {{"ARITHMETIC-ERROR-OPERANDS", CL_ORDINARY, NULL, -1, MKCL_OBJNULL}},
  {{"ARITHMETIC-ERROR-OPERATION", CL_ORDINARY, NULL, -1, MKCL_OBJNULL}},
  {{"ARRAY", CL_ORDINARY, NULL, -1, MKCL_OBJNULL}},
  {{"ARRAY-DIMENSION", CL_ORDINARY, mk_cl_array_dimension, 2, MKCL_OBJNULL}},
  {{"ARRAY-DIMENSION-LIMIT", CL_CONSTANT, NULL, -1, MKCL_MAKE_FIXNUM(MKCL_ADIMLIM)}},
  {{"ARRAY-DIMENSIONS", CL_ORDINARY, MKCL_IN_LISP(mk_cl_array_dimensions), 1, MKCL_OBJNULL}},
  {{"ARRAY-DISPLACEMENT", CL_ORDINARY, mk_cl_array_displacement, 1, MKCL_OBJNULL}},
  {{"ARRAY-ELEMENT-TYPE", CL_ORDINARY, mk_cl_array_element_type, 1, MKCL_OBJNULL}},
  {{"ARRAY-HAS-FILL-POINTER-P", CL_ORDINARY, mk_cl_array_has_fill_pointer_p, 1, MKCL_OBJNULL}},
  {{"ARRAY-IN-BOUNDS-P", CL_ORDINARY, MKCL_IN_LISP(mk_cl_array_in_bounds_p), -1, MKCL_OBJNULL}},
  {{"ARRAY-RANK", CL_ORDINARY, mk_cl_array_rank, 1, MKCL_OBJNULL}},
  {{"ARRAY-RANK-LIMIT", CL_CONSTANT, NULL, -1, MKCL_MAKE_FIXNUM(MKCL_ARANKLIM)}},
  {{"ARRAY-ROW-MAJOR-INDEX", CL_ORDINARY, mk_cl_array_row_major_index, -1, MKCL_OBJNULL}},
  {{"ARRAY-TOTAL-SIZE", CL_ORDINARY, mk_cl_array_total_size, 1, MKCL_OBJNULL}},
  {{"ARRAY-TOTAL-SIZE-LIMIT", CL_CONSTANT, NULL, -1, MKCL_MAKE_FIXNUM(MKCL_ATOTLIM)}},
  {{"ARRAYP", CL_ORDINARY, mk_cl_arrayp, 1, MKCL_OBJNULL}},
  {{"ASH", CL_ORDINARY, mk_cl_ash, 2, MKCL_OBJNULL}},
  {{"ASIN", CL_ORDINARY, MKCL_IN_LISP(mk_cl_asin), -1, MKCL_OBJNULL}},
  {{"ASINH", CL_ORDINARY, MKCL_IN_LISP(mk_cl_asinh), -1, MKCL_OBJNULL}},
  {{"ASSERT", CL_ORDINARY, NULL, -1, MKCL_OBJNULL}},
  {{"ASSOC", CL_ORDINARY, mk_cl_assoc, -1, MKCL_OBJNULL}},
  {{"ASSOC-IF", CL_ORDINARY, MKCL_IN_LISP(mk_cl_assoc_if), -1, MKCL_OBJNULL}},
  {{"ASSOC-IF-NOT", CL_ORDINARY, MKCL_IN_LISP(mk_cl_assoc_if_not), -1, MKCL_OBJNULL}},
  {{"ATAN", CL_ORDINARY, mk_cl_atan, -1, MKCL_OBJNULL}},
  {{"ATANH", CL_ORDINARY, MKCL_IN_LISP(mk_cl_atanh), -1, MKCL_OBJNULL}},
  {{"ATOM", CL_ORDINARY, mk_cl_atom, 1, MKCL_OBJNULL}},
  {{"BASE-CHAR", CL_ORDINARY, NULL, -1, MKCL_OBJNULL}},
  {{"BASE-STRING", CL_ORDINARY, NULL, -1, MKCL_OBJNULL}},
  {{"BIGNUM", CL_ORDINARY, NULL, -1, MKCL_OBJNULL}},
  {{"BIT", CL_ORDINARY, MKCL_IN_LISP(mk_cl_bit), -1, MKCL_OBJNULL}},
  {{"BIT-AND", CL_ORDINARY, MKCL_IN_LISP(mk_cl_bit_and), -1, MKCL_OBJNULL}},
  {{"BIT-ANDC1", CL_ORDINARY, MKCL_IN_LISP(mk_cl_bit_andc1), -1, MKCL_OBJNULL}},
  {{"BIT-ANDC2", CL_ORDINARY, MKCL_IN_LISP(mk_cl_bit_andc2), -1, MKCL_OBJNULL}},
  {{"BIT-EQV", CL_ORDINARY, MKCL_IN_LISP(mk_cl_bit_eqv), -1, MKCL_OBJNULL}},
  {{"BIT-IOR", CL_ORDINARY, MKCL_IN_LISP(mk_cl_bit_ior), -1, MKCL_OBJNULL}},
  {{"BIT-NAND", CL_ORDINARY, MKCL_IN_LISP(mk_cl_bit_nand), -1, MKCL_OBJNULL}},
  {{"BIT-NOR", CL_ORDINARY, MKCL_IN_LISP(mk_cl_bit_nor), -1, MKCL_OBJNULL}},
  {{"BIT-NOT", CL_ORDINARY, MKCL_IN_LISP(mk_cl_bit_not), -1, MKCL_OBJNULL}},
  {{"BIT-ORC1", CL_ORDINARY, MKCL_IN_LISP(mk_cl_bit_orc1), -1, MKCL_OBJNULL}},
  {{"BIT-ORC2", CL_ORDINARY, MKCL_IN_LISP(mk_cl_bit_orc2), -1, MKCL_OBJNULL}},
  {{"BIT-VECTOR", CL_ORDINARY, NULL, -1, MKCL_OBJNULL}},
  {{"BIT-VECTOR-P", CL_ORDINARY, mk_cl_bit_vector_p, 1, MKCL_OBJNULL}},
  {{"BIT-XOR", CL_ORDINARY, MKCL_IN_LISP(mk_cl_bit_xor), -1, MKCL_OBJNULL}},
  {{"BLOCK", CL_FORM, NULL, -1, MKCL_OBJNULL}},
  {{"BOOLE", CL_ORDINARY, mk_cl_boole, 3, MKCL_OBJNULL}},
  {{"BOOLE-1", CL_CONSTANT, NULL, -1, MKCL_MAKE_FIXNUM(MKCL_BOOL1)}},
  {{"BOOLE-2", CL_CONSTANT, NULL, -1, MKCL_MAKE_FIXNUM(MKCL_BOOL2)}},
  {{"BOOLE-AND", CL_CONSTANT, NULL, -1, MKCL_MAKE_FIXNUM(MKCL_BOOLAND)}},
  {{"BOOLE-ANDC1", CL_CONSTANT, NULL, -1, MKCL_MAKE_FIXNUM(MKCL_BOOLANDC1)}},
  {{"BOOLE-ANDC2", CL_CONSTANT, NULL, -1, MKCL_MAKE_FIXNUM(MKCL_BOOLANDC2)}},
  {{"BOOLE-C1", CL_CONSTANT, NULL, -1, MKCL_MAKE_FIXNUM(MKCL_BOOLC1)}},
  {{"BOOLE-C2", CL_CONSTANT, NULL, -1, MKCL_MAKE_FIXNUM(MKCL_BOOLC2)}},
  {{"BOOLE-CLR", CL_CONSTANT, NULL, -1, MKCL_MAKE_FIXNUM(MKCL_BOOLCLR)}},
  {{"BOOLE-EQV", CL_CONSTANT, NULL, -1, MKCL_MAKE_FIXNUM(MKCL_BOOLEQV)}},
  {{"BOOLE-IOR", CL_CONSTANT, NULL, -1, MKCL_MAKE_FIXNUM(MKCL_BOOLIOR)}},
  {{"BOOLE-NAND", CL_CONSTANT, NULL, -1, MKCL_MAKE_FIXNUM(MKCL_BOOLNAND)}},
  {{"BOOLE-NOR", CL_CONSTANT, NULL, -1, MKCL_MAKE_FIXNUM(MKCL_BOOLNOR)}},
  {{"BOOLE-ORC1", CL_CONSTANT, NULL, -1, MKCL_MAKE_FIXNUM(MKCL_BOOLORC1)}},
  {{"BOOLE-ORC2", CL_CONSTANT, NULL, -1, MKCL_MAKE_FIXNUM(MKCL_BOOLORC2)}},
  {{"BOOLE-SET", CL_CONSTANT, NULL, -1, MKCL_MAKE_FIXNUM(MKCL_BOOLSET)}},
  {{"BOOLE-XOR", CL_CONSTANT, NULL, -1, MKCL_MAKE_FIXNUM(MKCL_BOOLXOR)}},
  {{"BOOLEAN", CL_ORDINARY, NULL, -1, MKCL_OBJNULL}},
  {{"BOTH-CASE-P", CL_ORDINARY, mk_cl_both_case_p, 1, MKCL_OBJNULL}},
  {{"BOUNDP", CL_ORDINARY, mk_cl_boundp, 1, MKCL_OBJNULL}},
  {{"BREAK", CL_ORDINARY, NULL, -1, MKCL_OBJNULL}},
  {{"BROADCAST-STREAM", CL_ORDINARY, NULL, -1, MKCL_OBJNULL}},
  {{"BROADCAST-STREAM-STREAMS", CL_ORDINARY, mk_cl_broadcast_stream_streams, 1, MKCL_OBJNULL}},
  {{"BUTLAST", CL_ORDINARY, mk_cl_butlast, -1, MKCL_OBJNULL}},
  {{"BYTE", CL_ORDINARY, MKCL_IN_LISP(mk_cl_byte), -1, MKCL_OBJNULL}},
  {{"BYTE-POSITION", CL_ORDINARY, MKCL_IN_LISP(mk_cl_byte_position), -1, MKCL_OBJNULL}},
  {{"BYTE-SIZE", CL_ORDINARY, MKCL_IN_LISP(mk_cl_byte_size), -1, MKCL_OBJNULL}},
  {{"CAAAAR", CL_ORDINARY, mk_cl_caaaar, 1, MKCL_OBJNULL}},
  {{"CAAADR", CL_ORDINARY, mk_cl_caaadr, 1, MKCL_OBJNULL}},
  {{"CAAAR", CL_ORDINARY, mk_cl_caaar, 1, MKCL_OBJNULL}},
  {{"CAADAR", CL_ORDINARY, mk_cl_caadar, 1, MKCL_OBJNULL}},
  {{"CAADDR", CL_ORDINARY, mk_cl_caaddr, 1, MKCL_OBJNULL}},
  {{"CAADR", CL_ORDINARY, mk_cl_caadr, 1, MKCL_OBJNULL}},
  {{"CAAR", CL_ORDINARY, mk_cl_caar, 1, MKCL_OBJNULL}},
  {{"CADAAR", CL_ORDINARY, mk_cl_cadaar, 1, MKCL_OBJNULL}},
  {{"CADADR", CL_ORDINARY, mk_cl_cadadr, 1, MKCL_OBJNULL}},
  {{"CADAR", CL_ORDINARY, mk_cl_cadar, 1, MKCL_OBJNULL}},
  {{"CADDAR", CL_ORDINARY, mk_cl_caddar, 1, MKCL_OBJNULL}},
  {{"CADDDR", CL_ORDINARY, mk_cl_cadddr, 1, MKCL_OBJNULL}},
  {{"CADDR", CL_ORDINARY, mk_cl_caddr, 1, MKCL_OBJNULL}},
  {{"CADR", CL_ORDINARY, mk_cl_cadr, 1, MKCL_OBJNULL}},
  {{"CALL-ARGUMENTS-LIMIT", CL_CONSTANT, NULL, -1, MKCL_MAKE_FIXNUM(MKCL_CALL_ARGUMENTS_LIMIT)}},
  {{"CAR", CL_ORDINARY, mk_cl_car, 1, MKCL_OBJNULL}},
  {{"CASE", CL_FORM, NULL, -1, MKCL_OBJNULL}},
  {{"CATCH", CL_FORM, NULL, -1, MKCL_OBJNULL}},
  {{"CCASE", CL_ORDINARY, NULL, -1, MKCL_OBJNULL}},
  {{"CDAAAR", CL_ORDINARY, mk_cl_cdaaar, 1, MKCL_OBJNULL}},
  {{"CDAADR", CL_ORDINARY, mk_cl_cdaadr, 1, MKCL_OBJNULL}},
  {{"CDAAR", CL_ORDINARY, mk_cl_cdaar, 1, MKCL_OBJNULL}},
  {{"CDADAR", CL_ORDINARY, mk_cl_cdadar, 1, MKCL_OBJNULL}},
  {{"CDADDR", CL_ORDINARY, mk_cl_cdaddr, 1, MKCL_OBJNULL}},
  {{"CDADR", CL_ORDINARY, mk_cl_cdadr, 1, MKCL_OBJNULL}},
  {{"CDAR", CL_ORDINARY, mk_cl_cdar, 1, MKCL_OBJNULL}},
  {{"CDDAAR", CL_ORDINARY, mk_cl_cddaar, 1, MKCL_OBJNULL}},
  {{"CDDADR", CL_ORDINARY, mk_cl_cddadr, 1, MKCL_OBJNULL}},
  {{"CDDAR", CL_ORDINARY, mk_cl_cddar, 1, MKCL_OBJNULL}},
  {{"CDDDAR", CL_ORDINARY, mk_cl_cdddar, 1, MKCL_OBJNULL}},
  {{"CDDDDR", CL_ORDINARY, mk_cl_cddddr, 1, MKCL_OBJNULL}},
  {{"CDDDR", CL_ORDINARY, mk_cl_cdddr, 1, MKCL_OBJNULL}},
  {{"CDDR", CL_ORDINARY, mk_cl_cddr, 1, MKCL_OBJNULL}},
  {{"CDR", CL_ORDINARY, mk_cl_cdr, 1, MKCL_OBJNULL}},
  {{"CEILING", CL_ORDINARY, mk_cl_ceiling, -1, MKCL_OBJNULL}},
  {{"CELL-ERROR", CL_ORDINARY, NULL, -1, MKCL_OBJNULL}},
  {{"CELL-ERROR-NAME", CL_ORDINARY, NULL, -1, MKCL_OBJNULL}},
  {{"CERROR", CL_ORDINARY, mk_cl_cerror, -1, MKCL_OBJNULL}},
  {{"CHAR", CL_ORDINARY, mk_cl_char, 2, MKCL_OBJNULL}},
  {{"CHAR-CODE", CL_ORDINARY, mk_cl_char_code, 1, MKCL_OBJNULL}},
  {{"CHAR-CODE-LIMIT", CL_CONSTANT, NULL, -1, MKCL_MAKE_FIXNUM(MKCL_CHAR_CODE_LIMIT)}},
  {{"CHAR-DOWNCASE", CL_ORDINARY, mk_cl_char_downcase, 1, MKCL_OBJNULL}},
  {{"CHAR-EQUAL", CL_ORDINARY, mk_cl_char_equal, -1, MKCL_OBJNULL}},
  {{"CHAR-GREATERP", CL_ORDINARY, mk_cl_char_greaterp, -1, MKCL_OBJNULL}},
  {{"CHAR-INT", CL_ORDINARY, mk_cl_char_int, 1, MKCL_OBJNULL}},
  {{"CHAR-LESSP", CL_ORDINARY, mk_cl_char_lessp, -1, MKCL_OBJNULL}},
  {{"CHAR-NAME", CL_ORDINARY, mk_cl_char_name, 1, MKCL_OBJNULL}},
  {{"CHAR-NOT-EQUAL", CL_ORDINARY, mk_cl_char_not_equal, -1, MKCL_OBJNULL}},
  {{"CHAR-NOT-GREATERP", CL_ORDINARY, mk_cl_char_not_greaterp, -1, MKCL_OBJNULL}},
  {{"CHAR-NOT-LESSP", CL_ORDINARY, mk_cl_char_not_lessp, -1, MKCL_OBJNULL}},
  {{"CHAR-UPCASE", CL_ORDINARY, mk_cl_char_upcase, 1, MKCL_OBJNULL}},
  {{"CHAR/=", CL_ORDINARY, mk_cl_charNE, -1, MKCL_OBJNULL}},
  {{"CHAR<", CL_ORDINARY, mk_cl_charL, -1, MKCL_OBJNULL}},
  {{"CHAR<=", CL_ORDINARY, mk_cl_charLE, -1, MKCL_OBJNULL}},
  {{"CHAR=", CL_ORDINARY, mk_cl_charE, -1, MKCL_OBJNULL}},
  {{"CHAR>", CL_ORDINARY, mk_cl_charG, -1, MKCL_OBJNULL}},
  {{"CHAR>=", CL_ORDINARY, mk_cl_charGE, -1, MKCL_OBJNULL}},
  {{"CHARACTER", CL_ORDINARY, mk_cl_character, 1, MKCL_OBJNULL}},
  {{"CHARACTERP", CL_ORDINARY, mk_cl_characterp, 1, MKCL_OBJNULL}},
  {{"CHECK-TYPE", CL_ORDINARY, NULL, -1, MKCL_OBJNULL}},
  {{"CIS", CL_ORDINARY, MKCL_IN_LISP(mk_cl_cis), -1, MKCL_OBJNULL}},
  {{"CLEAR-INPUT", CL_ORDINARY, mk_cl_clear_input, -1, MKCL_OBJNULL}},
  {{"CLEAR-OUTPUT", CL_ORDINARY, mk_cl_clear_output, -1, MKCL_OBJNULL}},
  {{"CLOSE", CL_ORDINARY, mk_cl_close, -1, MKCL_OBJNULL}},
  {{"CLRHASH", CL_ORDINARY, mk_cl_clrhash, 1, MKCL_OBJNULL}},
  {{"CODE-CHAR", CL_ORDINARY, mk_cl_code_char, 1, MKCL_OBJNULL}},
  {{"COERCE", CL_ORDINARY, MKCL_IN_LISP(mk_cl_coerce), -1, MKCL_OBJNULL}},
  {{"COMPILATION-SPEED", CL_ORDINARY, NULL, -1, MKCL_OBJNULL}},
  {{"COMPILE", CL_ORDINARY, NULL, -1, MKCL_OBJNULL}},
  {{"COMPILE-FILE", CL_ORDINARY, NULL, -1, MKCL_OBJNULL}},
  {{"COMPILE-FILE-PATHNAME", CL_ORDINARY, NULL, -1, MKCL_OBJNULL}},
  {{"COMPILED-FUNCTION", CL_ORDINARY, NULL, -1, MKCL_OBJNULL}},
  {{"COMPILED-FUNCTION-P", CL_ORDINARY, mk_cl_compiled_function_p, 1, MKCL_OBJNULL}},
  {{"COMPILER-MACRO", CL_ORDINARY, NULL, -1, MKCL_OBJNULL}},
  {{"COMPILER-MACRO-FUNCTION", CL_ORDINARY, NULL, -1, MKCL_OBJNULL}},
  {{"COMPLEMENT", CL_ORDINARY, NULL, -1, MKCL_OBJNULL}},
  {{"COMPLEX", CL_ORDINARY, mk_cl_complex, -1, MKCL_OBJNULL}},
  {{"COMPLEXP", CL_ORDINARY, mk_cl_complexp, 1, MKCL_OBJNULL}},
  {{"COMPUTE-RESTARTS", CL_ORDINARY, NULL, 1, MKCL_OBJNULL}},
  {{"CONCATENATE", CL_ORDINARY, MKCL_IN_LISP(mk_cl_concatenate), -1, MKCL_OBJNULL}},
  {{"CONCATENATED-STREAM", CL_ORDINARY, NULL, -1, MKCL_OBJNULL}},
  {{"CONCATENATED-STREAM-STREAMS", CL_ORDINARY, mk_cl_concatenated_stream_streams, 1, MKCL_OBJNULL}},
  {{"COND", CL_FORM, NULL, -1, MKCL_OBJNULL}},
  {{"CONDITION", CL_ORDINARY, NULL, -1, MKCL_OBJNULL}},
  {{"CONJUGATE", CL_ORDINARY, mk_cl_conjugate, 1, MKCL_OBJNULL}},
  {{"CONTINUE", CL_ORDINARY, MKCL_IN_LISP(mk_cl_continue), -1, MKCL_OBJNULL}},
  {{"CONS", CL_ORDINARY, mk_cl_cons, 2, MKCL_OBJNULL}},
  {{"CONSP", CL_ORDINARY, mk_cl_consp, 1, MKCL_OBJNULL}},
  {{"CONSTANTLY", CL_ORDINARY, MKCL_IN_LISP(mk_cl_constantly), -1, MKCL_OBJNULL}},
  {{"CONSTANTP", CL_ORDINARY, mk_cl_constantp, -1, MKCL_OBJNULL}},
  {{"CONTROL-ERROR", CL_ORDINARY, NULL, -1, MKCL_OBJNULL}},
  {{"COPY-ALIST", CL_ORDINARY, mk_cl_copy_alist, 1, MKCL_OBJNULL}},
  {{"COPY-LIST", CL_ORDINARY, mk_cl_copy_list, 1, MKCL_OBJNULL}},
  {{"COPY-PPRINT-DISPATCH", CL_ORDINARY, MKCL_NAME_PPRINT(mk_cl_copy_pprint_dispatch), -1, MKCL_OBJNULL}},
  {{"COPY-READTABLE", CL_ORDINARY, mk_cl_copy_readtable, -1, MKCL_OBJNULL}},
  {{"COPY-SEQ", CL_ORDINARY, mk_cl_copy_seq, 1, MKCL_OBJNULL}},
  {{"COPY-STRUCTURE", CL_ORDINARY, mk_cl_copy_structure, 1, MKCL_OBJNULL}},
  {{"COPY-SYMBOL", CL_ORDINARY, mk_cl_copy_symbol, -1, MKCL_OBJNULL}},
  {{"COPY-TREE", CL_ORDINARY, mk_cl_copy_tree, 1, MKCL_OBJNULL}},
  {{"COS", CL_ORDINARY, mk_cl_cos, 1, MKCL_OBJNULL}},
  {{"COSH", CL_ORDINARY, mk_cl_cosh, 1, MKCL_OBJNULL}},
  {{"COUNT", CL_ORDINARY, MKCL_IN_LISP(mk_cl_count), -1, MKCL_OBJNULL}},
  {{"COUNT-IF", CL_ORDINARY, MKCL_IN_LISP(mk_cl_count_if), -1, MKCL_OBJNULL}},
  {{"COUNT-IF-NOT", CL_ORDINARY, MKCL_IN_LISP(mk_cl_count_if_not), -1, MKCL_OBJNULL}},
  {{"CTYPECASE", CL_ORDINARY, NULL, -1, MKCL_OBJNULL}},
  {{"DEBUG", CL_ORDINARY, NULL, -1, MKCL_OBJNULL}},
  {{"DECF", CL_ORDINARY, NULL, -1, MKCL_OBJNULL}},
  {{"DECLAIM", CL_ORDINARY, NULL, -1, MKCL_OBJNULL}},
  {{"DECLARATION", CL_ORDINARY, NULL, -1, MKCL_OBJNULL}},
  {{"DECLARE", CL_ORDINARY, NULL, -1, MKCL_OBJNULL}},
  {{"DECODE-FLOAT", CL_ORDINARY, mk_cl_decode_float, 1, MKCL_OBJNULL}},
  {{"DECODE-UNIVERSAL-TIME", CL_ORDINARY, MKCL_IN_LISP(mk_cl_decode_universal_time), -1, MKCL_OBJNULL}},
  {{"DEFCONSTANT", CL_ORDINARY, NULL, -1, MKCL_OBJNULL}},
  {{"DEFINE-CONDITION", CL_ORDINARY, NULL, -1, MKCL_OBJNULL}},
  {{"DEFINE-COMPILER-MACRO", CL_ORDINARY, NULL, -1, MKCL_OBJNULL}},
  {{"DEFINE-MODIFY-MACRO", CL_ORDINARY, NULL, -1, MKCL_OBJNULL}},
  {{"DEFINE-SETF-EXPANDER", CL_ORDINARY, NULL, -1, MKCL_OBJNULL}},
  {{"DEFINE-SYMBOL-MACRO", CL_ORDINARY, NULL, -1, MKCL_OBJNULL}},
  {{"DEFMACRO", CL_ORDINARY, NULL, -1, MKCL_OBJNULL}},
  {{"DEFPACKAGE", CL_ORDINARY, NULL, -1, MKCL_OBJNULL}},
  {{"DEFPARAMETER", CL_ORDINARY, NULL, -1, MKCL_OBJNULL}},
  {{"DEFSETF", CL_ORDINARY, NULL, -1, MKCL_OBJNULL}},
  {{"DEFSTRUCT", CL_ORDINARY, NULL, -1, MKCL_OBJNULL}},
  {{"DEFTYPE", CL_ORDINARY, NULL, -1, MKCL_OBJNULL}},
  {{"DEFUN", CL_ORDINARY, NULL, -1, MKCL_OBJNULL}},
  {{"DEFVAR", CL_ORDINARY, NULL, -1, MKCL_OBJNULL}},
  {{"DELETE", CL_ORDINARY, MKCL_IN_LISP(mk_cl_delete), -1, MKCL_OBJNULL}},
  {{"DELETE-DUPLICATES", CL_ORDINARY, MKCL_IN_LISP(mk_cl_delete_duplicates), -1, MKCL_OBJNULL}},
  {{"DELETE-FILE", CL_ORDINARY, mk_cl_delete_file, 1, MKCL_OBJNULL}},
  {{"DELETE-IF", CL_ORDINARY, MKCL_IN_LISP(mk_cl_delete_if), -1, MKCL_OBJNULL}},
  {{"DELETE-IF-NOT", CL_ORDINARY, MKCL_IN_LISP(mk_cl_delete_if_not), -1, MKCL_OBJNULL}},
  {{"DELETE-PACKAGE", CL_ORDINARY, mk_cl_delete_package, 1, MKCL_OBJNULL}},
  {{"DENOMINATOR", CL_ORDINARY, mk_cl_denominator, 1, MKCL_OBJNULL}},
  {{"DEPOSIT-FIELD", CL_ORDINARY, MKCL_IN_LISP(mk_cl_deposit_field), -1, MKCL_OBJNULL}},
  {{"DESCRIBE", CL_ORDINARY, NULL, -1, MKCL_OBJNULL}},
  {{"DESTRUCTURING-BIND", CL_ORDINARY, NULL, -1, MKCL_OBJNULL}},
  {{"DIGIT-CHAR", CL_ORDINARY, mk_cl_digit_char, -1, MKCL_OBJNULL}},
  {{"DIGIT-CHAR-P", CL_ORDINARY, mk_cl_digit_char_p, -1, MKCL_OBJNULL}},
  {{"DIRECTORY", CL_ORDINARY, mk_cl_directory, -1, MKCL_OBJNULL}},
  {{"DIRECTORY-NAMESTRING", CL_ORDINARY, mk_cl_directory_namestring, 1, MKCL_OBJNULL}},
  {{"DISASSEMBLE", CL_ORDINARY, NULL, -1, MKCL_OBJNULL}},
  {{"DIVISION-BY-ZERO", CL_ORDINARY, NULL, -1, MKCL_OBJNULL}},
  {{"DO", CL_FORM, NULL, -1, MKCL_OBJNULL}},
  {{"DO*", CL_FORM, NULL, -1, MKCL_OBJNULL}},
  {{"DO-ALL-SYMBOLS", CL_ORDINARY, NULL, -1, MKCL_OBJNULL}},
  {{"DO-EXTERNAL-SYMBOLS", CL_ORDINARY, NULL, -1, MKCL_OBJNULL}},
  {{"DO-SYMBOLS", CL_ORDINARY, NULL, -1, MKCL_OBJNULL}},
  {{"DOCUMENTATION", CL_ORDINARY, NULL, -1, MKCL_OBJNULL}},
  {{"DOLIST", CL_FORM, NULL, -1, MKCL_OBJNULL}},
  {{"DOTIMES", CL_FORM, NULL, -1, MKCL_OBJNULL}},
  {{"DOUBLE-FLOAT", CL_ORDINARY, NULL, -1, MKCL_OBJNULL}},
  {{"DOUBLE-FLOAT-EPSILON", CL_CONSTANT, NULL, -1, MKCL_OBJNULL}},
  {{"DOUBLE-FLOAT-NEGATIVE-EPSILON", CL_CONSTANT, NULL, -1, MKCL_OBJNULL}},
  {{"DPB", CL_ORDINARY, MKCL_IN_LISP(mk_cl_dpb), -1, MKCL_OBJNULL}},
  {{"DRIBBLE", CL_ORDINARY, NULL, -1, MKCL_OBJNULL}},
  {{"DYNAMIC-EXTENT", CL_ORDINARY, NULL, -1, MKCL_OBJNULL}},
  {{"ECASE", CL_ORDINARY, NULL, -1, MKCL_OBJNULL}},
  {{"ECHO-STREAM", CL_ORDINARY, NULL, -1, MKCL_OBJNULL}},
  {{"ECHO-STREAM-INPUT-STREAM", CL_ORDINARY, mk_cl_echo_stream_input_stream, 1, MKCL_OBJNULL}},
  {{"ECHO-STREAM-OUTPUT-STREAM", CL_ORDINARY, mk_cl_echo_stream_output_stream, 1, MKCL_OBJNULL}},
  {{"ED", CL_ORDINARY, NULL, -1, MKCL_OBJNULL}},
  {{"EIGHTH", CL_ORDINARY, mk_cl_eighth, 1, MKCL_OBJNULL}},
  {{"ELT", CL_ORDINARY, mk_cl_elt, 2, MKCL_OBJNULL}},
  {{"ENCODE-UNIVERSAL-TIME", CL_ORDINARY, MKCL_IN_LISP(mk_cl_encode_universal_time), -1, MKCL_OBJNULL}},
  {{"END-OF-FILE", CL_ORDINARY, NULL, -1, MKCL_OBJNULL}},
  {{"ENDP", CL_ORDINARY, mk_cl_endp, 1, MKCL_OBJNULL}},
  {{"ENOUGH-NAMESTRING", CL_ORDINARY, mk_cl_enough_namestring, -1, MKCL_OBJNULL}},
  {{"ENSURE-DIRECTORIES-EXIST", CL_ORDINARY, MKCL_IN_LISP(mk_cl_ensure_directories_exist), -1, MKCL_OBJNULL}},
  {{"EQ", CL_ORDINARY, mk_cl_eq, 2, MKCL_OBJNULL}},
  {{"EQL", CL_ORDINARY, mk_cl_eql, 2, MKCL_OBJNULL}},
  {{"EQUAL", CL_ORDINARY, mk_cl_equal, 2, MKCL_OBJNULL}},
  {{"EQUALP", CL_ORDINARY, mk_cl_equalp, 2, MKCL_OBJNULL}},
  {{"ERROR", CL_ORDINARY, mk_cl_error, -1, MKCL_OBJNULL}},
  {{"ETYPECASE", CL_ORDINARY, NULL, -1, MKCL_OBJNULL}},
  {{"EVAL", CL_ORDINARY, mk_cl_eval, 1, MKCL_OBJNULL}},
  {{"EVAL-WHEN", CL_FORM, NULL, -1, MKCL_OBJNULL}},
  {{"EVENP", CL_ORDINARY, mk_cl_evenp, 1, MKCL_OBJNULL}},
  {{"EVERY", CL_ORDINARY, MKCL_IN_LISP(mk_cl_every), -1, MKCL_OBJNULL}},
  {{"EXP", CL_ORDINARY, mk_cl_exp, 1, MKCL_OBJNULL}},
  {{"EXPORT", CL_ORDINARY, mk_cl_export, -1, MKCL_OBJNULL}},
  {{"EXPT", CL_ORDINARY, mk_cl_expt, 2, MKCL_OBJNULL}},
  {{"EXTENDED-CHAR", CL_ORDINARY, NULL, -1, MKCL_OBJNULL}},
  {{"FBOUNDP", CL_ORDINARY, mk_cl_fboundp, 1, MKCL_OBJNULL}},
  {{"FCEILING", CL_ORDINARY, MKCL_IN_LISP(mk_cl_fceiling), -1, MKCL_OBJNULL}},
  {{"FDEFINITION", CL_ORDINARY, mk_cl_fdefinition, 1, MKCL_OBJNULL}},
  {{"FFLOOR", CL_ORDINARY, MKCL_IN_LISP(mk_cl_ffloor), -1, MKCL_OBJNULL}},
  {{"FIFTH", CL_ORDINARY, mk_cl_fifth, 1, MKCL_OBJNULL}},
  {{"FILE-AUTHOR", CL_ORDINARY, mk_cl_file_author, 1, MKCL_OBJNULL}},
  {{"FILE-ERROR", CL_ORDINARY, NULL, -1, MKCL_OBJNULL}},
  {{"FILE-ERROR-PATHNAME", CL_ORDINARY, NULL, -1, MKCL_OBJNULL}},
  {{"FILE-LENGTH", CL_ORDINARY, mk_cl_file_length, 1, MKCL_OBJNULL}},
  {{"FILE-NAMESTRING", CL_ORDINARY, mk_cl_file_namestring, 1, MKCL_OBJNULL}},
  {{"FILE-POSITION", CL_ORDINARY, mk_cl_file_position, -1, MKCL_OBJNULL}},
  {{"FILE-STREAM", CL_ORDINARY, NULL, -1, MKCL_OBJNULL}},
  {{"FILE-STRING-LENGTH", CL_ORDINARY, mk_cl_file_string_length, 2, MKCL_OBJNULL}},
  {{"FILE-WRITE-DATE", CL_ORDINARY, mk_cl_file_write_date, 1, MKCL_OBJNULL}},
  {{"FILL", CL_ORDINARY, MKCL_IN_LISP(mk_cl_fill), -1, MKCL_OBJNULL}},
  {{"FILL-POINTER", CL_ORDINARY, mk_cl_fill_pointer, 1, MKCL_OBJNULL}},
  {{"FIND", CL_ORDINARY, MKCL_IN_LISP(mk_cl_find), -1, MKCL_OBJNULL}},
  {{"FIND-ALL-SYMBOLS", CL_ORDINARY, MKCL_IN_LISP(mk_cl_find_all_symbols), -1, MKCL_OBJNULL}},
  {{"FIND-IF", CL_ORDINARY, MKCL_IN_LISP(mk_cl_find_if), -1, MKCL_OBJNULL}},
  {{"FIND-IF-NOT", CL_ORDINARY, MKCL_IN_LISP(mk_cl_find_if_not), -1, MKCL_OBJNULL}},
  {{"FIND-PACKAGE", CL_ORDINARY, mk_cl_find_package, 1, MKCL_OBJNULL}},
  {{"FIND-RESTART", CL_ORDINARY, NULL, -1, MKCL_OBJNULL}},
  {{"FIND-SYMBOL", CL_ORDINARY, mk_cl_find_symbol, -1, MKCL_OBJNULL}},
  {{"FINISH-OUTPUT", CL_ORDINARY, mk_cl_finish_output, -1, MKCL_OBJNULL}},
  {{"FIRST", CL_ORDINARY, mk_cl_car, 1, MKCL_OBJNULL}},
  {{"FIXNUM", CL_ORDINARY, NULL, -1, MKCL_OBJNULL}},
  {{"FLET", CL_FORM, NULL, -1, MKCL_OBJNULL}},
  {{"FLOAT", CL_ORDINARY, mk_cl_float, -1, MKCL_OBJNULL}},
  {{"FLOAT-DIGITS", CL_ORDINARY, mk_cl_float_digits, 1, MKCL_OBJNULL}},
  {{"FLOAT-PRECISION", CL_ORDINARY, mk_cl_float_precision, 1, MKCL_OBJNULL}},
  {{"FLOAT-RADIX", CL_ORDINARY, mk_cl_float_radix, 1, MKCL_OBJNULL}},
  {{"FLOAT-SIGN", CL_ORDINARY, mk_cl_float_sign, -1, MKCL_OBJNULL}},
  {{"FLOATING-POINT-INEXACT", CL_ORDINARY, NULL, -1, MKCL_OBJNULL}},
  {{"FLOATING-POINT-INVALID-OPERATION", CL_ORDINARY, NULL, -1, MKCL_OBJNULL}},
  {{"FLOATING-POINT-OVERFLOW", CL_ORDINARY, NULL, -1, MKCL_OBJNULL}},
  {{"FLOATING-POINT-UNDERFLOW", CL_ORDINARY, NULL, -1, MKCL_OBJNULL}},
  {{"FLOATP", CL_ORDINARY, mk_cl_floatp, 1, MKCL_OBJNULL}},
  {{"FLOOR", CL_ORDINARY, mk_cl_floor, -1, MKCL_OBJNULL}},
  {{"FMAKUNBOUND", CL_ORDINARY, mk_cl_fmakunbound, 1, MKCL_OBJNULL}},
  {{"FORCE-OUTPUT", CL_ORDINARY, mk_cl_force_output, -1, MKCL_OBJNULL}},
  {{"FORMAT", CL_ORDINARY, mk_cl_format, -1, MKCL_OBJNULL}},
  {{"FORMATTER", CL_ORDINARY, NULL, -1, MKCL_OBJNULL}},
  {{"FOURTH", CL_ORDINARY, mk_cl_cadddr, 1, MKCL_OBJNULL}},
  {{"FRESH-LINE", CL_ORDINARY, mk_cl_fresh_line, -1, MKCL_OBJNULL}},
  {{"FROUND", CL_ORDINARY, MKCL_IN_LISP(mk_cl_fround), -1, MKCL_OBJNULL}},
  {{"FTRUNCATE", CL_ORDINARY, MKCL_IN_LISP(mk_cl_ftruncate), -1, MKCL_OBJNULL}},
  {{"FTYPE", CL_ORDINARY, NULL, -1, MKCL_OBJNULL}},
  {{"FUNCALL", CL_ORDINARY, mk_cl_funcall, -1, MKCL_OBJNULL}},
  {{"FUNCTION-LAMBDA-EXPRESSION", CL_ORDINARY, mk_cl_function_lambda_expression, 1, MKCL_OBJNULL}},
  {{"FUNCTION", CL_FORM, NULL, -1, MKCL_OBJNULL}},
  {{"FUNCTION-KEYWORDS", CL_ORDINARY, NULL, -1, MKCL_OBJNULL}},
  {{"FUNCTIONP", CL_ORDINARY, mk_cl_functionp, 1, MKCL_OBJNULL}},
  {{"GCD", CL_ORDINARY, mk_cl_gcd, -1, MKCL_OBJNULL}},
  {{"GENSYM", CL_ORDINARY, mk_cl_gensym, -1, MKCL_OBJNULL}},
  {{"GENTEMP", CL_ORDINARY, mk_cl_gentemp, -1, MKCL_OBJNULL}},
  {{"GET", CL_ORDINARY, mk_cl_get, -1, MKCL_OBJNULL}},
  {{"GET-DECODED-TIME", CL_ORDINARY, MKCL_IN_LISP(mk_cl_get_decoded_time), -1, MKCL_OBJNULL}},
  {{"GET-DISPATCH-MACRO-CHARACTER", CL_ORDINARY, mk_cl_get_dispatch_macro_character, -1, MKCL_OBJNULL}},
  {{"GET-INTERNAL-REAL-TIME", CL_ORDINARY, mk_cl_get_internal_real_time, 0, MKCL_OBJNULL}},
  {{"GET-INTERNAL-RUN-TIME", CL_ORDINARY, mk_cl_get_internal_run_time, 0, MKCL_OBJNULL}},
  {{"GET-MACRO-CHARACTER", CL_ORDINARY, mk_cl_get_macro_character, -1, MKCL_OBJNULL}},
  {{"GET-OUTPUT-STREAM-STRING", CL_ORDINARY, mk_cl_get_output_stream_string, 1, MKCL_OBJNULL}},
  {{"GET-PROPERTIES", CL_ORDINARY, mk_cl_get_properties, 2, MKCL_OBJNULL}},
  {{"GET-SETF-EXPANSION", CL_ORDINARY, NULL, -1, MKCL_OBJNULL}},
  {{"GET-UNIVERSAL-TIME", CL_ORDINARY, mk_cl_get_universal_time, 0, MKCL_OBJNULL}},
  {{"GETF", CL_ORDINARY, mk_cl_getf, -1, MKCL_OBJNULL}},
  {{"GETHASH", CL_ORDINARY, mk_cl_gethash, -1, MKCL_OBJNULL}},
  {{"GO", CL_FORM, NULL, -1, MKCL_OBJNULL}},
  {{"GRAPHIC-CHAR-P", CL_ORDINARY, mk_cl_graphic_char_p, 1, MKCL_OBJNULL}},
  {{"HANDLER-CASE", CL_ORDINARY, NULL, -1, MKCL_OBJNULL}},
  {{"HANDLER-BIND", CL_ORDINARY, NULL, -1, MKCL_OBJNULL}},
  {{"HASH-TABLE", CL_ORDINARY, NULL, -1, MKCL_OBJNULL}},
  {{"HASH-TABLE-COUNT", CL_ORDINARY, mk_cl_hash_table_count, 1, MKCL_OBJNULL}},
  {{"HASH-TABLE-P", CL_ORDINARY, mk_cl_hash_table_p, 1, MKCL_OBJNULL}},
  {{"HASH-TABLE-REHASH-SIZE", CL_ORDINARY, mk_cl_hash_table_rehash_size, 1, MKCL_OBJNULL}},
  {{"HASH-TABLE-REHASH-THRESHOLD", CL_ORDINARY, mk_cl_hash_table_rehash_threshold, 1, MKCL_OBJNULL}},
  {{"HASH-TABLE-SIZE", CL_ORDINARY, mk_cl_hash_table_size, 1, MKCL_OBJNULL}},
  {{"HASH-TABLE-TEST", CL_ORDINARY, mk_cl_hash_table_test, 1, MKCL_OBJNULL}},
  {{"HOST-NAMESTRING", CL_ORDINARY, mk_cl_host_namestring, 1, MKCL_OBJNULL}},
  {{"IDENTITY", CL_ORDINARY, mk_cl_identity, 1, MKCL_OBJNULL}},
  {{"IGNORABLE", CL_ORDINARY, NULL, -1, MKCL_OBJNULL}},
  {{"IGNORE", CL_ORDINARY, NULL, -1, MKCL_OBJNULL}},
  {{"IGNORE-ERRORS", CL_ORDINARY, NULL, -1, MKCL_OBJNULL}},
  {{"IMAGPART", CL_ORDINARY, mk_cl_imagpart, 1, MKCL_OBJNULL}},
  {{"IMPORT", CL_ORDINARY, mk_cl_import, -1, MKCL_OBJNULL}},
  {{"IN-PACKAGE", CL_ORDINARY, NULL, -1, MKCL_OBJNULL}},
  {{"INCF", CL_ORDINARY, NULL, -1, MKCL_OBJNULL}},
  {{"INLINE", CL_ORDINARY, NULL, -1, MKCL_OBJNULL}},
  {{"INPUT-STREAM-P", CL_ORDINARY, mk_cl_input_stream_p, 1, MKCL_OBJNULL}},
  {{"INSPECT", CL_ORDINARY, NULL, -1, MKCL_OBJNULL}},
  {{"INTEGER", CL_ORDINARY, NULL, -1, MKCL_OBJNULL}},
  {{"INTEGER-DECODE-FLOAT", CL_ORDINARY, mk_cl_integer_decode_float, 1, MKCL_OBJNULL}},
  {{"INTEGER-LENGTH", CL_ORDINARY, mk_cl_integer_length, 1, MKCL_OBJNULL}},
  {{"INTEGERP", CL_ORDINARY, mk_cl_integerp, 1, MKCL_OBJNULL}},
  {{"INTERACTIVE-STREAM-P", CL_ORDINARY, mk_cl_interactive_stream_p, 1, MKCL_OBJNULL}},
  {{"INTERN", CL_ORDINARY, mk_cl_intern, -1, MKCL_OBJNULL}},
  {{"INTERNAL-TIME-UNITS-PER-SECOND", CL_CONSTANT, NULL, -1, MKCL_OBJNULL}},
  {{"INTERSECTION", CL_ORDINARY, MKCL_IN_LISP(mk_cl_intersection), -1, MKCL_OBJNULL}},
  {{"INVOKE-DEBUGGER", CL_ORDINARY, NULL, -1, MKCL_OBJNULL}},
  {{"INVOKE-RESTART", CL_ORDINARY, NULL, -1, MKCL_OBJNULL}},
  {{"INVOKE-RESTART-INTERACTIVELY", CL_ORDINARY, NULL, -1, MKCL_OBJNULL}},
  {{"ISQRT", CL_ORDINARY, MKCL_IN_LISP(mk_cl_isqrt), -1, MKCL_OBJNULL}},
  {{"KEYWORD", CL_ORDINARY, NULL, -1, MKCL_OBJNULL}},
  {{"KEYWORDP", CL_ORDINARY, mk_cl_keywordp, 1, MKCL_OBJNULL}},
  {{"LABELS", CL_FORM, NULL, -1, MKCL_OBJNULL}},
  {{"LAMBDA", CL_FORM, NULL, -1, MKCL_OBJNULL}},
  {{"LAMBDA-LIST-KEYWORDS", CL_CONSTANT, NULL, -1, MKCL_OBJNULL}},
  {{"LAMBDA-PARAMETERS-LIMIT", CL_CONSTANT, NULL, -1, MKCL_MAKE_FIXNUM(MKCL_LAMBDA_PARAMETERS_LIMIT)}},
  {{"LAST", CL_ORDINARY, mk_cl_last, -1, MKCL_OBJNULL}},
  {{"LCM", CL_ORDINARY, mk_cl_lcm, -1, MKCL_OBJNULL}},
  {{"LDB", CL_ORDINARY, MKCL_IN_LISP(mk_cl_ldb), -1, MKCL_OBJNULL}},
  {{"LDB-TEST", CL_ORDINARY, MKCL_IN_LISP(mk_cl_ldb_test), -1, MKCL_OBJNULL}},
  {{"LDIFF", CL_ORDINARY, mk_cl_ldiff, 2, MKCL_OBJNULL}},
  {{"LEAST-NEGATIVE-DOUBLE-FLOAT", CL_CONSTANT, NULL, -1, MKCL_OBJNULL}},
  {{"LEAST-NEGATIVE-LONG-FLOAT", CL_CONSTANT, NULL, -1, MKCL_OBJNULL}},
  {{"LEAST-NEGATIVE-NORMALIZED-DOUBLE-FLOAT", CL_CONSTANT, NULL, -1, MKCL_OBJNULL}},
  {{"LEAST-NEGATIVE-NORMALIZED-LONG-FLOAT", CL_CONSTANT, NULL, -1, MKCL_OBJNULL}},
  {{"LEAST-NEGATIVE-NORMALIZED-SHORT-FLOAT", CL_CONSTANT, NULL, -1, MKCL_OBJNULL}},
  {{"LEAST-NEGATIVE-NORMALIZED-SINGLE-FLOAT", CL_CONSTANT, NULL, -1, MKCL_OBJNULL}},
  {{"LEAST-NEGATIVE-SHORT-FLOAT", CL_CONSTANT, NULL, -1, MKCL_OBJNULL}},
  {{"LEAST-NEGATIVE-SINGLE-FLOAT", CL_CONSTANT, NULL, -1, MKCL_OBJNULL}},
  {{"LEAST-POSITIVE-DOUBLE-FLOAT", CL_CONSTANT, NULL, -1, MKCL_OBJNULL}},
  {{"LEAST-POSITIVE-LONG-FLOAT", CL_CONSTANT, NULL, -1, MKCL_OBJNULL}},
  {{"LEAST-POSITIVE-NORMALIZED-DOUBLE-FLOAT", CL_CONSTANT, NULL, -1, MKCL_OBJNULL}},
  {{"LEAST-POSITIVE-NORMALIZED-LONG-FLOAT", CL_CONSTANT, NULL, -1, MKCL_OBJNULL}},
  {{"LEAST-POSITIVE-NORMALIZED-SHORT-FLOAT", CL_CONSTANT, NULL, -1, MKCL_OBJNULL}},
  {{"LEAST-POSITIVE-NORMALIZED-SINGLE-FLOAT", CL_CONSTANT, NULL, -1, MKCL_OBJNULL}},
  {{"LEAST-POSITIVE-SHORT-FLOAT", CL_CONSTANT, NULL, -1, MKCL_OBJNULL}},
  {{"LEAST-POSITIVE-SINGLE-FLOAT", CL_CONSTANT, NULL, -1, MKCL_OBJNULL}},
  {{"LENGTH", CL_ORDINARY, mk_cl_length, 1, MKCL_OBJNULL}},
  {{"LET", CL_FORM, NULL, -1, MKCL_OBJNULL}},
  {{"LET*", CL_FORM, NULL, -1, MKCL_OBJNULL}},
  {{"LISP-IMPLEMENTATION-TYPE", CL_ORDINARY, NULL, -1, MKCL_OBJNULL}},
  {{"LISP-IMPLEMENTATION-VERSION", CL_ORDINARY, NULL, -1, MKCL_OBJNULL}},
  {{"LIST", CL_ORDINARY, mk_cl_list, -1, MKCL_OBJNULL}},
  {{"LIST*", CL_ORDINARY, mk_cl_listX, -1, MKCL_OBJNULL}},
  {{"LIST-ALL-PACKAGES", CL_ORDINARY, mk_cl_list_all_packages, 0, MKCL_OBJNULL}},
  {{"LIST-LENGTH", CL_ORDINARY, mk_cl_list_length, 1, MKCL_OBJNULL}},
  {{"LISTEN", CL_ORDINARY, mk_cl_listen, -1, MKCL_OBJNULL}},
  {{"LISTP", CL_ORDINARY, mk_cl_listp, 1, MKCL_OBJNULL}},
  {{"LOAD", CL_ORDINARY, mk_cl_load, -1, MKCL_OBJNULL}},
  {{"LOAD-LOGICAL-PATHNAME-TRANSLATIONS", CL_ORDINARY, MKCL_IN_LISP(mk_cl_load_logical_pathname_translations), -1, MKCL_OBJNULL}},
  {{"LOAD-TIME-VALUE", CL_FORM, NULL, -1, MKCL_OBJNULL}},
  {{"LOCALLY", CL_FORM, NULL, -1, MKCL_OBJNULL}},
  {{"LOG", CL_ORDINARY, mk_cl_log, -1, MKCL_OBJNULL}},
  {{"LOGAND", CL_ORDINARY, mk_cl_logand, -1, MKCL_OBJNULL}},
  {{"LOGANDC1", CL_ORDINARY, mk_cl_logandc1, 2, MKCL_OBJNULL}},
  {{"LOGANDC2", CL_ORDINARY, mk_cl_logandc2, 2, MKCL_OBJNULL}},
  {{"LOGBITP", CL_ORDINARY, mk_cl_logbitp, 2, MKCL_OBJNULL}},
  {{"LOGCOUNT", CL_ORDINARY, mk_cl_logcount, 1, MKCL_OBJNULL}},
  {{"LOGEQV", CL_ORDINARY, mk_cl_logeqv, -1, MKCL_OBJNULL}},
  {{"LOGICAL-PATHNAME", CL_ORDINARY, mk_cl_logical_pathname, 1, MKCL_OBJNULL}},
  {{"LOGICAL-PATHNAME-TRANSLATIONS", CL_ORDINARY, MKCL_IN_LISP(mk_cl_logical_pathname_translations), -1, MKCL_OBJNULL}},
  {{"LOGIOR", CL_ORDINARY, mk_cl_logior, -1, MKCL_OBJNULL}},
  {{"LOGNAND", CL_ORDINARY, mk_cl_lognand, 2, MKCL_OBJNULL}},
  {{"LOGNOR", CL_ORDINARY, mk_cl_lognor, 2, MKCL_OBJNULL}},
  {{"LOGNOT", CL_ORDINARY, mk_cl_lognot, 1, MKCL_OBJNULL}},
  {{"LOGORC1", CL_ORDINARY, mk_cl_logorc1, 2, MKCL_OBJNULL}},
  {{"LOGORC2", CL_ORDINARY, mk_cl_logorc2, 2, MKCL_OBJNULL}},
  {{"LOGTEST", CL_ORDINARY, MKCL_IN_LISP(mk_cl_logtest), -1, MKCL_OBJNULL}},
  {{"LOGXOR", CL_ORDINARY, mk_cl_logxor, -1, MKCL_OBJNULL}},
  {{"LONG-FLOAT", CL_ORDINARY, NULL, -1, MKCL_OBJNULL}},
  {{"LONG-FLOAT-EPSILON", CL_CONSTANT, NULL, -1, MKCL_OBJNULL}},
  {{"LONG-FLOAT-NEGATIVE-EPSILON", CL_CONSTANT, NULL, -1, MKCL_OBJNULL}},
  {{"LONG-SITE-NAME", CL_ORDINARY, NULL, -1, MKCL_OBJNULL}},
  {{"LOOP", CL_ORDINARY, NULL, -1, MKCL_OBJNULL}},
  {{"LOOP-FINISH", CL_ORDINARY, NULL, -1, MKCL_OBJNULL}},
  {{"LOWER-CASE-P", CL_ORDINARY, mk_cl_lower_case_p, 1, MKCL_OBJNULL}},
  {{"MACHINE-INSTANCE", CL_ORDINARY, NULL, -1, MKCL_OBJNULL}},
  {{"MACHINE-TYPE", CL_ORDINARY, NULL, -1, MKCL_OBJNULL}},
  {{"MACHINE-VERSION", CL_ORDINARY, NULL, -1, MKCL_OBJNULL}},
  {{"MACRO-FUNCTION", CL_ORDINARY, mk_cl_macro_function, -1, MKCL_OBJNULL}},
  {{"MACROEXPAND", CL_ORDINARY, mk_cl_macroexpand, -1, MKCL_OBJNULL}},
  {{"MACROEXPAND-1", CL_ORDINARY, mk_cl_macroexpand_1, -1, MKCL_OBJNULL}},
  {{"MACROLET", CL_FORM, NULL, -1, MKCL_OBJNULL}},
  {{"MAKE-ARRAY", CL_ORDINARY, MKCL_IN_LISP(mk_cl_make_array), -1, MKCL_OBJNULL}},
  {{"MAKE-BROADCAST-STREAM", CL_ORDINARY, mk_cl_make_broadcast_stream, -1, MKCL_OBJNULL}},
  {{"MAKE-CONDITION", CL_ORDINARY, NULL, -1, MKCL_OBJNULL}},
  {{"MAKE-CONCATENATED-STREAM", CL_ORDINARY, mk_cl_make_concatenated_stream, -1, MKCL_OBJNULL}},
  {{"MAKE-DISPATCH-MACRO-CHARACTER", CL_ORDINARY, mk_cl_make_dispatch_macro_character, -1, MKCL_OBJNULL}},
  {{"MAKE-ECHO-STREAM", CL_ORDINARY, mk_cl_make_echo_stream, 2, MKCL_OBJNULL}},
  {{"MAKE-HASH-TABLE", CL_ORDINARY, mk_cl_make_hash_table, -1, MKCL_OBJNULL}},
  {{"MAKE-LIST", CL_ORDINARY, mk_cl_make_list, -1, MKCL_OBJNULL}},
  {{"MAKE-PACKAGE", CL_ORDINARY, mk_cl_make_package, -1, MKCL_OBJNULL}},
  {{"MAKE-PATHNAME", CL_ORDINARY, mk_cl_make_pathname, -1, MKCL_OBJNULL}},
  {{"MAKE-RANDOM-STATE", CL_ORDINARY, mk_cl_make_random_state, -1, MKCL_OBJNULL}},
  {{"MAKE-SEQUENCE", CL_ORDINARY, MKCL_IN_LISP(mk_cl_make_sequence), -1, MKCL_OBJNULL}},
  {{"MAKE-STRING", CL_ORDINARY, mk_cl_make_string, -1, MKCL_OBJNULL}},
  {{"MAKE-STRING-INPUT-STREAM", CL_ORDINARY, mk_cl_make_string_input_stream, -1, MKCL_OBJNULL}},
  {{"MAKE-STRING-OUTPUT-STREAM", CL_ORDINARY, mk_cl_make_string_output_stream, -1, MKCL_OBJNULL}},
  {{"MAKE-SYMBOL", CL_ORDINARY, mk_cl_make_symbol, 1, MKCL_OBJNULL}},
  {{"MAKE-SYNONYM-STREAM", CL_ORDINARY, mk_cl_make_synonym_stream, 1, MKCL_OBJNULL}},
  {{"MAKE-TWO-WAY-STREAM", CL_ORDINARY, mk_cl_make_two_way_stream, 2, MKCL_OBJNULL}},
  {{"MAKUNBOUND", CL_ORDINARY, mk_cl_makunbound, 1, MKCL_OBJNULL}},
  {{"MAP", CL_ORDINARY, MKCL_IN_LISP(mk_cl_map), -1, MKCL_OBJNULL}},
  {{"MAP-INTO", CL_ORDINARY, MKCL_IN_LISP(mk_cl_map_into), -1, MKCL_OBJNULL}},
  {{"MAPC", CL_ORDINARY, mk_cl_mapc, -1, MKCL_OBJNULL}},
  {{"MAPCAN", CL_ORDINARY, mk_cl_mapcan, -1, MKCL_OBJNULL}},
  {{"MAPCAR", CL_ORDINARY, mk_cl_mapcar, -1, MKCL_OBJNULL}},
  {{"MAPCON", CL_ORDINARY, mk_cl_mapcon, -1, MKCL_OBJNULL}},
  {{"MAPHASH", CL_ORDINARY, mk_cl_maphash, 2, MKCL_OBJNULL}},
  {{"MAPL", CL_ORDINARY, mk_cl_mapl, -1, MKCL_OBJNULL}},
  {{"MAPLIST", CL_ORDINARY, mk_cl_maplist, -1, MKCL_OBJNULL}},
  {{"MASK-FIELD", CL_ORDINARY, MKCL_IN_LISP(mk_cl_mask_field), -1, MKCL_OBJNULL}},
  {{"MAX", CL_ORDINARY, mk_cl_max, -1, MKCL_OBJNULL}},
  {{"MEMBER", CL_ORDINARY, mk_cl_member, -1, MKCL_OBJNULL}},
  {{"MEMBER-IF", CL_ORDINARY, MKCL_IN_LISP(mk_cl_member_if), -1, MKCL_OBJNULL}},
  {{"MEMBER-IF-NOT", CL_ORDINARY, MKCL_IN_LISP(mk_cl_member_if_not), -1, MKCL_OBJNULL}},
  {{"MERGE", CL_ORDINARY, MKCL_IN_LISP(mk_cl_merge), -1, MKCL_OBJNULL}},
  {{"MERGE-PATHNAMES", CL_ORDINARY, mk_cl_merge_pathnames, -1, MKCL_OBJNULL}},
  {{"MIN", CL_ORDINARY, mk_cl_min, -1, MKCL_OBJNULL}},
  {{"MINUSP", CL_ORDINARY, mk_cl_minusp, 1, MKCL_OBJNULL}},
  {{"MISMATCH", CL_ORDINARY, MKCL_IN_LISP(mk_cl_mismatch), -1, MKCL_OBJNULL}},
  {{"MOD", CL_ORDINARY, mk_cl_mod, 2, MKCL_OBJNULL}},
  {{"MOST-NEGATIVE-DOUBLE-FLOAT", CL_CONSTANT, NULL, -1, MKCL_OBJNULL}},
  {{"MOST-NEGATIVE-FIXNUM", CL_CONSTANT, NULL, -1, MKCL_MAKE_FIXNUM(MKCL_MOST_NEGATIVE_FIXNUM)}},
  {{"MOST-NEGATIVE-LONG-FLOAT", CL_CONSTANT, NULL, -1, MKCL_OBJNULL}},
  {{"MOST-NEGATIVE-SHORT-FLOAT", CL_CONSTANT, NULL, -1, MKCL_OBJNULL}},
  {{"MOST-NEGATIVE-SINGLE-FLOAT", CL_CONSTANT, NULL, -1, MKCL_OBJNULL}},
  {{"MOST-POSITIVE-DOUBLE-FLOAT", CL_CONSTANT, NULL, -1, MKCL_OBJNULL}},
  {{"MOST-POSITIVE-FIXNUM", CL_CONSTANT, NULL, -1, MKCL_MAKE_FIXNUM(MKCL_MOST_POSITIVE_FIXNUM)}},
  {{"MOST-POSITIVE-LONG-FLOAT", CL_CONSTANT, NULL, -1, MKCL_OBJNULL}},
  {{"MOST-POSITIVE-SHORT-FLOAT", CL_CONSTANT, NULL, -1, MKCL_OBJNULL}},
  {{"MOST-POSITIVE-SINGLE-FLOAT", CL_CONSTANT, NULL, -1, MKCL_OBJNULL}},
  {{"MUFFLE-WARNING", CL_ORDINARY, NULL, -1, MKCL_OBJNULL}},
  {{"MULTIPLE-VALUE-BIND", CL_FORM, NULL, -1, MKCL_OBJNULL}},
  {{"MULTIPLE-VALUE-CALL", CL_FORM, NULL, -1, MKCL_OBJNULL}},
  {{"MULTIPLE-VALUE-LIST", CL_FORM, NULL, -1, MKCL_OBJNULL}},
  {{"MULTIPLE-VALUE-PROG1", CL_FORM, NULL, -1, MKCL_OBJNULL}},
  {{"MULTIPLE-VALUE-SETQ", CL_FORM, NULL, -1, MKCL_OBJNULL}},
  {{"MULTIPLE-VALUES-LIMIT", CL_CONSTANT, NULL, -1, MKCL_MAKE_FIXNUM(MKCL_MULTIPLE_VALUES_LIMIT)}},
  {{"NAME-CHAR", CL_ORDINARY, mk_cl_name_char, 1, MKCL_OBJNULL}},
  {{"NAMESTRING", CL_ORDINARY, mk_cl_namestring, 1, MKCL_OBJNULL}},
  {{"NBUTLAST", CL_ORDINARY, mk_cl_nbutlast, -1, MKCL_OBJNULL}},
  {{"NCONC", CL_ORDINARY, mk_cl_nconc, -1, MKCL_OBJNULL}},
  {{"NINTERSECTION", CL_ORDINARY, MKCL_IN_LISP(mk_cl_nintersection), -1, MKCL_OBJNULL}},
  {{"NINTH", CL_ORDINARY, mk_cl_ninth, 1, MKCL_OBJNULL}},
  {{"NOT", CL_ORDINARY, mk_cl_not, 1, MKCL_OBJNULL}},
  {{"NOTANY", CL_ORDINARY, MKCL_IN_LISP(mk_cl_notany), -1, MKCL_OBJNULL}},
  {{"NOTEVERY", CL_ORDINARY, MKCL_IN_LISP(mk_cl_notevery), -1, MKCL_OBJNULL}},
  {{"NOTINLINE", CL_ORDINARY, NULL, -1, MKCL_OBJNULL}},
  {{"NRECONC", CL_ORDINARY, mk_cl_nreconc, 2, MKCL_OBJNULL}},
  {{"NREVERSE", CL_ORDINARY, mk_cl_nreverse, 1, MKCL_OBJNULL}},
  {{"NSET-DIFFERENCE", CL_ORDINARY, MKCL_IN_LISP(mk_cl_nset_difference), -1, MKCL_OBJNULL}},
  {{"NSET-EXCLUSIVE-OR", CL_ORDINARY, MKCL_IN_LISP(mk_cl_nset_exclusive_or), -1, MKCL_OBJNULL}},
  {{"NSTRING-CAPITALIZE", CL_ORDINARY, mk_cl_nstring_capitalize, -1, MKCL_OBJNULL}},
  {{"NSTRING-DOWNCASE", CL_ORDINARY, mk_cl_nstring_downcase, -1, MKCL_OBJNULL}},
  {{"NSTRING-UPCASE", CL_ORDINARY, mk_cl_nstring_upcase, -1, MKCL_OBJNULL}},
  {{"NSUBLIS", CL_ORDINARY, mk_cl_nsublis, -1, MKCL_OBJNULL}},
  {{"NSUBST", CL_ORDINARY, mk_cl_nsubst, -1, MKCL_OBJNULL}},
  {{"NSUBST-IF", CL_ORDINARY, MKCL_IN_LISP(mk_cl_nsubst_if), -1, MKCL_OBJNULL}},
  {{"NSUBST-IF-NOT", CL_ORDINARY, MKCL_IN_LISP(mk_cl_nsubst_if_not), -1, MKCL_OBJNULL}},
  {{"NSUBSTITUTE", CL_ORDINARY, MKCL_IN_LISP(mk_cl_nsubstitute), -1, MKCL_OBJNULL}},
  {{"NSUBSTITUTE-IF", CL_ORDINARY, MKCL_IN_LISP(mk_cl_nsubstitute_if), -1, MKCL_OBJNULL}},
  {{"NSUBSTITUTE-IF-NOT", CL_ORDINARY, MKCL_IN_LISP(mk_cl_nsubstitute_if_not), -1, MKCL_OBJNULL}},
  {{"NTH", CL_ORDINARY, mk_cl_nth, 2, MKCL_OBJNULL}},
  {{"NTH-VALUE", CL_FORM, NULL, -1, MKCL_OBJNULL}},
  {{"NTHCDR", CL_ORDINARY, mk_cl_nthcdr, 2, MKCL_OBJNULL}},
  {{"NULL", CL_ORDINARY, mk_cl_null, 1, MKCL_OBJNULL}},
  {{"NUMBER", CL_ORDINARY, NULL, -1, MKCL_OBJNULL}},
  {{"NUMBERP", CL_ORDINARY, mk_cl_numberp, 1, MKCL_OBJNULL}},
  {{"NUMERATOR", CL_ORDINARY, mk_cl_numerator, 1, MKCL_OBJNULL}},
  {{"NUNION", CL_ORDINARY, MKCL_IN_LISP(mk_cl_nunion), -1, MKCL_OBJNULL}},
  {{"ODDP", CL_ORDINARY, mk_cl_oddp, 1, MKCL_OBJNULL}},
  {{"OPEN", CL_ORDINARY, mk_cl_open, -1, MKCL_OBJNULL}},
  {{"OPEN-STREAM-P", CL_ORDINARY, mk_cl_open_stream_p, 1, MKCL_OBJNULL}},
  {{"OPTIMIZE", CL_ORDINARY, NULL, -1, MKCL_OBJNULL}},
  {{"OR", CL_ORDINARY, NULL, -1, MKCL_OBJNULL}},
  {{"OTHERWISE", CL_ORDINARY, NULL, -1, MKCL_OBJNULL}},
  {{"OUTPUT-STREAM-P", CL_ORDINARY, mk_cl_output_stream_p, 1, MKCL_OBJNULL}},
  {{"PACKAGE", CL_ORDINARY, NULL, -1, MKCL_OBJNULL}},
  {{"PACKAGE-ERROR", CL_ORDINARY, NULL, -1, MKCL_OBJNULL}},
  {{"PACKAGE-ERROR-PACKAGE", CL_ORDINARY, NULL, -1, MKCL_OBJNULL}},
  {{"PACKAGE-NAME", CL_ORDINARY, mk_cl_package_name, 1, MKCL_OBJNULL}},
  {{"PACKAGE-NICKNAMES", CL_ORDINARY, mk_cl_package_nicknames, 1, MKCL_OBJNULL}},
  {{"PACKAGE-SHADOWING-SYMBOLS", CL_ORDINARY, mk_cl_package_shadowing_symbols, 1, MKCL_OBJNULL}},
  {{"PACKAGE-USE-LIST", CL_ORDINARY, mk_cl_package_use_list, 1, MKCL_OBJNULL}},
  {{"PACKAGE-USED-BY-LIST", CL_ORDINARY, mk_cl_package_used_by_list, 1, MKCL_OBJNULL}},
  {{"PACKAGEP", CL_ORDINARY, mk_cl_packagep, 1, MKCL_OBJNULL}},
  {{"PAIRLIS", CL_ORDINARY, mk_cl_pairlis, -1, MKCL_OBJNULL}},
  {{"PARSE-ERROR", CL_ORDINARY, NULL, -1, MKCL_OBJNULL}},
  {{"PARSE-INTEGER", CL_ORDINARY, mk_cl_parse_integer, -1, MKCL_OBJNULL}},
  {{"PARSE-NAMESTRING", CL_ORDINARY, mk_cl_parse_namestring, -1, MKCL_OBJNULL}},
  {{"PATHNAME", CL_ORDINARY, mk_cl_pathname, 1, MKCL_OBJNULL}},
  {{"PATHNAME-DEVICE", CL_ORDINARY, mk_cl_pathname_device, -1, MKCL_OBJNULL}},
  {{"PATHNAME-DIRECTORY", CL_ORDINARY, mk_cl_pathname_directory, -1, MKCL_OBJNULL}},
  {{"PATHNAME-HOST", CL_ORDINARY, mk_cl_pathname_host, -1, MKCL_OBJNULL}},
  {{"PATHNAME-MATCH-P", CL_ORDINARY, mk_cl_pathname_match_p, 2, MKCL_OBJNULL}},
  {{"PATHNAME-NAME", CL_ORDINARY, mk_cl_pathname_name, -1, MKCL_OBJNULL}},
  {{"PATHNAME-TYPE", CL_ORDINARY, mk_cl_pathname_type, -1, MKCL_OBJNULL}},
  {{"PATHNAME-VERSION", CL_ORDINARY, mk_cl_pathname_version, 1, MKCL_OBJNULL}},
  {{"PATHNAMEP", CL_ORDINARY, mk_cl_pathnamep, 1, MKCL_OBJNULL}},
  {{"PEEK-CHAR", CL_ORDINARY, mk_cl_peek_char, -1, MKCL_OBJNULL}},
  {{"PHASE", CL_ORDINARY, MKCL_IN_LISP(mk_cl_phase), -1, MKCL_OBJNULL}},
  {{"PI", CL_CONSTANT, NULL, -1, MKCL_OBJNULL}},
  {{"PLUSP", CL_ORDINARY, mk_cl_plusp, 1, MKCL_OBJNULL}},
  {{"POP", CL_ORDINARY, NULL, -1, MKCL_OBJNULL}},
  {{"POSITION", CL_ORDINARY, MKCL_IN_LISP(mk_cl_position), -1, MKCL_OBJNULL}},
  {{"POSITION-IF", CL_ORDINARY, MKCL_IN_LISP(mk_cl_position_if), -1, MKCL_OBJNULL}},
  {{"POSITION-IF-NOT", CL_ORDINARY, MKCL_IN_LISP(mk_cl_position_if_not), -1, MKCL_OBJNULL}},
  {{"PPRINT", CL_ORDINARY, mk_cl_pprint, -1, MKCL_OBJNULL}},
  {{"PPRINT-DISPATCH", CL_ORDINARY, MKCL_NAME_PPRINT(mk_cl_pprint_dispatch), -1, MKCL_OBJNULL}},
  {{"PPRINT-EXIT-IF-LIST-EXHAUSTED", CL_ORDINARY, NULL, -1, MKCL_OBJNULL}},
  {{"PPRINT-FILL", CL_ORDINARY, MKCL_NAME_PPRINT(mk_cl_pprint_fill), -1, MKCL_OBJNULL}},
  {{"PPRINT-INDENT", CL_ORDINARY, MKCL_NAME_PPRINT(mk_cl_pprint_indent), -1, MKCL_OBJNULL}},
  {{"PPRINT-LINEAR", CL_ORDINARY, MKCL_NAME_PPRINT(mk_cl_pprint_linear), -1, MKCL_OBJNULL}},
  {{"PPRINT-LOGICAL-BLOCK", CL_ORDINARY, NULL, -1, MKCL_OBJNULL}},
  {{"PPRINT-NEWLINE", CL_ORDINARY, MKCL_NAME_PPRINT(mk_cl_pprint_newline), -1, MKCL_OBJNULL}},
  {{"PPRINT-POP", CL_ORDINARY, NULL, -1, MKCL_OBJNULL}},
  {{"PPRINT-TAB", CL_ORDINARY, MKCL_NAME_PPRINT(mk_cl_pprint_tab), -1, MKCL_OBJNULL}},
  {{"PPRINT-TABULAR", CL_ORDINARY, MKCL_NAME_PPRINT(mk_cl_pprint_tabular), -1, MKCL_OBJNULL}},
  {{"PRIN1", CL_ORDINARY, mk_cl_prin1, -1, MKCL_OBJNULL}},
  {{"PRIN1-TO-STRING", CL_ORDINARY, MKCL_IN_LISP(mk_cl_prin1_to_string), -1, MKCL_OBJNULL}},
  {{"PRINC", CL_ORDINARY, mk_cl_princ, -1, MKCL_OBJNULL}},
  {{"PRINC-TO-STRING", CL_ORDINARY, MKCL_IN_LISP(mk_cl_princ_to_string), -1, MKCL_OBJNULL}},
  {{"PRINT", CL_ORDINARY, mk_cl_print, -1, MKCL_OBJNULL}},
  {{"PRINT-NOT-READABLE", CL_ORDINARY, NULL, -1, MKCL_OBJNULL}},
  {{"PRINT-NOT-READABLE-OBJECT", CL_ORDINARY, NULL, -1, MKCL_OBJNULL}},
  {{"PROBE-FILE", CL_ORDINARY, mk_cl_probe_file, 1, MKCL_OBJNULL}},
  {{"PROCLAIM", CL_ORDINARY, NULL, -1, MKCL_OBJNULL}},
  {{"PROG", CL_FORM, NULL, -1, MKCL_OBJNULL}},
  {{"PROG*", CL_FORM, NULL, -1, MKCL_OBJNULL}},
  {{"PROG1", CL_FORM, NULL, -1, MKCL_OBJNULL}},
  {{"PROG2", CL_FORM, NULL, -1, MKCL_OBJNULL}},
  {{"PROGN", CL_FORM, NULL, -1, MKCL_OBJNULL}},
  {{"PROGRAM-ERROR", CL_ORDINARY, NULL, -1, MKCL_OBJNULL}},
  {{"PROGV", CL_FORM, NULL, -1, MKCL_OBJNULL}},
  {{"PROVIDE", CL_ORDINARY, MKCL_IN_LISP(mk_cl_provide), -1, MKCL_OBJNULL}},
  {{"PSETF", CL_ORDINARY, NULL, -1, MKCL_OBJNULL}},
  {{"PSETQ", CL_FORM, NULL, -1, MKCL_OBJNULL}},
  {{"PUSH", CL_ORDINARY, NULL, -1, MKCL_OBJNULL}},
  {{"PUSHNEW", CL_ORDINARY, NULL, -1, MKCL_OBJNULL}},
  {{"QUOTE", CL_FORM, NULL, -1, MKCL_OBJNULL}},
  {{"RANDOM", CL_ORDINARY, mk_cl_random, -1, MKCL_OBJNULL}},
  {{"RANDOM-STATE", CL_ORDINARY, NULL, -1, MKCL_OBJNULL}},
  {{"RANDOM-STATE-P", CL_ORDINARY, mk_cl_random_state_p, 1, MKCL_OBJNULL}},
  {{"RASSOC", CL_ORDINARY, mk_cl_rassoc, -1, MKCL_OBJNULL}},
  {{"RASSOC-IF", CL_ORDINARY, MKCL_IN_LISP(mk_cl_rassoc_if), -1, MKCL_OBJNULL}},
  {{"RASSOC-IF-NOT", CL_ORDINARY, MKCL_IN_LISP(mk_cl_rassoc_if_not), -1, MKCL_OBJNULL}},
  {{"RATIO", CL_ORDINARY, NULL, -1, MKCL_OBJNULL}},
  {{"RATIONAL", CL_ORDINARY, mk_cl_rational, 1, MKCL_OBJNULL}},
  {{"RATIONALIZE", CL_ORDINARY, mk_cl_rationalize, 1, MKCL_OBJNULL}},
  {{"RATIONALP", CL_ORDINARY, mk_cl_rationalp, 1, MKCL_OBJNULL}},
  {{"READ", CL_ORDINARY, mk_cl_read, -1, MKCL_OBJNULL}},
  {{"READ-BYTE", CL_ORDINARY, mk_cl_read_byte, -1, MKCL_OBJNULL}},
  {{"READ-CHAR", CL_ORDINARY, mk_cl_read_char, -1, MKCL_OBJNULL}},
  {{"READ-CHAR-NO-HANG", CL_ORDINARY, mk_cl_read_char_no_hang, -1, MKCL_OBJNULL}},
  {{"READ-DELIMITED-LIST", CL_ORDINARY, mk_cl_read_delimited_list, -1, MKCL_OBJNULL}},
  {{"READ-FROM-STRING", CL_ORDINARY, MKCL_IN_LISP(mk_cl_read_from_string), -1, MKCL_OBJNULL}},
  {{"READ-LINE", CL_ORDINARY, mk_cl_read_line, -1, MKCL_OBJNULL}},
  {{"READ-PRESERVING-WHITESPACE", CL_ORDINARY, mk_cl_read_preserving_whitespace, -1, MKCL_OBJNULL}},
  {{"READ-SEQUENCE", CL_ORDINARY, mk_cl_read_sequence, -1, MKCL_OBJNULL}},
  {{"READER-ERROR", CL_ORDINARY, NULL, -1, MKCL_OBJNULL}},
  {{"READTABLE", CL_ORDINARY, NULL, -1, MKCL_OBJNULL}},
  {{"READTABLE-CASE", CL_ORDINARY, mk_cl_readtable_case, 1, MKCL_OBJNULL}},
  {{"READTABLEP", CL_ORDINARY, mk_cl_readtablep, 1, MKCL_OBJNULL}},
  {{"REAL", CL_ORDINARY, NULL, -1, MKCL_OBJNULL}},
  {{"REALP", CL_ORDINARY, mk_cl_realp, 1, MKCL_OBJNULL}},
  {{"REALPART", CL_ORDINARY, mk_cl_realpart, 1, MKCL_OBJNULL}},
  {{"REDUCE", CL_ORDINARY, MKCL_IN_LISP(mk_cl_reduce), -1, MKCL_OBJNULL}},
  {{"REM", CL_ORDINARY, mk_cl_rem, 2, MKCL_OBJNULL}},
  {{"REMF", CL_ORDINARY, NULL, -1, MKCL_OBJNULL}},
  {{"REMHASH", CL_ORDINARY, mk_cl_remhash, 2, MKCL_OBJNULL}},
  {{"REMOVE", CL_ORDINARY, MKCL_IN_LISP(mk_cl_remove), -1, MKCL_OBJNULL}},
  {{"REMOVE-DUPLICATES", CL_ORDINARY, MKCL_IN_LISP(mk_cl_remove_duplicates), -1, MKCL_OBJNULL}},
  {{"REMOVE-IF", CL_ORDINARY, MKCL_IN_LISP(mk_cl_remove_if), -1, MKCL_OBJNULL}},
  {{"REMOVE-IF-NOT", CL_ORDINARY, MKCL_IN_LISP(mk_cl_remove_if_not), -1, MKCL_OBJNULL}},
  {{"REMPROP", CL_ORDINARY, mk_cl_remprop, 2, MKCL_OBJNULL}},
  {{"RENAME-FILE", CL_ORDINARY, mk_cl_rename_file, 2, MKCL_OBJNULL}},
  {{"RENAME-PACKAGE", CL_ORDINARY, mk_cl_rename_package, -1, MKCL_OBJNULL}},
  {{"REPLACE", CL_ORDINARY, MKCL_IN_LISP(mk_cl_replace), -1, MKCL_OBJNULL}},
  {{"REQUIRE", CL_ORDINARY, MKCL_IN_LISP(mk_cl_require), -1, MKCL_OBJNULL}},
  {{"REST", CL_ORDINARY, mk_cl_cdr, 1, MKCL_OBJNULL}},
  {{"RESTART", CL_ORDINARY, NULL, 1, MKCL_OBJNULL}},
  {{"RESTART-BIND", CL_ORDINARY, NULL, 1, MKCL_OBJNULL}},
  {{"RESTART-CASE", CL_ORDINARY, NULL, 1, MKCL_OBJNULL}},
  {{"RESTART-NAME", CL_ORDINARY, NULL, 1, MKCL_OBJNULL}},
  {{"RETURN", CL_FORM, NULL, -1, MKCL_OBJNULL}},
  {{"RETURN-FROM", CL_FORM, NULL, -1, MKCL_OBJNULL}},
  {{"REVAPPEND", CL_ORDINARY, mk_cl_revappend, 2, MKCL_OBJNULL}},
  {{"REVERSE", CL_ORDINARY, mk_cl_reverse, 1, MKCL_OBJNULL}},
  {{"ROOM", CL_ORDINARY, NULL, -1, MKCL_OBJNULL}},
  {{"ROTATEF", CL_ORDINARY, NULL, -1, MKCL_OBJNULL}},
  {{"ROUND", CL_ORDINARY, mk_cl_round, -1, MKCL_OBJNULL}},
  {{"ROW-MAJOR-AREF", CL_ORDINARY, mk_cl_row_major_aref, 2, MKCL_OBJNULL}},
  {{"RPLACA", CL_ORDINARY, mk_cl_rplaca, 2, MKCL_OBJNULL}},
  {{"RPLACD", CL_ORDINARY, mk_cl_rplacd, 2, MKCL_OBJNULL}},
  {{"SAFETY", CL_ORDINARY, NULL, -1, MKCL_OBJNULL}},
  {{"SATISFIES", CL_ORDINARY, NULL, -1, MKCL_OBJNULL}},
  {{"SBIT", CL_ORDINARY, MKCL_IN_LISP(mk_cl_sbit), -1, MKCL_OBJNULL}},
  {{"SCALE-FLOAT", CL_ORDINARY, mk_cl_scale_float, 2, MKCL_OBJNULL}},
  {{"SCHAR", CL_ORDINARY, mk_cl_char, 2, MKCL_OBJNULL}},
  {{"SEARCH", CL_ORDINARY, MKCL_IN_LISP(mk_cl_search), -1, MKCL_OBJNULL}},
  {{"SECOND", CL_ORDINARY, mk_cl_cadr, 1, MKCL_OBJNULL}},
  {{"SEQUENCE", CL_ORDINARY, NULL, -1, MKCL_OBJNULL}},
  {{"SERIOUS-CONDITION", CL_ORDINARY, NULL, -1, MKCL_OBJNULL}},
  {{"SET", CL_ORDINARY, mk_cl_set, 2, MKCL_OBJNULL}},
  {{"SET-DIFFERENCE", CL_ORDINARY, MKCL_IN_LISP(mk_cl_set_difference), -1, MKCL_OBJNULL}},
  {{"SET-DISPATCH-MACRO-CHARACTER", CL_ORDINARY, mk_cl_set_dispatch_macro_character, -1, MKCL_OBJNULL}},
  {{"SET-EXCLUSIVE-OR", CL_ORDINARY, MKCL_IN_LISP(mk_cl_set_exclusive_or), -1, MKCL_OBJNULL}},
  {{"SET-MACRO-CHARACTER", CL_ORDINARY, mk_cl_set_macro_character, -1, MKCL_OBJNULL}},
  {{"SET-PPRINT-DISPATCH", CL_ORDINARY, MKCL_NAME_PPRINT(mk_cl_set_pprint_dispatch), -1, MKCL_OBJNULL}},
  {{"SET-SYNTAX-FROM-CHAR", CL_ORDINARY, mk_cl_set_syntax_from_char, -1, MKCL_OBJNULL}},
  {{"SETF", CL_ORDINARY, NULL, -1, MKCL_OBJNULL}},
  {{"SETQ", CL_FORM, NULL, -1, MKCL_OBJNULL}},
  {{"SEVENTH", CL_ORDINARY, mk_cl_seventh, 1, MKCL_OBJNULL}},
  {{"SHADOW", CL_ORDINARY, mk_cl_shadow, -1, MKCL_OBJNULL}},
  {{"SHADOWING-IMPORT", CL_ORDINARY, mk_cl_shadowing_import, -1, MKCL_OBJNULL}},
  {{"SHIFTF", CL_ORDINARY, NULL, -1, MKCL_OBJNULL}},
  {{"SHORT-FLOAT", CL_ORDINARY, NULL, -1, MKCL_OBJNULL}},
  {{"SHORT-FLOAT-EPSILON", CL_CONSTANT, NULL, -1, MKCL_OBJNULL}},
  {{"SHORT-FLOAT-NEGATIVE-EPSILON", CL_CONSTANT, NULL, -1, MKCL_OBJNULL}},
  {{"SHORT-SITE-NAME", CL_ORDINARY, NULL, -1, MKCL_OBJNULL}},
  {{"SIGNAL", CL_ORDINARY, NULL, -1, MKCL_OBJNULL}},
  {{"SIGNED-BYTE", CL_ORDINARY, NULL, -1, MKCL_OBJNULL}},
  {{"SIGNUM", CL_ORDINARY, MKCL_IN_LISP(mk_cl_signum), -1, MKCL_OBJNULL}},
  {{"SIMPLE-ARRAY", CL_ORDINARY, NULL, -1, MKCL_OBJNULL}},
  {{"SIMPLE-BASE-STRING", CL_ORDINARY, NULL, -1, MKCL_OBJNULL}},
  {{"SIMPLE-BIT-VECTOR", CL_ORDINARY, NULL, -1, MKCL_OBJNULL}},
  {{"SIMPLE-BIT-VECTOR-P", CL_ORDINARY, mk_cl_simple_bit_vector_p, 1, MKCL_OBJNULL}},
  {{"SIMPLE-CONDITION", CL_ORDINARY, NULL, -1, MKCL_OBJNULL}},
  {{"SIMPLE-CONDITION-FORMAT-CONTROL", CL_ORDINARY, NULL, -1, MKCL_OBJNULL}},
  {{"SIMPLE-CONDITION-FORMAT-ARGUMENTS", CL_ORDINARY, NULL, -1, MKCL_OBJNULL}},
  {{"SIMPLE-ERROR", CL_ORDINARY, NULL, -1, MKCL_OBJNULL}},
  {{"SIMPLE-STRING", CL_ORDINARY, NULL, -1, MKCL_OBJNULL}},
  {{"SIMPLE-STRING-P", CL_ORDINARY, mk_cl_simple_string_p, 1, MKCL_OBJNULL}},
  {{"SIMPLE-TYPE-ERROR", CL_ORDINARY, NULL, -1, MKCL_OBJNULL}},
  {{"SIMPLE-VECTOR", CL_ORDINARY, NULL, -1, MKCL_OBJNULL}},
  {{"SIMPLE-VECTOR-P", CL_ORDINARY, mk_cl_simple_vector_p, 1, MKCL_OBJNULL}},
  {{"SIMPLE-WARNING", CL_ORDINARY, NULL, -1, MKCL_OBJNULL}},
  {{"SIN", CL_ORDINARY, mk_cl_sin, 1, MKCL_OBJNULL}},
  {{"SINGLE-FLOAT", CL_ORDINARY, NULL, -1, MKCL_OBJNULL}},
  {{"SINGLE-FLOAT-EPSILON", CL_CONSTANT, NULL, -1, MKCL_OBJNULL}},
  {{"SINGLE-FLOAT-NEGATIVE-EPSILON", CL_CONSTANT, NULL, -1, MKCL_OBJNULL}},
  {{"SINH", CL_ORDINARY, mk_cl_sinh, 1, MKCL_OBJNULL}},
  {{"SIXTH", CL_ORDINARY, mk_cl_sixth, 1, MKCL_OBJNULL}},
  {{"SLEEP", CL_ORDINARY, mk_cl_sleep, 1, MKCL_OBJNULL}},
  {{"SOFTWARE-TYPE", CL_ORDINARY, NULL, -1, MKCL_OBJNULL}},
  {{"SOFTWARE-VERSION", CL_ORDINARY, NULL, -1, MKCL_OBJNULL}},
  {{"SOME", CL_ORDINARY, MKCL_IN_LISP(mk_cl_some), -1, MKCL_OBJNULL}},
  {{"SORT", CL_ORDINARY, MKCL_IN_LISP(mk_cl_sort), -1, MKCL_OBJNULL}},
  {{"SPACE", CL_ORDINARY, NULL, -1, MKCL_OBJNULL}},
  {{"SPECIAL", CL_ORDINARY, NULL, -1, MKCL_OBJNULL}},
  {{"SPECIAL-OPERATOR-P", CL_ORDINARY, mk_cl_special_operator_p, 1, MKCL_OBJNULL}},
  {{"SPEED", CL_ORDINARY, NULL, -1, MKCL_OBJNULL}},
  {{"SQRT", CL_ORDINARY, mk_cl_sqrt, 1, MKCL_OBJNULL}},
  {{"STABLE-SORT", CL_ORDINARY, MKCL_IN_LISP(mk_cl_stable_sort), -1, MKCL_OBJNULL}},
  {{"STANDARD-CHAR", CL_ORDINARY, NULL, -1, MKCL_OBJNULL}},
  {{"STANDARD-CHAR-P", CL_ORDINARY, mk_cl_standard_char_p, 1, MKCL_OBJNULL}},
  {{"STEP", CL_ORDINARY, NULL, -1, MKCL_OBJNULL}},
  {{"STORAGE-CONDITION", CL_ORDINARY, NULL, -1, MKCL_OBJNULL}},
  {{"STORE-VALUE", CL_ORDINARY, NULL, -1, MKCL_OBJNULL}},
  {{"STREAM", CL_ORDINARY, NULL, -1, MKCL_OBJNULL}},
  {{"STREAM-ELEMENT-TYPE", CL_ORDINARY, mk_cl_stream_element_type, 1, MKCL_OBJNULL}},
  {{"STREAM-ERROR", CL_ORDINARY, NULL, -1, MKCL_OBJNULL}},
  {{"STREAM-ERROR-STREAM", CL_ORDINARY, NULL, -1, MKCL_OBJNULL}},
  {{"STREAM-EXTERNAL-FORMAT", CL_ORDINARY, mk_cl_stream_external_format, 1, MKCL_OBJNULL}},
  {{"STREAMP", CL_ORDINARY, mk_cl_streamp, 1, MKCL_OBJNULL}},
  {{"STRING", CL_ORDINARY, mk_cl_string, 1, MKCL_OBJNULL}},
  {{"STRING-DOWNCASE", CL_ORDINARY, mk_cl_string_downcase, -1, MKCL_OBJNULL}},
  {{"STRING-CAPITALIZE", CL_ORDINARY, mk_cl_string_capitalize, -1, MKCL_OBJNULL}},
  {{"STRING-EQUAL", CL_ORDINARY, mk_cl_string_equal, -1, MKCL_OBJNULL}},
  {{"STRING-GREATERP", CL_ORDINARY, mk_cl_string_greaterp, -1, MKCL_OBJNULL}},
  {{"STRING-LEFT-TRIM", CL_ORDINARY, mk_cl_string_left_trim, 2, MKCL_OBJNULL}},
  {{"STRING-LESSP", CL_ORDINARY, mk_cl_string_lessp, -1, MKCL_OBJNULL}},
  {{"STRING-NOT-EQUAL", CL_ORDINARY, mk_cl_string_not_equal, -1, MKCL_OBJNULL}},
  {{"STRING-NOT-GREATERP", CL_ORDINARY, mk_cl_string_not_greaterp, -1, MKCL_OBJNULL}},
  {{"STRING-NOT-LESSP", CL_ORDINARY, mk_cl_string_not_lessp, -1, MKCL_OBJNULL}},
  {{"STRING-RIGHT-TRIM", CL_ORDINARY, mk_cl_string_right_trim, 2, MKCL_OBJNULL}},
  {{"STRING-STREAM", CL_ORDINARY, NULL, -1, MKCL_OBJNULL}},
  {{"STRING-TRIM", CL_ORDINARY, mk_cl_string_trim, 2, MKCL_OBJNULL}},
  {{"STRING-UPCASE", CL_ORDINARY, mk_cl_string_upcase, -1, MKCL_OBJNULL}},
  {{"STRING/=", CL_ORDINARY, mk_cl_stringNE, -1, MKCL_OBJNULL}},
  {{"STRING<", CL_ORDINARY, mk_cl_stringL, -1, MKCL_OBJNULL}},
  {{"STRING<=", CL_ORDINARY, mk_cl_stringLE, -1, MKCL_OBJNULL}},
  {{"STRING=", CL_ORDINARY, mk_cl_stringE, -1, MKCL_OBJNULL}},
  {{"STRING>", CL_ORDINARY, mk_cl_stringG, -1, MKCL_OBJNULL}},
  {{"STRING>=", CL_ORDINARY, mk_cl_stringGE, -1, MKCL_OBJNULL}},
  {{"STRINGP", CL_ORDINARY, mk_cl_stringp, 1, MKCL_OBJNULL}},
  {{"STRUCTURE", CL_ORDINARY, NULL, -1, MKCL_OBJNULL}},
  {{"STYLE-WARNING", CL_ORDINARY, NULL, -1, MKCL_OBJNULL}},
  {{"SUBLIS", CL_ORDINARY, mk_cl_sublis, -1, MKCL_OBJNULL}},
  {{"SUBSEQ", CL_ORDINARY, mk_cl_subseq, -1, MKCL_OBJNULL}},
  {{"SUBSETP", CL_ORDINARY, MKCL_IN_LISP(mk_cl_subsetp), -1, MKCL_OBJNULL}},
  {{"SUBST", CL_ORDINARY, mk_cl_subst, -1, MKCL_OBJNULL}},
  {{"SUBST-IF", CL_ORDINARY, MKCL_IN_LISP(mk_cl_subst_if), -1, MKCL_OBJNULL}},
  {{"SUBST-IF-NOT", CL_ORDINARY, MKCL_IN_LISP(mk_cl_subst_if_not), -1, MKCL_OBJNULL}},
  {{"SUBSTITUTE", CL_ORDINARY, MKCL_IN_LISP(mk_cl_substitute), -1, MKCL_OBJNULL}},
  {{"SUBSTITUTE-IF", CL_ORDINARY, MKCL_IN_LISP(mk_cl_substitute_if), -1, MKCL_OBJNULL}},
  {{"SUBSTITUTE-IF-NOT", CL_ORDINARY, MKCL_IN_LISP(mk_cl_substitute_if_not), -1, MKCL_OBJNULL}},
  {{"SUBTYPEP", CL_ORDINARY, MKCL_IN_LISP(mk_cl_subtypep), -1, MKCL_OBJNULL}},
  {{"SVREF", CL_ORDINARY, mk_cl_svref, 2, MKCL_OBJNULL}},
  {{"SXHASH", CL_ORDINARY, mk_cl_sxhash, 1, MKCL_OBJNULL}},
  {{"SYMBOL", CL_ORDINARY, NULL, -1, MKCL_OBJNULL}},
  {{"SYMBOL-FUNCTION", CL_ORDINARY, mk_cl_symbol_function, 1, MKCL_OBJNULL}},
  {{"SYMBOL-MACROLET", CL_FORM, NULL, -1, MKCL_OBJNULL}},
  {{"SYMBOL-NAME", CL_ORDINARY, mk_cl_symbol_name, 1, MKCL_OBJNULL}},
  {{"SYMBOL-PACKAGE", CL_ORDINARY, mk_cl_symbol_package, 1, MKCL_OBJNULL}},
  {{"SYMBOL-PLIST", CL_ORDINARY, mk_cl_symbol_plist, 1, MKCL_OBJNULL}},
  {{"SYMBOL-VALUE", CL_ORDINARY, mk_cl_symbol_value, 1, MKCL_OBJNULL}},
  {{"SYMBOLP", CL_ORDINARY, mk_cl_symbolp, 1, MKCL_OBJNULL}},
  {{"SYNONYM-STREAM", CL_ORDINARY, NULL, -1, MKCL_OBJNULL}},
  {{"SYNONYM-STREAM-SYMBOL", CL_ORDINARY, mk_cl_synonym_stream_symbol, 1, MKCL_OBJNULL}},
  {{"TAGBODY", CL_FORM, NULL, -1, MKCL_OBJNULL}},
  {{"TAILP", CL_ORDINARY, mk_cl_tailp, 2, MKCL_OBJNULL}},
  {{"TAN", CL_ORDINARY, mk_cl_tan, 1, MKCL_OBJNULL}},
  {{"TANH", CL_ORDINARY, mk_cl_tanh, 1, MKCL_OBJNULL}},
  {{"TENTH", CL_ORDINARY, mk_cl_tenth, 1, MKCL_OBJNULL}},
  {{"TERPRI", CL_ORDINARY, mk_cl_terpri, -1, MKCL_OBJNULL}},
  {{"THE", CL_FORM, NULL, -1, MKCL_OBJNULL}},
  {{"THIRD", CL_ORDINARY, mk_cl_caddr, 1, MKCL_OBJNULL}},
  {{"THROW", CL_FORM, NULL, -1, MKCL_OBJNULL}},
  {{"TIME", CL_ORDINARY, NULL, -1, MKCL_OBJNULL}},
  {{"TRACE", CL_ORDINARY, NULL, -1, MKCL_OBJNULL}},
  {{"TRANSLATE-LOGICAL-PATHNAME", CL_ORDINARY, mk_cl_translate_logical_pathname, -1, MKCL_OBJNULL}},
  {{"TRANSLATE-PATHNAME", CL_ORDINARY, mk_cl_translate_pathname, -1, MKCL_OBJNULL}},
  {{"TREE-EQUAL", CL_ORDINARY, mk_cl_tree_equal, -1, MKCL_OBJNULL}},
  {{"TRUENAME", CL_ORDINARY, mk_cl_truename, 1, MKCL_OBJNULL}},
  {{"TRUNCATE", CL_ORDINARY, mk_cl_truncate, -1, MKCL_OBJNULL}},
  {{"TWO-WAY-STREAM", CL_ORDINARY, NULL, -1, MKCL_OBJNULL}},
  {{"TWO-WAY-STREAM-INPUT-STREAM", CL_ORDINARY, mk_cl_two_way_stream_input_stream, 1, MKCL_OBJNULL}},
  {{"TWO-WAY-STREAM-OUTPUT-STREAM", CL_ORDINARY, mk_cl_two_way_stream_output_stream, 1, MKCL_OBJNULL}},
  {{"TYPE", CL_ORDINARY, NULL, -1, MKCL_OBJNULL}},
  {{"TYPE-ERROR", CL_ORDINARY, NULL, -1, MKCL_OBJNULL}},
  {{"TYPE-ERROR-DATUM", CL_ORDINARY, NULL, -1, MKCL_OBJNULL}},
  {{"TYPE-ERROR-EXPECTED-TYPE", CL_ORDINARY, NULL, -1, MKCL_OBJNULL}},
  {{"TYPE-OF", CL_ORDINARY, mk_cl_type_of, 1, MKCL_OBJNULL}},
  {{"TYPECASE", CL_ORDINARY, NULL, -1, MKCL_OBJNULL}},
  {{"TYPEP", CL_ORDINARY, MKCL_IN_LISP(mk_cl_typep), -1, MKCL_OBJNULL}},
  {{"UNBOUND-SLOT", CL_ORDINARY, NULL, -1, MKCL_OBJNULL}},
  {{"UNBOUND-SLOT-INSTANCE", CL_ORDINARY, NULL, -1, MKCL_OBJNULL}},
  {{"UNBOUND-VARIABLE", CL_ORDINARY, NULL, -1, MKCL_OBJNULL}},
  {{"UNDEFINED-FUNCTION", CL_ORDINARY, NULL, -1, MKCL_OBJNULL}},
  {{"UNEXPORT", CL_ORDINARY, mk_cl_unexport, -1, MKCL_OBJNULL}},
  {{"UNINTERN", CL_ORDINARY, mk_cl_unintern, -1, MKCL_OBJNULL}},
  {{"UNION", CL_ORDINARY, MKCL_IN_LISP(mk_cl_union), -1, MKCL_OBJNULL}},
  {{"UNLESS", CL_FORM, NULL, -1, MKCL_OBJNULL}},
  {{"UNREAD-CHAR", CL_ORDINARY, mk_cl_unread_char, -1, MKCL_OBJNULL}},
  {{"UNSIGNED-BYTE", CL_ORDINARY, NULL, -1, MKCL_OBJNULL}},
  {{"UNTRACE", CL_ORDINARY, NULL, -1, MKCL_OBJNULL}},
  {{"UNUSE-PACKAGE", CL_ORDINARY, mk_cl_unuse_package, -1, MKCL_OBJNULL}},
  {{"UNWIND-PROTECT", CL_FORM, NULL, -1, MKCL_OBJNULL}},
  {{"UPGRADED-ARRAY-ELEMENT-TYPE", CL_ORDINARY, MKCL_IN_LISP(mk_cl_upgraded_array_element_type), -1, MKCL_OBJNULL}},
  {{"UPGRADED-COMPLEX-PART-TYPE", CL_ORDINARY, MKCL_IN_LISP(mk_cl_upgraded_complex_part_type), -1, MKCL_OBJNULL}},
  {{"UPPER-CASE-P", CL_ORDINARY, mk_cl_upper_case_p, 1, MKCL_OBJNULL}},
  {{"USE-PACKAGE", CL_ORDINARY, mk_cl_use_package, -1, MKCL_OBJNULL}},
  {{"USE-VALUE", CL_ORDINARY, NULL, -1, MKCL_OBJNULL}},
  {{"USER-HOMEDIR-PATHNAME", CL_ORDINARY, mk_cl_user_homedir_pathname, -1, MKCL_OBJNULL}},
  {{"VALUES", CL_ORDINARY, mk_cl_values, -1, MKCL_OBJNULL}},
  {{"VALUES-LIST", CL_ORDINARY, mk_cl_values_list, 1, MKCL_OBJNULL}},
  {{"VARIABLE", CL_ORDINARY, NULL, -1, MKCL_OBJNULL}},
  {{"VECTOR", CL_ORDINARY, MKCL_IN_LISP(mk_cl_vector), -1, MKCL_OBJNULL}},
  {{"VECTOR-POP", CL_ORDINARY, MKCL_IN_LISP(mk_cl_vector_pop), 1, MKCL_OBJNULL}},
  {{"VECTOR-PUSH", CL_ORDINARY, MKCL_IN_LISP(mk_cl_vector_push), 2, MKCL_OBJNULL}},
  {{"VECTOR-PUSH-EXTEND", CL_ORDINARY, MKCL_IN_LISP(mk_cl_vector_push_extend), -1, MKCL_OBJNULL}},
  {{"VECTORP", CL_ORDINARY, mk_cl_vectorp, 1, MKCL_OBJNULL}},
  {{"WARN", CL_ORDINARY, NULL, -1, MKCL_OBJNULL}},
  {{"WARNING", CL_ORDINARY, NULL, -1, MKCL_OBJNULL}},
  {{"WHEN", CL_FORM, NULL, -1, MKCL_OBJNULL}},
  {{"WILD-PATHNAME-P", CL_ORDINARY, mk_cl_wild_pathname_p, -1, MKCL_OBJNULL}},
  {{"WITH-COMPILATION-UNIT", CL_ORDINARY, NULL, -1, MKCL_OBJNULL}},
  {{"WITH-CONDITION-RESTARTS", CL_ORDINARY, NULL, -1, MKCL_OBJNULL}},
  {{"WITH-HASH-TABLE-ITERATOR", CL_ORDINARY, NULL, -1, MKCL_OBJNULL}},
  {{"WITH-INPUT-FROM-STRING", CL_ORDINARY, NULL, -1, MKCL_OBJNULL}},
  {{"WITH-OPEN-FILE", CL_ORDINARY, NULL, -1, MKCL_OBJNULL}},
  {{"WITH-OPEN-STREAM", CL_ORDINARY, NULL, -1, MKCL_OBJNULL}},
  {{"WITH-OUTPUT-TO-STRING", CL_ORDINARY, NULL, -1, MKCL_OBJNULL}},
  {{"WITH-PACKAGE-ITERATOR", CL_ORDINARY, NULL, -1, MKCL_OBJNULL}},
  {{"WITH-SIMPLE-RESTART", CL_ORDINARY, NULL, -1, MKCL_OBJNULL}},
  {{"WITH-STANDARD-IO-SYNTAX", CL_ORDINARY, NULL, -1, MKCL_OBJNULL}},
  {{"WRITE", CL_ORDINARY, mk_cl_write, -1, MKCL_OBJNULL}},
  {{"WRITE-BYTE", CL_ORDINARY, mk_cl_write_byte, 2, MKCL_OBJNULL}},
  {{"WRITE-CHAR", CL_ORDINARY, mk_cl_write_char, -1, MKCL_OBJNULL}},
  {{"WRITE-LINE", CL_ORDINARY, mk_cl_write_line, -1, MKCL_OBJNULL}},
  {{"WRITE-SEQUENCE", CL_ORDINARY, mk_cl_write_sequence, -1, MKCL_OBJNULL}},
  {{"WRITE-STRING", CL_ORDINARY, mk_cl_write_string, -1, MKCL_OBJNULL}},
  {{"WRITE-TO-STRING", CL_ORDINARY, MKCL_IN_LISP(mk_cl_write_to_string), -1, MKCL_OBJNULL}},
  {{"Y-OR-N-P", CL_ORDINARY, MKCL_IN_LISP(mk_cl_y_or_n_p), -1, MKCL_OBJNULL}},
  {{"YES-OR-NO-P", CL_ORDINARY, MKCL_IN_LISP(mk_cl_yes_or_no_p), -1, MKCL_OBJNULL}},
  {{"ZEROP", CL_ORDINARY, mk_cl_zerop, 1, MKCL_OBJNULL}},

  {{"ALLOCATE-INSTANCE", CL_ORDINARY, NULL, 2, MKCL_OBJNULL}},
  {{"ADD-METHOD", CL_ORDINARY, NULL, -1, MKCL_OBJNULL}},
  {{"BUILT-IN-CLASS", CL_ORDINARY, NULL, -1, MKCL_OBJNULL}},
  {{"CALL-METHOD", CL_ORDINARY, NULL, -1, MKCL_OBJNULL}},
  {{"CALL-NEXT-METHOD", CL_ORDINARY, NULL, -1, MKCL_OBJNULL}},
  {{"CHANGE-CLASS", CL_ORDINARY, NULL, -1, MKCL_OBJNULL}},
  {{"CLASS", CL_ORDINARY, NULL, -1, MKCL_OBJNULL}},
  {{"CLASS-NAME", CL_ORDINARY, NULL, -1, MKCL_OBJNULL}},
  {{"CLASS-OF", CL_ORDINARY, mk_cl_class_of, 1, MKCL_OBJNULL}},
  {{"COMPUTE-APPLICABLE-METHODS", CL_ORDINARY, NULL, -1, MKCL_OBJNULL}},
  {{"DEFCLASS", CL_ORDINARY, NULL, -1, MKCL_OBJNULL}},
  {{"DEFGENERIC", CL_ORDINARY, NULL, -1, MKCL_OBJNULL}},
  {{"DEFINE-METHOD-COMBINATION", CL_ORDINARY, NULL, -1, MKCL_OBJNULL}},
  {{"DEFMETHOD", CL_ORDINARY, NULL, -1, MKCL_OBJNULL}},
  {{"DESCRIBE-OBJECT", CL_ORDINARY, NULL, -1, MKCL_OBJNULL}},
  {{"ENSURE-GENERIC-FUNCTION", CL_ORDINARY, NULL, -1, MKCL_OBJNULL}},
  {{"FIND-CLASS", CL_ORDINARY, mk_cl_find_class, -1, MKCL_OBJNULL}},
  {{"FIND-METHOD", CL_ORDINARY, NULL, -1, MKCL_OBJNULL}},
  {{"GENERIC-FUNCTION", CL_ORDINARY, NULL, -1, MKCL_OBJNULL}},
  {{"IF", CL_FORM, NULL, -1, MKCL_OBJNULL}},
  {{"INITIALIZE-INSTANCE", CL_ORDINARY, NULL, -1, MKCL_OBJNULL}},
  {{"INVALID-METHOD-ERROR", CL_ORDINARY, MKCL_IN_LISP(mk_cl_invalid_method_error), -1, MKCL_OBJNULL}},
  {{"MAKE-INSTANCE", CL_ORDINARY, NULL, -1, MKCL_OBJNULL}},
  {{"MAKE-INSTANCES-OBSOLETE", CL_ORDINARY, NULL, -1, MKCL_OBJNULL}},
  {{"MAKE-LOAD-FORM", CL_ORDINARY, NULL, -1, MKCL_OBJNULL}},
  {{"MAKE-LOAD-FORM-SAVING-SLOTS", CL_ORDINARY, NULL, -1, MKCL_OBJNULL}},
  {{"MAKE-METHOD", CL_ORDINARY, NULL, -1, MKCL_OBJNULL}},
  {{"METHOD", CL_ORDINARY, NULL, -1, MKCL_OBJNULL}},
  {{"METHOD-COMBINATION-ERROR", CL_ORDINARY, MKCL_IN_LISP(mk_cl_method_combination_error), -1, MKCL_OBJNULL}},
  {{"METHOD-COMBINATION", CL_ORDINARY, NULL, -1, MKCL_OBJNULL}},
  {{"METHOD-QUALIFIERS", CL_ORDINARY, NULL, -1, MKCL_OBJNULL}},
  {{"NEXT-METHOD-P", CL_ORDINARY, NULL, -1, MKCL_OBJNULL}},
  {{"NO-APPLICABLE-METHOD", CL_ORDINARY, NULL, -1, MKCL_OBJNULL}},
  {{"NO-NEXT-METHOD", CL_ORDINARY, NULL, -1, MKCL_OBJNULL}},
  {{"PRINT-OBJECT", CL_ORDINARY, NULL, -1, MKCL_OBJNULL}},
  {{"PRINT-UNREADABLE-OBJECT", CL_ORDINARY, NULL, -1, MKCL_OBJNULL}},
  {{"REINITIALIZE-INSTANCE", CL_ORDINARY, NULL, -1, MKCL_OBJNULL}},
  {{"REMOVE-METHOD", CL_ORDINARY, NULL, -1, MKCL_OBJNULL}},
  {{"SHARED-INITIALIZE", CL_ORDINARY, NULL, -1, MKCL_OBJNULL}},
  {{"SLOT-BOUNDP", CL_ORDINARY, NULL, -1, MKCL_OBJNULL}},
  {{"SLOT-EXISTS-P", CL_ORDINARY, NULL, -1, MKCL_OBJNULL}},
  {{"SLOT-MAKUNBOUND", CL_ORDINARY, NULL, -1, MKCL_OBJNULL}},
  {{"SLOT-MISSING", CL_ORDINARY, NULL, -1, MKCL_OBJNULL}},
  {{"SLOT-UNBOUND", CL_ORDINARY, NULL, -1, MKCL_OBJNULL}},
  {{"SLOT-VALUE", CL_ORDINARY, NULL, -1, MKCL_OBJNULL}},
  {{"STANDARD", CL_ORDINARY, NULL, -1, MKCL_OBJNULL}},
  {{"STANDARD-CLASS", CL_ORDINARY, NULL, -1, MKCL_OBJNULL}},
  {{"STANDARD-GENERIC-FUNCTION", CL_ORDINARY, NULL, -1, MKCL_OBJNULL}},
  {{"STANDARD-METHOD", CL_ORDINARY, NULL, -1, MKCL_OBJNULL}},
  {{"STANDARD-OBJECT", CL_ORDINARY, NULL, -1, MKCL_OBJNULL}},
  {{"STRUCTURE-CLASS", CL_ORDINARY, NULL, -1, MKCL_OBJNULL}},
  {{"STRUCTURE-OBJECT", CL_ORDINARY, NULL, -1, MKCL_OBJNULL}},
  {{"UPDATE-INSTANCE-FOR-DIFFERENT-CLASS", CL_ORDINARY, NULL, -1, MKCL_OBJNULL}},
  {{"UPDATE-INSTANCE-FOR-REDEFINED-CLASS", CL_ORDINARY, NULL, -1, MKCL_OBJNULL}},
  {{"WITH-ACCESSORS", CL_ORDINARY, NULL, -1, MKCL_OBJNULL}},
  {{"WITH-SLOTS", CL_ORDINARY, NULL, -1, MKCL_OBJNULL}},
  {{KEY_ "ARGUMENT-PRECEDENCE-ORDER", KEYWORD, NULL, -1, MKCL_OBJNULL}},
  {{KEY_ "DECLARE", KEYWORD, NULL, -1, MKCL_OBJNULL}},
  {{KEY_ "DEFAULT-INITARGS", KEYWORD, NULL, -1, MKCL_OBJNULL}},
  {{KEY_ "DIRECT-DEFAULT-INITARGS", KEYWORD, NULL, -1, MKCL_OBJNULL}},
  {{KEY_ "DIRECT-SLOTS", KEYWORD, NULL, -1, MKCL_OBJNULL}},
  {{KEY_ "DIRECT-SUPERCLASSES", KEYWORD, NULL, -1, MKCL_OBJNULL}},
  {{KEY_ "GENERIC-FUNCTION-CLASS", KEYWORD, NULL, -1, MKCL_OBJNULL}},
  {{KEY_ "LAMBDA-LIST", KEYWORD, NULL, -1, MKCL_OBJNULL}},
  {{KEY_ "METHOD-CLASS", KEYWORD, NULL, -1, MKCL_OBJNULL}},
  {{KEY_ "METHOD-COMBINATION", KEYWORD, NULL, -1, MKCL_OBJNULL}},

  /* SYSTEM PACKAGE */
  {{SYS_ "#!", SI_ORDINARY, NULL, -1, MKCL_OBJNULL}},
  {{SYS_ "*BACKQ-LEVEL*", SI_SPECIAL, NULL, -1, MKCL_MAKE_FIXNUM(0)}},
  {{SYS_ "*CBLOCK*", SI_SPECIAL, NULL, -1, mk_cl_Cnil}},
  {{SYS_ "*CIRCLE-COUNTER*", SI_SPECIAL, NULL, -1, mk_cl_Cnil}},
  {{SYS_ "*CIRCLE-STACK*", SI_SPECIAL, NULL, -1, MKCL_OBJNULL}},
  {{SYS_ "*CLASS-NAME-HASH-TABLE*", SI_SPECIAL, NULL, -1, MKCL_OBJNULL}},
  {{SYS_ "*COMPILER-CONSTANTS*", SI_SPECIAL, NULL, -1, MKCL_OBJNULL}}, /* Added back for use by #'compile. JCB */
  {{SYS_ "*GC-MESSAGE*", SI_SPECIAL, NULL, -1, mk_cl_Cnil}},
  {{SYS_ "*GC-VERBOSE*", SI_SPECIAL, NULL, -1, mk_cl_Cnil}},
  {{SYS_ "*IGNORE-EOF-ON-TERMINAL-IO*", SI_SPECIAL, NULL, -1, mk_cl_Cnil}},
  {{SYS_ "*INDENT-FORMATTED-OUTPUT*", SI_SPECIAL, NULL, -1, mk_cl_Cnil}},
  {{SYS_ "*INIT-FUNCTION-PREFIX*", SI_SPECIAL, NULL, -1, mk_cl_Cnil}},
  {{SYS_ "*KEEP-DEFINITIONS*", SI_SPECIAL, NULL, -1, mk_cl_Ct}},
  {{SYS_ "*LOAD-HOOKS*", SI_SPECIAL, NULL, -1, MKCL_OBJNULL}},
  {{SYS_ "*LOAD-SEARCH-LIST*", SI_SPECIAL, NULL, -1, mk_cl_Cnil}},
  {{SYS_ "*MAKE-CONSTANT", SI_ORDINARY, mk_si_Xmake_constant, 2, MKCL_OBJNULL}},
  {{SYS_ "*MAKE-SPECIAL", SI_ORDINARY, mk_si_Xmake_special, 1, MKCL_OBJNULL}},
  {{SYS_ "*PRINT-PACKAGE*", SI_SPECIAL, NULL, -1, mk_cl_Cnil}},
  {{SYS_ "*PRINT-STRUCTURE*", SI_SPECIAL, NULL, -1, mk_cl_Cnil}},
  {{SYS_ "*SHARP-EQ-CONTEXT*", SI_SPECIAL, NULL, -1, mk_cl_Cnil}},
  {{SYS_ "*STEP-LEVEL*", SI_SPECIAL, NULL, -1, MKCL_MAKE_FIXNUM(0)}},
  {{SYS_ "*STEP-ACTION*", SI_SPECIAL, NULL, -1, mk_cl_Cnil}},
  {{SYS_ "+READING-FASL-FILE+", SI_SPECIAL, NULL, -1, mk_cl_Cnil}},
  {{SYS_ ".", SI_ORDINARY, NULL, -1, MKCL_OBJNULL}},
  {{SYS_ "UNQUOTE", SI_ORDINARY, NULL, -1, MKCL_OBJNULL}},
  {{SYS_ "UNQUOTE-NSPLICE", SI_ORDINARY, NULL, -1, MKCL_OBJNULL}},
  {{SYS_ "UNQUOTE-SPLICE", SI_ORDINARY, NULL, -1, MKCL_OBJNULL}},
  {{SYS_ "ALLOCATE-RAW-INSTANCE", SI_ORDINARY, mk_si_allocate_raw_instance, 3, MKCL_OBJNULL}},
  {{SYS_ "ARGC", SI_ORDINARY, mk_si_argc, 0, MKCL_OBJNULL}},
  {{SYS_ "ARGV", SI_ORDINARY, mk_si_argv, 1, MKCL_OBJNULL}},
  {{SYS_ "ASET", SI_ORDINARY, mk_si_aset, -1, MKCL_OBJNULL}},
  {{SYS_ "BASE-CHAR-P", SI_ORDINARY, mk_mkcl_base_char_p, 1, MKCL_OBJNULL}},
  {{SYS_ "BASE-STRING-P", SI_ORDINARY, mk_si_base_string_p, 1, MKCL_OBJNULL}},
  {{SYS_ "BC-DISASSEMBLE", SI_ORDINARY, mk_si_bc_disassemble, 1, MKCL_OBJNULL}},
  {{SYS_ "BC-SPLIT", SI_ORDINARY, mk_si_bc_split, 1, MKCL_OBJNULL}},
  {{SYS_ "BDS-TOP", SI_ORDINARY, mk_si_bds_top, 0, MKCL_OBJNULL}},
  {{SYS_ "BDS-VAL", SI_ORDINARY, mk_si_bds_val, 1, MKCL_OBJNULL}},
  {{SYS_ "BDS-VAR", SI_ORDINARY, mk_si_bds_var, 1, MKCL_OBJNULL}},
  {{SYS_ "BIT-ARRAY-OP", SI_ORDINARY, mk_si_bit_array_op, 4, MKCL_OBJNULL}},
  {{SYS_ "C-ARGUMENTS-LIMIT", SI_CONSTANT, NULL, -1, MKCL_MAKE_FIXNUM(MKCL_C_ARGUMENTS_LIMIT)}},
  {{SYS_ "CHAR-SET", SI_ORDINARY, mk_si_char_set, 3, MKCL_OBJNULL}},
  {{MKCL_EXT_ "CHDIR", MKCL_EXT_ORDINARY, mk_mkcl_chdir, -1, MKCL_OBJNULL}},
  {{SYS_ "CLEAR-COMPILER-PROPERTIES", SI_ORDINARY, mk_cl_identity, 1, MKCL_OBJNULL}},
  {{SYS_ "COERCE-TO-BASE-STRING", SI_ORDINARY, mk_si_coerce_to_base_string, 1, MKCL_OBJNULL}},
  {{SYS_ "COERCE-TO-EXTENDED-STRING", SI_ORDINARY, mk_si_coerce_to_extended_string, 1, MKCL_OBJNULL}},
  {{SYS_ "COERCE-TO-FILENAME", SI_ORDINARY, mk_si_coerce_to_filename, 1, MKCL_OBJNULL}},
  {{SYS_ "COERCE-TO-FUNCTION", SI_ORDINARY, mk_si_coerce_to_function, 1, MKCL_OBJNULL}},
  {{SYS_ "COERCE-TO-PACKAGE", SI_ORDINARY, mk_si_coerce_to_package, 1, MKCL_OBJNULL}},
  {{SYS_ "COPY-TO-SIMPLE-BASE-STRING", SI_ORDINARY, mk_si_copy_to_simple_base_string, 1, MKCL_OBJNULL}},
  {{SYS_ "COMPILED-FUNCTION-BLOCK", SI_ORDINARY, mk_si_compiled_function_block, 1, MKCL_OBJNULL}},
  {{SYS_ "COMPILED-FUNCTION-NAME", SI_ORDINARY, mk_si_compiled_function_name, 1, MKCL_OBJNULL}},
  {{SYS_ "COPY-STREAM", SI_ORDINARY, mk_si_copy_stream, 1, MKCL_OBJNULL}},
  {{SYS_ "DO-READ-SEQUENCE", SI_ORDINARY, mk_si_do_read_sequence, 4, MKCL_OBJNULL}},
  {{SYS_ "DO-WRITE-SEQUENCE", SI_ORDINARY, mk_si_do_write_sequence, 4, MKCL_OBJNULL}},
  {{SYS_ "ELT-SET", SI_ORDINARY, mk_si_elt_set, 3, MKCL_OBJNULL}},
  {{SYS_ "EVAL-IN-ENV", SI_ORDINARY, mk_si_eval_in_env, -1, MKCL_OBJNULL}},
  {{SYS_ "EXPAND-DEFMACRO", SI_ORDINARY, NULL, -1, MKCL_OBJNULL}},
  {{SYS_ "FILE-COLUMN", SI_ORDINARY, mk_si_file_column, 1, MKCL_OBJNULL}},
  {{SYS_ "FILE-KIND", SI_ORDINARY, mk_si_file_kind, -1, MKCL_OBJNULL}},
  {{SYS_ "FILL-POINTER-SET", SI_ORDINARY, mk_si_fill_pointer_set, 2, MKCL_OBJNULL}},
  {{SYS_ "FIXNUMP", SI_ORDINARY, mk_si_fixnump, 1, MKCL_OBJNULL}},
  {{SYS_ "FORMAT-ERROR", SI_ORDINARY, NULL, -1, MKCL_OBJNULL}},
  {{SYS_ "FORMATTER-AUX", SI_ORDINARY, NULL, -1, MKCL_OBJNULL}},
  {{SYS_ "FRS-BDS", SI_ORDINARY, mk_si_frs_bds, 1, MKCL_OBJNULL}},
  {{SYS_ "FRS-IHS", SI_ORDINARY, mk_si_frs_ihs, 1, MKCL_OBJNULL}},
  {{SYS_ "FRS-TAG", SI_ORDINARY, mk_si_frs_tag, 1, MKCL_OBJNULL}},
  {{SYS_ "FRS-TOP", SI_ORDINARY, mk_si_frs_top, 0, MKCL_OBJNULL}},
  {{SYS_ "FSET", SI_ORDINARY, mk_si_fset, -1, MKCL_OBJNULL}},
  {{SYS_ "FUNCTION-BLOCK-NAME", SI_ORDINARY, mk_si_function_block_name, 1, MKCL_OBJNULL}},
  {{SYS_ "GET-SYS-LIBRARY-PATHNAME", SI_ORDINARY, mk_si_get_SYS_library_pathname, 0, MKCL_OBJNULL}},
  {{SYS_ "GET-SYSPROP", SI_ORDINARY, mk_si_get_sysprop, 2, MKCL_OBJNULL}},
  {{MKCL_EXT_ "GETENV", MKCL_EXT_ORDINARY, mk_mkcl_getenv, 1, MKCL_OBJNULL}},
  {{MKCL_EXT_ "GETCWD", MKCL_EXT_ORDINARY, mk_mkcl_getcwd, -1, MKCL_OBJNULL}},
  {{SYS_ "GETPID", SI_ORDINARY, mk_si_getpid, 0, MKCL_OBJNULL}},
  {{SYS_ "GETTID", SI_ORDINARY, mk_si_gettid, 0, MKCL_OBJNULL}},
  {{SYS_ "HASH-SET", SI_ORDINARY, mk_si_hash_set, 3, MKCL_OBJNULL}},
  {{SYS_ "HASH-TABLE-ITERATOR", SI_ORDINARY, mk_si_hash_table_iterator, 1, MKCL_OBJNULL}},
  {{SYS_ "IHS-BDS-MARKER", SI_ORDINARY, mk_si_ihs_bds_marker, 1, MKCL_OBJNULL}},
  {{SYS_ "IHS-ENV", SI_ORDINARY, mk_si_ihs_env, 1, MKCL_OBJNULL}},
  {{SYS_ "IHS-FUN", SI_ORDINARY, mk_si_ihs_fun, 1, MKCL_OBJNULL}},
  {{SYS_ "IHS-NEXT", SI_ORDINARY, mk_si_ihs_next, 1, MKCL_OBJNULL}},
  {{SYS_ "IHS-PREV", SI_ORDINARY, mk_si_ihs_prev, 1, MKCL_OBJNULL}},
  {{SYS_ "IHS-TOP", SI_ORDINARY, mk_si_ihs_top, 0, MKCL_OBJNULL}},
  {{SYS_ "INTERPRETER-STACK", SI_ORDINARY, mk_si_interpreter_stack, -1, MKCL_OBJNULL}},
  {{SYS_ "LINK-FROM", SI_ORDINARY, NULL, -1, MKCL_OBJNULL}},
  {{SYS_ "LINK-TO", SI_ORDINARY, NULL, -1, MKCL_OBJNULL}},
  {{SYS_ "LOAD-SOURCE", SI_ORDINARY, mk_si_load_source, 4, MKCL_OBJNULL}},
  {{SYS_ "LOGICAL-PATHNAME-P", SI_ORDINARY, mk_si_logical_pathname_p, 1, MKCL_OBJNULL}},
  {{SYS_ "MACRO", SI_ORDINARY, NULL, -1, MKCL_OBJNULL}},
  {{SYS_ "MAKE-LAMBDA", SI_ORDINARY, mk_si_make_lambda, 2, MKCL_OBJNULL}},
  {{SYS_ "MAKE-PURE-ARRAY", SI_ORDINARY, mk_si_make_pure_array, 6, MKCL_OBJNULL}},
  {{SYS_ "MAKE-STRING-OUTPUT-STREAM-FROM-STRING", SI_ORDINARY, mk_si_make_string_output_stream_from_string, 2, MKCL_OBJNULL}},
  {{SYS_ "MAKE-STRUCTURE", SI_ORDINARY, mk_si_make_structure, -1, MKCL_OBJNULL}},
  {{SYS_ "MAKE-VECTOR", SI_ORDINARY, mk_si_make_vector, 6, MKCL_OBJNULL}},
  {{SYS_ "MANGLE-NAME", SI_ORDINARY, mk_si_mangle_name, 1, MKCL_OBJNULL}},
  {{SYS_ "MEMBER1", SI_ORDINARY, mk_si_member1, 5, MKCL_OBJNULL}},
  {{SYS_ "MEMQ", SI_ORDINARY, mk_si_memq, 2, MKCL_OBJNULL}},
  {{SYS_ "MKDIR", SI_ORDINARY, mk_si_mkdir, 2, MKCL_OBJNULL}},
  {{SYS_ "MKSTEMP", SI_ORDINARY, mk_si_mkstemp, -1, MKCL_OBJNULL}},
  {{SYS_ "RMDIR", SI_ORDINARY, mk_si_rmdir, 1, MKCL_OBJNULL}},
  {{MKCL_EXT_ "MAKE-PIPE", MKCL_EXT_ORDINARY, mk_mkcl_make_pipe, 0, MKCL_OBJNULL}},
  {{SYS_ "PACKAGE-HASH-TABLES", SI_ORDINARY, mk_si_package_hash_tables, 1, MKCL_OBJNULL}},
  {{SYS_ "PATHNAME-TRANSLATIONS", SI_ORDINARY, mk_si_pathname_translations, -1, MKCL_OBJNULL}},
  {{SYS_ "ALL-LOGICAL-PATHNAME-TRANSLATIONS", SI_ORDINARY, mk_si_all_logical_pathname_translations, 0, MKCL_OBJNULL}},
  {{SYS_ "POINTER", SI_ORDINARY, mk_si_pointer, 1, MKCL_OBJNULL}},
  {{SYS_ "PRETTY-PRINT-FORMAT", SI_ORDINARY, NULL, -1, MKCL_OBJNULL}},
  {{SYS_ "PROCESS-DECLARATIONS", SI_ORDINARY, mk_si_process_declarations, -1, MKCL_OBJNULL}},
#if 0
  {{SYS_ "PROCESS-LAMBDA", SI_ORDINARY, mk_si_process_lambda, 1, MKCL_OBJNULL}},
#endif
  {{SYS_ "PROCESS-LAMBDA-LIST", SI_ORDINARY, mk_si_process_lambda_list, 2, MKCL_OBJNULL}},
  {{SYS_ "PUT-F", SI_ORDINARY, mk_si_put_f, 3, MKCL_OBJNULL}},
  {{SYS_ "PUT-PROPERTIES", SI_ORDINARY, mk_si_put_properties, -1, MKCL_OBJNULL}},
  {{SYS_ "PUT-SYSPROP", SI_ORDINARY, mk_si_put_sysprop, 3, MKCL_OBJNULL}},
  {{SYS_ "PUTPROP", SI_ORDINARY, mk_si_putprop, 3, MKCL_OBJNULL}},
  {{SYS_ "READTABLE-CASE-SET", SI_ORDINARY, mk_si_readtable_case_set, 2, MKCL_OBJNULL}},
  {{SYS_ "REM-F", SI_ORDINARY, mk_si_rem_f, 2, MKCL_OBJNULL}},
  {{SYS_ "REM-SYSPROP", SI_ORDINARY, mk_si_rem_sysprop, 2, MKCL_OBJNULL}},
  {{SYS_ "REPLACE-ARRAY", SI_ORDINARY, mk_si_replace_array, 2, MKCL_OBJNULL}},
  {{SYS_ "ROW-MAJOR-ASET", SI_ORDINARY, mk_si_row_major_aset, 3, MKCL_OBJNULL}},
  {{SYS_ "RUN-COMMAND", SI_ORDINARY, mk_si_run_command, -1, MKCL_OBJNULL}},
  {{MKCL_EXT_ "RUN-PROGRAM", MKCL_EXT_ORDINARY, mk_mkcl_run_program, -1, MKCL_OBJNULL}},
  {{SYS_ "SAFE-EVAL", SI_ORDINARY, mk_si_safe_eval, -1, MKCL_OBJNULL}},
  {{SYS_ "SCH-FRS-BASE", SI_ORDINARY, mk_si_sch_frs_base, 2, MKCL_OBJNULL}},
  {{SYS_ "SCHAR-SET", SI_ORDINARY, mk_si_char_set, 3, MKCL_OBJNULL}},
  {{SYS_ "SHARP-A-READER", SI_ORDINARY, NULL, -1, MKCL_OBJNULL}},
  {{SYS_ "SHARP-S-READER", SI_ORDINARY, NULL, -1, MKCL_OBJNULL}},
  {{SYS_ "SELECT-PACKAGE", SI_ORDINARY, mk_si_select_package, 1, MKCL_OBJNULL}},
  {{SYS_ "SET-SYMBOL-PLIST", SI_ORDINARY, mk_si_set_symbol_plist, 2, MKCL_OBJNULL}},
  {{MKCL_EXT_ "SETENV", MKCL_EXT_ORDINARY, mk_mkcl_setenv, 2, MKCL_OBJNULL}},
  {{SYS_ "SETF-LAMBDA", SI_ORDINARY, NULL, -1, MKCL_OBJNULL}},
  {{SYS_ "SETF-METHOD", SI_ORDINARY, NULL, -1, MKCL_OBJNULL}},
  {{SYS_ "SETF-NAMEP", SI_ORDINARY, NULL, -1, MKCL_OBJNULL}},
  {{SYS_ "SETF-SYMBOL", SI_ORDINARY, NULL, -1, MKCL_OBJNULL}},
  {{SYS_ "SETF-UPDATE", SI_ORDINARY, NULL, -1, MKCL_OBJNULL}},
  {{SYS_ "SIMPLE-PROGRAM-ERROR", SI_ORDINARY, NULL, -1, MKCL_OBJNULL}},
  {{SYS_ "SPECIALP", SI_ORDINARY, mk_si_specialp, 1, MKCL_OBJNULL}},
  {{SYS_ "STANDARD-READTABLE", SI_ORDINARY, mk_si_standard_readtable, 0, MKCL_OBJNULL}},
  {{SYS_ "STEPPER", SI_ORDINARY, NULL, -1, MKCL_OBJNULL}},
  {{SYS_ "CONCATENATE-BASE-STRINGS", SI_ORDINARY, mk_si_concatenate_base_strings, -1, MKCL_OBJNULL}},
  {{SYS_ "FAST-READ-FROM-BASE-STRING", SI_ORDINARY, mk_si_fast_read_from_base_string, 1, MKCL_OBJNULL}},
  {{SYS_ "STRUCTURE-NAME", SI_ORDINARY, mk_si_structure_name, 1, MKCL_OBJNULL}},
  {{SYS_ "STRUCTURE-LENGTH", SI_ORDINARY, mk_si_structure_length, 1, MKCL_OBJNULL}},
  {{SYS_ "STRUCTURE-PRINT-FUNCTION", SI_ORDINARY, NULL, -1, MKCL_OBJNULL}},
  {{SYS_ "STRUCTURE-REF", SI_ORDINARY, mk_si_structure_ref, 3, MKCL_OBJNULL}},
  {{SYS_ "STRUCTURE-SET", SI_ORDINARY, mk_si_structure_set, 4, MKCL_OBJNULL}},
  {{SYS_ "STRUCTURE-SLOT-DESCRIPTIONS", SI_ORDINARY, NULL, -1, MKCL_OBJNULL}},
  {{SYS_ "STRUCTURE-SUBTYPE-P", SI_ORDINARY, mk_si_structure_subtype_p, 2, MKCL_OBJNULL}},
  {{SYS_ "STRUCTUREP", SI_ORDINARY, mk_si_structurep, 1, MKCL_OBJNULL}},
  {{SYS_ "SVSET", SI_ORDINARY, mk_si_svset, 3, MKCL_OBJNULL}},
  {{SYS_ "SYMBOL-MACRO", SI_ORDINARY, NULL, -1, MKCL_OBJNULL}},
  {{SYS_ "SYSTEM", SI_ORDINARY, mk_si_system, -1, MKCL_OBJNULL}},
  {{SYS_ "TERMINAL-INTERRUPT", SI_ORDINARY, NULL, -1, MKCL_OBJNULL}},
  {{SYS_ "SIGINT-HANDLER", SI_ORDINARY, NULL, -1, MKCL_OBJNULL}},
  {{SYS_ "SIGHUP-HANDLER", SI_ORDINARY, NULL, -1, MKCL_OBJNULL}},
  {{SYS_ "SIGTERM-HANDLER", SI_ORDINARY, NULL, -1, MKCL_OBJNULL}},
  {{SYS_ "TERMINAL-SIGNAL-HANDLER", SI_ORDINARY, NULL, -1, MKCL_OBJNULL}},
  {{SYS_ "INITIAL", SI_ORDINARY, NULL, -1, MKCL_OBJNULL}},
  {{SYS_ "TOP-LEVEL", SI_ORDINARY, NULL, -1, MKCL_OBJNULL}},
  {{SYS_ "UNIVERSAL-ERROR-HANDLER", SI_ORDINARY, NULL, -1, MKCL_OBJNULL}},
  {{SYS_ "VALID-FUNCTION-NAME-P", SI_ORDINARY, mk_si_valid_function_name_p, 1, MKCL_OBJNULL}},
  {{SYS_ "WRITE-OBJECT", SI_SPECIAL, mk_si_write_object, 2, MKCL_OBJNULL}},
  {{SYS_ "WRITE-UGLY-OBJECT", SI_SPECIAL, mk_si_write_ugly_object, 2, MKCL_OBJNULL}},

  {{SYS_ "STRUCTURE-INCLUDE", SI_ORDINARY, NULL, -1, MKCL_OBJNULL}},
  {{SYS_ "COPY-INSTANCE", SI_ORDINARY, mk_si_copy_instance, 1, MKCL_OBJNULL}},
  {{SYS_ "GENERIC-FUNCTION-P", SI_ORDINARY, mk_si_generic_function_p, 1, MKCL_OBJNULL}},
  {{SYS_ "INSTANCE-REF-SAFE", SI_ORDINARY, mk_si_instance_ref_safe, 2, MKCL_OBJNULL}},
  {{SYS_ "INSTANCE-REF", SI_ORDINARY, mk_si_instance_ref, 2, MKCL_OBJNULL}},
  {{SYS_ "INSTANCE-SET", SI_ORDINARY, mk_si_instance_set, 3, MKCL_OBJNULL}},
  {{SYS_ "INSTANCE-SIG", SI_ORDINARY, mk_si_instance_sig, 1, MKCL_OBJNULL}},
  {{SYS_ "INSTANCE-SIG-SET", SI_ORDINARY, mk_si_instance_sig_set, 1, MKCL_OBJNULL}},
  {{SYS_ "INSTANCE-SIG-SET2", SI_ORDINARY, mk_si_instance_sig_set2, 2, MKCL_OBJNULL}},
  {{SYS_ "INSTANCE-CLASS", SI_ORDINARY, mk_si_instance_class, 1, MKCL_OBJNULL}},
  {{SYS_ "INSTANCE-CLASS-SET", SI_ORDINARY, mk_si_instance_class_set, 2, MKCL_OBJNULL}},
  {{SYS_ "INSTANCEP", SI_ORDINARY, mk_si_instancep, 1, MKCL_OBJNULL}},
  {{SYS_ "INSTANCE-LENGTH", SI_ORDINARY, mk_si_instance_length, 1, MKCL_OBJNULL}},
  {{SYS_ "SL-BOUNDP", SI_ORDINARY, mk_si_sl_boundp, 1, MKCL_OBJNULL}},
  {{SYS_ "SL-MAKUNBOUND", SI_ORDINARY, mk_si_sl_makunbound, 2, MKCL_OBJNULL}},
  {{SYS_ "SUBCLASSP", SI_ORDINARY, MKCL_IN_LISP(mk_si_subclassp), 2, MKCL_OBJNULL}},
  {{SYS_ "OF-CLASS-P", SI_ORDINARY, MKCL_IN_LISP(mk_si_of_class_p), 2, MKCL_OBJNULL}},

  {{SYS_ "*SOURCE-LOCATION*", SI_SPECIAL, NULL, -1, mk_cl_Cnil}},
  {{SYS_ "*REGISTER-WITH-PDE-HOOK*", SI_SPECIAL, NULL, -1, mk_cl_Cnil}},
  {{SYS_ "REGISTER-WITH-PDE", SI_ORDINARY, NULL, -1, MKCL_OBJNULL}},


  /* KEYWORD PACKAGE */
  {{KEY_ "ADJUSTABLE", KEYWORD, NULL, -1, MKCL_OBJNULL}},
  {{KEY_ "ABORT", KEYWORD, NULL, -1, MKCL_OBJNULL}},
  {{KEY_ "ABSOLUTE", KEYWORD, NULL, -1, MKCL_OBJNULL}},
  {{KEY_ "ALLOW-OTHER-KEYS", KEYWORD, NULL, -1, MKCL_OBJNULL}},
  {{KEY_ "APPEND", KEYWORD, NULL, -1, MKCL_OBJNULL}},
  {{KEY_ "ARRAY", KEYWORD, NULL, -1, MKCL_OBJNULL}},
  {{KEY_ "BACK", KEYWORD, NULL, -1, MKCL_OBJNULL}},
  {{KEY_ "BASE", KEYWORD, NULL, -1, MKCL_OBJNULL}},
  {{KEY_ "BLOCK", KEYWORD, NULL, -1, MKCL_OBJNULL}},
  {{KEY_ "CAPITALIZE", KEYWORD, NULL, -1, MKCL_OBJNULL}},
  {{KEY_ "CASE", KEYWORD, NULL, -1, MKCL_OBJNULL}},
  {{KEY_ "CIRCLE", KEYWORD, NULL, -1, MKCL_OBJNULL}},
  {{KEY_ "COMPILE-TOPLEVEL", KEYWORD, NULL, -1, MKCL_OBJNULL}},
  {{KEY_ "COMMON",KEYWORD,NULL,-1,MKCL_OBJNULL}},
  {{KEY_ "CONC-NAME", KEYWORD, NULL, -1, MKCL_OBJNULL}},
  {{KEY_ "CONSTRUCTOR", KEYWORD, NULL, -1, MKCL_OBJNULL}},
  {{KEY_ "CONTROL-STRING", KEYWORD, NULL, -1, MKCL_OBJNULL}},
  {{KEY_ "COPIER", KEYWORD, NULL, -1, MKCL_OBJNULL}},
  {{KEY_ "CREATE", KEYWORD, NULL, -1, MKCL_OBJNULL}},
  {{KEY_ "DATUM", KEYWORD, NULL, -1, MKCL_OBJNULL}},
  {{KEY_ "DEFAULT", KEYWORD, NULL, -1, MKCL_OBJNULL}},
  {{KEY_ "DEFAULTS", KEYWORD, NULL, -1, MKCL_OBJNULL}},
  {{KEY_ "DEVICE", KEYWORD, NULL, -1, MKCL_OBJNULL}},
  {{KEY_ "DIRECTION", KEYWORD, NULL, -1, MKCL_OBJNULL}},
  {{KEY_ "DIRECTORY", KEYWORD, NULL, -1, MKCL_OBJNULL}},
  {{KEY_ "DISPLACED-INDEX-OFFSET", KEYWORD, NULL, -1, MKCL_OBJNULL}},
  {{KEY_ "DISPLACED-TO", KEYWORD, NULL, -1, MKCL_OBJNULL}},
  {{KEY_ "DOCUMENTATION", KEYWORD, NULL, -1, MKCL_OBJNULL}},
  {{KEY_ "DOWNCASE", KEYWORD, NULL, -1, MKCL_OBJNULL}},
  {{KEY_ "ELEMENT-TYPE", KEYWORD, NULL, -1, MKCL_OBJNULL}},
  {{KEY_ "END", KEYWORD, NULL, -1, MKCL_OBJNULL}},
  {{KEY_ "END1", KEYWORD, NULL, -1, MKCL_OBJNULL}},
  {{KEY_ "END2", KEYWORD, NULL, -1, MKCL_OBJNULL}},
  {{KEY_ "EOF", KEYWORD, NULL, -1, MKCL_OBJNULL}},
  {{KEY_ "ERROR", KEYWORD, NULL, -1, MKCL_OBJNULL}},
  {{KEY_ "ESCAPE", KEYWORD, NULL, -1, MKCL_OBJNULL}},
  {{KEY_ "EXECUTE", KEYWORD, NULL, -1, MKCL_OBJNULL}},
  {{KEY_ "EXPECTED-TYPE", KEYWORD, NULL, -1, MKCL_OBJNULL}},
  {{KEY_ "EXPORT", KEYWORD, NULL, -1, MKCL_OBJNULL}},
  {{KEY_ "EXPORT-FROM", KEYWORD, NULL, -1, MKCL_OBJNULL}},
  {{KEY_ "EXTERNAL", KEYWORD, NULL, -1, MKCL_OBJNULL}},
  {{KEY_ "EXTERNAL-FORMAT", KEYWORD, NULL, -1, MKCL_OBJNULL}},
  {{KEY_ "FILE", KEYWORD, NULL, -1, MKCL_OBJNULL}},
  {{KEY_ "FILL-POINTER", KEYWORD, NULL, -1, MKCL_OBJNULL}},
  {{KEY_ "FORCE", KEYWORD, NULL, -1, MKCL_OBJNULL}},
  {{KEY_ "FORMAT-ARGUMENTS", KEYWORD, NULL, -1, MKCL_OBJNULL}},
  {{KEY_ "FORMAT-CONTROL", KEYWORD, NULL, -1, MKCL_OBJNULL}},
  {{KEY_ "FUNCTION", KEYWORD, NULL, -1, MKCL_OBJNULL}},
  {{KEY_ "GENSYM", KEYWORD, NULL, -1, MKCL_OBJNULL}},
  {{KEY_ "HOST", KEYWORD, NULL, -1, MKCL_OBJNULL}},
  {{KEY_ "IF-DOES-NOT-EXIST", KEYWORD, NULL, -1, MKCL_OBJNULL}},
  {{KEY_ "IF-EXISTS", KEYWORD, NULL, -1, MKCL_OBJNULL}},
  {{KEY_ "IMPORT-FROM", KEYWORD, NULL, -1, MKCL_OBJNULL}},
  {{KEY_ "INCLUDE", KEYWORD, NULL, -1, MKCL_OBJNULL}},
  {{KEY_ "INHERITED", KEYWORD, NULL, -1, MKCL_OBJNULL}},
  {{KEY_ "INITIAL-ELEMENT", KEYWORD, NULL, -1, MKCL_OBJNULL}},
  {{KEY_ "INITIAL-CONTENTS", KEYWORD, NULL, -1, MKCL_OBJNULL}},
  {{KEY_ "INITIAL-OFFSET", KEYWORD, NULL, -1, MKCL_OBJNULL}},
  {{KEY_ "INPUT", KEYWORD, NULL, -1, MKCL_OBJNULL}},
  {{KEY_ "INTERACTIVE", KEYWORD, NULL, -1, MKCL_OBJNULL}},
  {{KEY_ "INSTANCE", KEYWORD, NULL, -1, MKCL_OBJNULL}},
  {{KEY_ "INTERN", KEYWORD, NULL, -1, MKCL_OBJNULL}},
  {{KEY_ "INTERNAL", KEYWORD, NULL, -1, MKCL_OBJNULL}},
  {{KEY_ "INVERT", KEYWORD, NULL, -1, MKCL_OBJNULL}},
  {{KEY_ "IO", KEYWORD, NULL, -1, MKCL_OBJNULL}},
  {{KEY_ "JUNK-ALLOWED", KEYWORD, NULL, -1, MKCL_OBJNULL}},
  {{KEY_ "KEY", KEYWORD, NULL, -1, MKCL_OBJNULL}},
  {{KEY_ "LENGTH", KEYWORD, NULL, -1, MKCL_OBJNULL}},
  {{KEY_ "LEVEL", KEYWORD, NULL, -1, MKCL_OBJNULL}},
  {{KEY_ "LINES", KEYWORD, NULL, -1, MKCL_OBJNULL}},
  {{KEY_ "LINK", KEYWORD, NULL, -1, MKCL_OBJNULL}},
  {{KEY_ "LIST-ALL", KEYWORD, NULL, -1, MKCL_OBJNULL}},
  {{KEY_ "LOCAL",KEYWORD,NULL,-1,MKCL_OBJNULL}},
  {{KEY_ "LOCKABLE", KEYWORD, NULL, -1, MKCL_OBJNULL}},
  {{KEY_ "LOAD-TOPLEVEL", KEYWORD, NULL, -1, MKCL_OBJNULL}},
  {{KEY_ "MISER-WIDTH", KEYWORD, NULL, -1, MKCL_OBJNULL}},
  {{KEY_ "NAME", KEYWORD, NULL, -1, MKCL_OBJNULL}},
  {{KEY_ "NAMED", KEYWORD, NULL, -1, MKCL_OBJNULL}},
  {{KEY_ "NEW-VERSION", KEYWORD, NULL, -1, MKCL_OBJNULL}},
  {{KEY_ "NEWEST", KEYWORD, NULL, -1, MKCL_OBJNULL}},
  {{KEY_ "NICKNAMES", KEYWORD, NULL, -1, MKCL_OBJNULL}},
  {{KEY_ "OBJECT", KEYWORD, NULL, -1, MKCL_OBJNULL}},
  {{KEY_ "OFFSET", KEYWORD, NULL, -1, MKCL_OBJNULL}},
  {{KEY_ "OPERATION", KEYWORD, NULL, -1, MKCL_OBJNULL}},
  {{KEY_ "OPERANDS", KEYWORD, NULL, -1, MKCL_OBJNULL}},
  {{KEY_ "OUTPUT", KEYWORD, NULL, -1, MKCL_OBJNULL}},
  {{KEY_ "OVERWRITE", KEYWORD, NULL, -1, MKCL_OBJNULL}},
  {{KEY_ "PACKAGE", KEYWORD, NULL, -1, MKCL_OBJNULL}},
  {{KEY_ "PATHNAME", KEYWORD, NULL, -1, MKCL_OBJNULL}},
  {{KEY_ "PPRINT-DISPATCH", KEYWORD, NULL, -1, MKCL_OBJNULL}},
  {{KEY_ "PREDICATE", KEYWORD, NULL, -1, MKCL_OBJNULL}},
  {{KEY_ "PRESERVE", KEYWORD, NULL, -1, MKCL_OBJNULL}},
  {{KEY_ "PRETTY", KEYWORD, NULL, -1, MKCL_OBJNULL}},
  {{KEY_ "PRINT", KEYWORD, NULL, -1, MKCL_OBJNULL}},
  {{KEY_ "PRINT-FUNCTION", KEYWORD, NULL, -1, MKCL_OBJNULL}},
  {{KEY_ "PRINT-OBJECT", KEYWORD, NULL, -1, MKCL_OBJNULL}},
  {{KEY_ "PROBE", KEYWORD, NULL, -1, MKCL_OBJNULL}},
  {{KEY_ "RADIX", KEYWORD, NULL, -1, MKCL_OBJNULL}},
  {{KEY_ "READABLY", KEYWORD, NULL, -1, MKCL_OBJNULL}},
  {{KEY_ "REHASH-SIZE", KEYWORD, NULL, -1, MKCL_OBJNULL}},
  {{KEY_ "REHASH-THRESHOLD", KEYWORD, NULL, -1, MKCL_OBJNULL}},
  {{KEY_ "RELATIVE", KEYWORD, NULL, -1, MKCL_OBJNULL}},
  {{KEY_ "RENAME", KEYWORD, NULL, -1, MKCL_OBJNULL}},
  {{KEY_ "RENAME-AND-DELETE", KEYWORD, NULL, -1, MKCL_OBJNULL}},
  {{KEY_ "REPORT", KEYWORD, NULL, -1, MKCL_OBJNULL}},
  {{KEY_ "RIGHT-MARGIN", KEYWORD, NULL, -1, MKCL_OBJNULL}},
  {{KEY_ "SET-DEFAULT-PATHNAME", KEYWORD, NULL, -1, MKCL_OBJNULL}},
  {{KEY_ "SEARCH-LIST", KEYWORD, NULL, -1, MKCL_OBJNULL}},
  {{KEY_ "SHADOW", KEYWORD, NULL, -1, MKCL_OBJNULL}},
  {{KEY_ "SHADOWING-IMPORT", KEYWORD, NULL, -1, MKCL_OBJNULL}},
  {{KEY_ "SIZE", KEYWORD, NULL, -1, MKCL_OBJNULL}},
  {{KEY_ "SPECIAL", KEYWORD, NULL, -1, MKCL_OBJNULL}},
  {{KEY_ "START", KEYWORD, NULL, -1, MKCL_OBJNULL}},
  {{KEY_ "START1", KEYWORD, NULL, -1, MKCL_OBJNULL}},
  {{KEY_ "START2", KEYWORD, NULL, -1, MKCL_OBJNULL}},
  {{KEY_ "STREAM", KEYWORD, NULL, -1, MKCL_OBJNULL}},
  {{KEY_ "SUPERSEDE", KEYWORD, NULL, -1, MKCL_OBJNULL}},
  {{KEY_ "TAG", KEYWORD, NULL, -1, MKCL_OBJNULL}},
  {{KEY_ "TEST", KEYWORD, NULL, -1, MKCL_OBJNULL}},
  {{KEY_ "TEST-NOT", KEYWORD, NULL, -1, MKCL_OBJNULL}},
  {{KEY_ "TYPE", KEYWORD, NULL, -1, MKCL_OBJNULL}},
  {{KEY_ "UNSPECIFIC", KEYWORD, NULL, -1, MKCL_OBJNULL}},
  {{KEY_ "UP", KEYWORD, NULL, -1, MKCL_OBJNULL}},
  {{KEY_ "UPCASE", KEYWORD, NULL, -1, MKCL_OBJNULL}},
  {{KEY_ "USE", KEYWORD, NULL, -1, MKCL_OBJNULL}},
  {{KEY_ "STDIO-STREAM", KEYWORD, NULL, -1, MKCL_OBJNULL}},
  {{KEY_ "VERBOSE", KEYWORD, NULL, -1, MKCL_OBJNULL}},
  {{KEY_ "VERSION", KEYWORD, NULL, -1, MKCL_OBJNULL}},
  {{KEY_ "WILD", KEYWORD, NULL, -1, MKCL_OBJNULL}},
  {{KEY_ "WILD-INFERIORS", KEYWORD, NULL, -1, MKCL_OBJNULL}},
  {{KEY_ "WAIT", KEYWORD, NULL, -1, MKCL_OBJNULL}},

  {{MKCL_EXT_ "BYTE8", MKCL_EXT_ORDINARY, NULL, -1, MKCL_OBJNULL}},
  {{MKCL_EXT_ "BYTE16", MKCL_EXT_ORDINARY, NULL, -1, MKCL_OBJNULL}},
  {{MKCL_EXT_ "BYTE32", MKCL_EXT_ORDINARY, NULL, -1, MKCL_OBJNULL}},
  {{MKCL_EXT_ "BYTE64", MKCL_EXT_ORDINARY, NULL, -1, MKCL_OBJNULL}},
  {{MKCL_EXT_ "COMPILER-LET", MKCL_EXT_FORM, NULL, -1, MKCL_OBJNULL}},
  {{MKCL_EXT_ "INTEGER8", MKCL_EXT_ORDINARY, NULL, -1, MKCL_OBJNULL}},
  {{MKCL_EXT_ "INTEGER16", MKCL_EXT_ORDINARY, NULL, -1, MKCL_OBJNULL}},
  {{MKCL_EXT_ "INTEGER32", MKCL_EXT_ORDINARY, NULL, -1, MKCL_OBJNULL}},
  {{MKCL_EXT_ "INTEGER64", MKCL_EXT_ORDINARY, NULL, -1, MKCL_OBJNULL}},
  {{MKCL_EXT_ "QUIT", MKCL_EXT_ORDINARY, NULL, -1, MKCL_OBJNULL}},
  {{SYS_ "LAMBDA-BLOCK", SI_ORDINARY, NULL, -1, MKCL_OBJNULL}},
  {{SYS_ "INSTANCE", SI_ORDINARY, NULL, -1, MKCL_OBJNULL}},

  {{SYS_ "ALLOCATE-FOREIGN-DATA", SI_ORDINARY, mk_si_allocate_foreign_data, 2, MKCL_OBJNULL}},
  {{SYS_ "FIND-FOREIGN-SYMBOL", SI_ORDINARY, mk_si_find_foreign_symbol, 4, MKCL_OBJNULL}},
#if 0
  {{SYS_ "FOREIGN-DATA", SI_ORDINARY, NULL, -1, MKCL_OBJNULL}},
#else
  {{SYS_ "FOREIGN", SI_ORDINARY, NULL, -1, MKCL_OBJNULL}},
#endif
  {{SYS_ "FOREIGN-ADDRESS", SI_ORDINARY, mk_si_foreign_address, 1, MKCL_OBJNULL}},
  {{SYS_ "FOREIGN-INDEXED", SI_ORDINARY, mk_si_foreign_indexed, 4, MKCL_OBJNULL}},
  {{SYS_ "FOREIGN-RECAST", SI_ORDINARY, mk_si_foreign_recast, 3, MKCL_OBJNULL}},
  {{SYS_ "FOREIGN-REF", SI_ORDINARY, mk_si_foreign_ref, 4, MKCL_OBJNULL}},
  {{SYS_ "FOREIGN-REF-ELT", SI_ORDINARY, mk_si_foreign_ref_elt, 3, MKCL_OBJNULL}},
  {{SYS_ "FOREIGN-SET", SI_ORDINARY, mk_si_foreign_set, 3, MKCL_OBJNULL}},
  {{SYS_ "FOREIGN-SET-ELT", SI_ORDINARY, mk_si_foreign_set_elt, 4, MKCL_OBJNULL}},
  {{SYS_ "FOREIGN-TAG", SI_ORDINARY, mk_si_foreign_tag, 1, MKCL_OBJNULL}},
  {{SYS_ "FREE-FOREIGN-DATA", SI_ORDINARY, mk_si_free_foreign_data, 1, MKCL_OBJNULL}},
  {{SYS_ "MAKE-FOREIGN-DATA-FROM-ARRAY", SI_ORDINARY, mk_si_make_foreign_data_from_array, 1, MKCL_OBJNULL}},
  {{SYS_ "LOAD-FOREIGN-MODULE", SI_ORDINARY, mk_si_load_foreign_module, 1, MKCL_OBJNULL}},
  {{SYS_ "UNLOAD-FOREIGN-MODULE", SI_ORDINARY, mk_si_unload_foreign_module, 1, MKCL_OBJNULL}},
  {{SYS_ "NULL-POINTER-P", SI_ORDINARY, mk_si_null_pointer_p, 1, MKCL_OBJNULL}},
  {{SYS_ "SIZE-OF-FOREIGN-ELT-TYPE", SI_ORDINARY, mk_si_size_of_foreign_elt_type, 1, MKCL_OBJNULL}},
  {{KEY_ "BYTE", KEYWORD, NULL, -1, MKCL_OBJNULL}},
  {{KEY_ "CHAR", KEYWORD, NULL, -1, MKCL_OBJNULL}},
  {{KEY_ "CSTRING", KEYWORD, NULL, -1, MKCL_OBJNULL}},
  {{KEY_ "DOUBLE", KEYWORD, NULL, -1, MKCL_OBJNULL}},
  {{KEY_ "FIXNUM", KEYWORD, NULL, -1, MKCL_OBJNULL}},
  {{KEY_ "FLOAT", KEYWORD, NULL, -1, MKCL_OBJNULL}},
  {{KEY_ "INT", KEYWORD, NULL, -1, MKCL_OBJNULL}},
  {{KEY_ "INT8-T", KEYWORD, NULL, -1, MKCL_OBJNULL}},
  {{KEY_ "INT16-T", KEYWORD, NULL, -1, MKCL_OBJNULL}},
  {{KEY_ "INT32-T", KEYWORD, NULL, -1, MKCL_OBJNULL}},
  {{KEY_ "INT64-T", KEYWORD, NULL, -1, MKCL_OBJNULL}},
  {{KEY_ "LONG", KEYWORD, NULL, -1, MKCL_OBJNULL}},
  {{KEY_ "LONG-DOUBLE", KEYWORD, NULL, -1, MKCL_OBJNULL}},
  {{KEY_ "LONG-LONG", KEYWORD, NULL, -1, MKCL_OBJNULL}},
  {{KEY_ "POINTER-SELF", KEYWORD, NULL, -1, MKCL_OBJNULL}},
  {{KEY_ "POINTER-VOID", KEYWORD, NULL, -1, MKCL_OBJNULL}},
  {{KEY_ "SHORT", KEYWORD, NULL, -1, MKCL_OBJNULL}},
  {{KEY_ "STRUCT", KEYWORD, NULL, -1, MKCL_OBJNULL}},
  {{KEY_ "UNION", KEYWORD, NULL, -1, MKCL_OBJNULL}},
  {{KEY_ "VOID", KEYWORD, NULL, -1, MKCL_OBJNULL}},
  {{KEY_ "UINT8-T", KEYWORD, NULL, -1, MKCL_OBJNULL}},
  {{KEY_ "UINT16-T", KEYWORD, NULL, -1, MKCL_OBJNULL}},
  {{KEY_ "UINT32-T", KEYWORD, NULL, -1, MKCL_OBJNULL}},
  {{KEY_ "UINT64-T", KEYWORD, NULL, -1, MKCL_OBJNULL}},
  {{KEY_ "UNSIGNED-BYTE", KEYWORD, NULL, -1, MKCL_OBJNULL}},
  {{KEY_ "UNSIGNED-CHAR", KEYWORD, NULL, -1, MKCL_OBJNULL}},
  {{KEY_ "UNSIGNED-INT", KEYWORD, NULL, -1, MKCL_OBJNULL}},
  {{KEY_ "UNSIGNED-LONG", KEYWORD, NULL, -1, MKCL_OBJNULL}},
  {{KEY_ "UNSIGNED-LONG-LONG", KEYWORD, NULL, -1, MKCL_OBJNULL}},
  {{KEY_ "UNSIGNED-SHORT", KEYWORD, NULL, -1, MKCL_OBJNULL}},
  {{KEY_ "FLOAT-COMPLEX", KEYWORD, NULL, -1, MKCL_OBJNULL}},
  {{KEY_ "DOUBLE-COMPLEX", KEYWORD, NULL, -1, MKCL_OBJNULL}},
  {{KEY_ "LONG-DOUBLE-COMPLEX", KEYWORD, NULL, -1, MKCL_OBJNULL}},
  {{KEY_ "FLOAT-IMAGINARY", KEYWORD, NULL, -1, MKCL_OBJNULL}},
  {{KEY_ "DOUBLE-IMAGINARY", KEYWORD, NULL, -1, MKCL_OBJNULL}},
  {{KEY_ "LONG-DOUBLE-IMAGINARY", KEYWORD, NULL, -1, MKCL_OBJNULL}},
  {{SYS_ "C-CHAR-BIT", SI_CONSTANT, NULL, -1, MKCL_MAKE_FIXNUM(CHAR_BIT)}},
  {{SYS_ "C-CHAR-MAX", SI_CONSTANT, NULL, -1, MKCL_MAKE_FIXNUM(CHAR_MAX)}},
  {{SYS_ "C-CHAR-MIN", SI_CONSTANT, NULL, -1, MKCL_MAKE_FIXNUM(CHAR_MIN)}},
  {{SYS_ "C-INT-MAX", SI_CONSTANT, NULL, -1, MKCL_OBJNULL}}, /* See main.d */
  {{SYS_ "C-INT-MIN", SI_CONSTANT, NULL, -1, MKCL_OBJNULL}}, /* See main.d */
  {{SYS_ "C-SHORT-MAX", SI_CONSTANT, NULL, -1, MKCL_MAKE_FIXNUM(SHRT_MAX)}},
  {{SYS_ "C-SHORT-MIN", SI_CONSTANT, NULL, -1, MKCL_MAKE_FIXNUM(SHRT_MIN)}},
  {{SYS_ "C-LONG-MAX", SI_CONSTANT, NULL, -1, MKCL_OBJNULL}}, /* See main.d */
  {{SYS_ "C-LONG-MIN", SI_CONSTANT, NULL, -1, MKCL_OBJNULL}}, /* See main.d */
  {{SYS_ "C-LONG-LONG-MAX",SI_CONSTANT,NULL,-1,MKCL_OBJNULL}}, /* See main.d */
  {{SYS_ "C-LONG-LONG-MIN",SI_CONSTANT,NULL,-1,MKCL_OBJNULL}}, /* See main.d */
  {{SYS_ "C-UCHAR-MAX", SI_CONSTANT, NULL, -1, MKCL_MAKE_FIXNUM(UCHAR_MAX)}},
  {{SYS_ "C-UINT-MAX", SI_CONSTANT, NULL, -1, MKCL_OBJNULL}}, /* See main.d */
  {{SYS_ "C-USHORT-MAX", SI_CONSTANT, NULL, -1, MKCL_MAKE_FIXNUM(USHRT_MAX)}},
  {{SYS_ "C-ULONG-MAX", SI_CONSTANT, NULL, -1, MKCL_OBJNULL}}, /* See main.d */
  {{SYS_ "C-ULONG-LONG-MAX",SI_CONSTANT,NULL,-1,MKCL_OBJNULL}}, /* See main.d */
  {{SYS_ "GC", SI_ORDINARY, mk_si_gc, -1, MKCL_OBJNULL}},
  {{SYS_ "GC-DUMP", SI_ORDINARY, mk_si_gc_dump, 0, MKCL_OBJNULL}},

  {{MT_ "THREAD", MT_ORDINARY, NULL, -1, MKCL_OBJNULL}},
  {{MT_ "LOCK", MT_ORDINARY, NULL, -1, MKCL_OBJNULL}},
  {{MT_ "RWLOCK", MT_ORDINARY, NULL, -1, MKCL_OBJNULL}},
  {{MT_ "SEMAPHORE", MT_ORDINARY, NULL, -1, MKCL_OBJNULL}},
  {{MT_ "CONDITION-VARIABLE", MT_ORDINARY, NULL, -1, MKCL_OBJNULL}},
  {{MT_ "*THREAD*", MT_SPECIAL, NULL, -1, MKCL_OBJNULL}},
  {{MT_ "ALL-THREADS", MT_ORDINARY, mk_mt_all_threads, 0, MKCL_OBJNULL}},
  {{MT_ "EXIT-THREAD", MT_ORDINARY, mk_mt_exit_thread, 1, MKCL_OBJNULL}},
  {{MT_ "TERMINATE-THREAD", MT_ORDINARY, mk_mt_terminate_thread, 0, MKCL_OBJNULL}},
  {{MT_ "MAKE-THREAD", MT_ORDINARY, mk_mt_make_thread, -1, MKCL_OBJNULL}},
  {{MT_ "THREAD-ACTIVE-P", MT_ORDINARY, mk_mt_thread_active_p, 1, MKCL_OBJNULL}},
  {{MT_ "THREAD-ENABLE", MT_ORDINARY, mk_mt_thread_enable, 1, MKCL_OBJNULL}},
  {{MT_ "THREAD-YIELD", MT_ORDINARY, mk_mt_thread_yield, 0, MKCL_OBJNULL}},
  {{MT_ "THREAD-KILL", MT_ORDINARY, mk_mt_thread_kill, 1, MKCL_OBJNULL}},
  {{MT_ "THREAD-DETACH", MT_ORDINARY, mk_mt_thread_detach, 1, MKCL_OBJNULL}},
  {{MT_ "THREAD-JOIN", MT_ORDINARY, mk_mt_thread_join, 1, MKCL_OBJNULL}},
  {{MT_ "THREAD-NAME", MT_ORDINARY, mk_mt_thread_name, 1, MKCL_OBJNULL}},
  {{MT_ "THREAD-PRESET", MT_ORDINARY, mk_mt_thread_preset, -1, MKCL_OBJNULL}},
  {{MT_ "SHOW-SIGMASK", MT_ORDINARY, mk_mt_show_sigmask, 0, MKCL_OBJNULL}},
  {{MT_ "RESET-SIGMASK", MT_ORDINARY, mk_mt_reset_sigmask, 0, MKCL_OBJNULL}},
  {{MT_ "BLOCK-SIGNALS", MT_ORDINARY, mk_mt_block_signals, 0, MKCL_OBJNULL}},
  {{MT_ "UNBLOCK-SIGNALS", MT_ORDINARY, mk_mt_unblock_signals, 0, MKCL_OBJNULL}},
  {{MT_ "THREAD-RUN-FUNCTION", MT_ORDINARY, mk_mt_thread_run_function, -1, MKCL_OBJNULL}},
#if 0
  {{MT_ "THREAD-WHOSTATE", MT_ORDINARY, mk_mt_thread_whostate, 1, MKCL_OBJNULL}},
#endif
  {{MT_ "MAKE-LOCK", MT_ORDINARY, mk_mt_make_lock, -1, MKCL_OBJNULL}},
  {{KEY_ "RECURSIVE", KEYWORD, NULL, -1, MKCL_OBJNULL}},
  {{MT_ "RECURSIVE-LOCK-P", MT_ORDINARY, mk_mt_recursive_lock_p, 1, MKCL_OBJNULL}},
  {{MT_ "LOCK-NAME", MT_ORDINARY, mk_mt_lock_name, 1, MKCL_OBJNULL}},
  {{MT_ "LOCK-HOLDER", MT_ORDINARY, mk_mt_lock_holder, 1, MKCL_OBJNULL}},
  {{MT_ "GET-LOCK", MT_ORDINARY, mk_mt_get_lock, -1, MKCL_OBJNULL}},
  {{KEY_ "TIMEOUT", KEYWORD, NULL, -1, MKCL_OBJNULL}},
  {{MT_ "GIVEUP-LOCK", MT_ORDINARY, mk_mt_giveup_lock, 1, MKCL_OBJNULL}},
  {{MT_ "MAKE-RWLOCK", MT_ORDINARY, mk_mt_make_rwlock, 0, MKCL_OBJNULL}},
  {{MT_ "GIVEUP-RWLOCK", MT_ORDINARY, mk_mt_giveup_rwlock, -1, MKCL_OBJNULL}},
  {{MT_ "GET-READ-RWLOCK", MT_ORDINARY, mk_mt_get_read_rwlock, -1, MKCL_OBJNULL}},
  {{MT_ "GET-WRITE-RWLOCK", MT_ORDINARY, mk_mt_get_write_rwlock, -1, MKCL_OBJNULL}},
  {{MT_ "MAKE-SEMAPHORE", MT_ORDINARY, mk_mt_make_semaphore, -1, MKCL_OBJNULL}},
  {{MT_ "SEMAPHORE-COUNT", MT_ORDINARY, mk_mt_semaphore_count, 1, MKCL_OBJNULL}},
  {{MT_ "SEMAPHORE-SIGNAL", MT_ORDINARY, mk_mt_semaphore_signal, -1, MKCL_OBJNULL}},
  {{MT_ "SEMAPHORE-WAIT", MT_ORDINARY, mk_mt_semaphore_wait, -1, MKCL_OBJNULL}},
  {{MT_ "MAKE-CONDITION-VARIABLE", MT_ORDINARY, mk_mt_make_condition_variable, 0, MKCL_OBJNULL}},
  {{MT_ "CONDITION-WAIT", MT_ORDINARY, mk_mt_condition_wait, -1, MKCL_OBJNULL}},
  {{MT_ "CONDITION-SIGNAL", MT_ORDINARY, mk_mt_condition_signal, 1, MKCL_OBJNULL}},
  {{MT_ "CONDITION-BROADCAST", MT_ORDINARY, mk_mt_condition_broadcast, 1, MKCL_OBJNULL}},
  {{KEY_ "INITIAL-BINDINGS", KEYWORD, NULL, -1, MKCL_OBJNULL}},
  {{MT_ "INTERRUPT-THREAD", MT_ORDINARY, mk_mt_interrupt_thread, -1, MKCL_OBJNULL}},
  {{MT_ "+LOAD-COMPILE-LOCK+", MT_CONSTANT, NULL, -1, MKCL_OBJNULL}},
  {{MT_ "WITH-LOCK", MT_CONSTANT, NULL, -1, MKCL_OBJNULL}},
  {{MT_ "WITHOUT-LOCK", MT_CONSTANT, NULL, -1, MKCL_OBJNULL}},
  {{MT_ "WITHOUT-INTERRUPTS", MT_CONSTANT, NULL, -1, MKCL_OBJNULL}},

  {{MT_ "INTERRUPT-ERROR", MT_ORDINARY, NULL, -1, MKCL_OBJNULL}},
  {{MT_ "THREAD-SLEEPING", MT_ORDINARY, NULL, -1, MKCL_OBJNULL}},
  {{MT_ "INTERRUPT-REFUSED", MT_ORDINARY, NULL, -1, MKCL_OBJNULL}},
  {{MT_ "INVALID-THREAD", MT_ORDINARY, NULL, -1, MKCL_OBJNULL}},

  {{SYS_ "WHILE", SI_ORDINARY, NULL, -1, MKCL_OBJNULL}},
  {{SYS_ "UNTIL", SI_ORDINARY, NULL, -1, MKCL_OBJNULL}},
  {{SYS_ "QUASIQUOTE", SI_ORDINARY, NULL, -1, MKCL_OBJNULL}},
  {{SYS_ "*EXIT-HOOKS*", SI_SPECIAL, NULL, -1, mk_cl_Cnil}},
  {{KEY_ "THREAD", KEYWORD, NULL, -1, MKCL_OBJNULL}},
  {{KEY_ "REASON", KEYWORD, NULL, -1, MKCL_OBJNULL}},
  {{KEY_ "SUSPENDED", KEYWORD, NULL, -1, MKCL_OBJNULL}},
  {{KEY_ "DEAD", KEYWORD, NULL, -1, MKCL_OBJNULL}},

  {{CLOS_ "*BUILTIN-CLASSES*", CLOS_SPECIAL, NULL, -1, mk_cl_Cnil}},
  {{CLOS_ "COMPUTE-EFFECTIVE-METHOD", CLOS_ORDINARY, NULL, -1, MKCL_OBJNULL}},
  {{CLOS_ "COMPUTE-EFFECTIVE-METHOD-FOR-CACHE", CLOS_ORDINARY, NULL, -1, MKCL_OBJNULL}},
  {{CLOS_ "FUNCALLABLE-STANDARD-INSTANCE-ACCESS", CLOS_ORDINARY, mk_si_instance_ref, 2, MKCL_OBJNULL}},
  {{CLOS_ "SET-FUNCALLABLE-INSTANCE-FUNCTION", CLOS_ORDINARY, mk_clos_set_funcallable_instance_function, 2, MKCL_OBJNULL}},

  {{SYS_ "CL-WORD-BITS", SI_CONSTANT, NULL, -1, MKCL_MAKE_FIXNUM(MKCL_WORD_BITS)}},
  {{MKCL_EXT_ "CL-WORD", MKCL_EXT_ORDINARY, NULL, -1, MKCL_OBJNULL}},
  {{MKCL_EXT_ "CL-INDEX", MKCL_EXT_ORDINARY, NULL, -1, MKCL_OBJNULL}},

  {{SYS_ "DO-DEFTYPE", SI_ORDINARY, MKCL_IN_LISP(mk_si_do_deftype), -1, MKCL_OBJNULL}},
  {{SYS_ "CREATE-TYPE-NAME", SI_ORDINARY, NULL, -1, MKCL_OBJNULL}},
  {{SYS_ "*ALIEN-DECLARATIONS*", SI_SPECIAL, NULL, -1, mk_cl_Cnil}},

  {{SYS_ "LOAD-BINARY", SI_ORDINARY, mk_si_load_binary, 4, MKCL_OBJNULL}},

  {{SYS_ "*CODE-WALKER*", SI_SPECIAL, NULL, -1, MKCL_OBJNULL}},

  {{SYS_ "CALL-CFUN", SI_ORDINARY, mk_si_call_cfun, -1, MKCL_OBJNULL}},
  {{KEY_ "CALLBACK", KEYWORD, NULL, -1, MKCL_OBJNULL}},
  {{SYS_ "MAKE-DYNAMIC-CALLBACK", SI_ORDINARY, mk_si_make_dynamic_callback, -1, MKCL_OBJNULL}},
  {{KEY_ "CDECL", KEYWORD, NULL, -1, MKCL_OBJNULL}},
  {{KEY_ "STDCALL", KEYWORD, NULL, -1, MKCL_OBJNULL}},

  {{SYS_ "TRAP-FPE", SI_ORDINARY, NULL, -1, MKCL_OBJNULL}},

  {{SYS_ "DO-SIGSEGV", SI_ORDINARY, mk_si_do_sigsegv, 0, MKCL_OBJNULL}},
  {{SYS_ "OBJNULL", SI_ORDINARY, mk_si_objnull, 0, MKCL_OBJNULL}},

  {{SYS_ "DISPLAY-SIGNAL-DISPOSITIONS", SI_ORDINARY, mk_si_display_signal_dispositions, 0, MKCL_OBJNULL}},

  {{SYS_ "*ACTION-ON-UNDEFINED-VARIABLE*", SI_SPECIAL, NULL, -1, mk_cl_Cnil}},

  {{SYS_ "SET-BUFFERING-MODE", SI_ORDINARY, mk_si_set_buffering_mode, 2, MKCL_OBJNULL}},
  {{KEY_ "NONE", KEYWORD, NULL, -1, MKCL_OBJNULL}},
  {{KEY_ "LINE-BUFFERED", KEYWORD, NULL, -1, MKCL_OBJNULL}},
  {{KEY_ "LINE", KEYWORD, NULL, -1, MKCL_OBJNULL}},
  {{KEY_ "FULLY-BUFFERED", KEYWORD, NULL, -1, MKCL_OBJNULL}},
  {{KEY_ "FULL", KEYWORD, NULL, -1, MKCL_OBJNULL}},

  {{SYS_ "CMP-ENV-REGISTER-MACROLET", SI_ORDINARY, NULL, -1, MKCL_OBJNULL}},

  {{SYS_ "GET-FINALIZER", SI_ORDINARY, mk_si_get_finalizer, 1, MKCL_OBJNULL}},
  {{SYS_ "SET-FINALIZER", SI_ORDINARY, mk_si_set_finalizer, 2, MKCL_OBJNULL}},

  {{SYS_ "*RELATIVE-PACKAGE-NAMES*", SI_SPECIAL, NULL, -1, RELATIVE_PACKAGES_P}},
  {{KEY_ "RELATIVE-PACKAGE-NAMES", KEYWORD, NULL, -1, MKCL_OBJNULL}},
  {{SYS_ "FIND-RELATIVE-PACKAGE", SI_ORDINARY, MKCL_IN_LISP(mk_si_find_relative_package), -1, MKCL_OBJNULL}},
  {{SYS_ "PACKAGE-PARENT", SI_ORDINARY, MKCL_IN_LISP(mk_si_package_parent), -1, MKCL_OBJNULL}},
  {{SYS_ "PACKAGE-CHILDREN", SI_ORDINARY, MKCL_IN_LISP(mk_si_package_children), -1, MKCL_OBJNULL}},

  {{SYS_ "WRONG-TYPE-ARGUMENT", SI_ORDINARY, NULL, -1, MKCL_OBJNULL}},

  {{SYS_ "GC-STATS", SI_ORDINARY, mk_si_gc_stats, 1, MKCL_OBJNULL}},

  {{SYS_ "*CURRENT-FORM*", SI_SPECIAL, NULL, -1, MKCL_OBJNULL}},

  {{SYS_ "CODE-BLOCK", SI_ORDINARY, NULL, -1, MKCL_OBJNULL}},

  {{SYS_ "CLEAR-GFUN-CACHE", SI_ORDINARY, mk_si_clear_gfun_cache, 1, MKCL_OBJNULL}},

  {{SYS_ "TEMP-STACK-FRAME", SI_ORDINARY, NULL, -1, MKCL_OBJNULL}},
  {{SYS_ "APPLY-FROM-TEMP-STACK-FRAME", SI_ORDINARY, mk_si_apply_from_temp_stack_frame, 2, MKCL_OBJNULL}},

  {{GRAY_ "CLOSE", GRAY_ORDINARY, NULL, -1, MKCL_OBJNULL}},
  {{GRAY_ "STREAMP", GRAY_ORDINARY, NULL, -1, MKCL_OBJNULL}},
  {{GRAY_ "INPUT-STREAM-P", GRAY_ORDINARY, NULL, 1, MKCL_OBJNULL}},
  {{GRAY_ "OUTPUT-STREAM-P", GRAY_ORDINARY, NULL, 1, MKCL_OBJNULL}},
  {{GRAY_ "OPEN-STREAM-P", GRAY_ORDINARY, NULL, 1, MKCL_OBJNULL}},
  {{GRAY_ "STREAM-ADVANCE-TO-COLUMN", GRAY_ORDINARY, NULL, -1, MKCL_OBJNULL}},
  {{GRAY_ "STREAM-CLEAR-INPUT", GRAY_ORDINARY, NULL, -1, MKCL_OBJNULL}},
  {{GRAY_ "STREAM-CLEAR-OUTPUT", GRAY_ORDINARY, NULL, -1, MKCL_OBJNULL}},
  {{GRAY_ "STREAM-ELEMENT-TYPE", GRAY_ORDINARY, NULL, 1, MKCL_OBJNULL}},
  {{GRAY_ "STREAM-FILE-POSITION", GRAY_ORDINARY, NULL, -1, MKCL_OBJNULL}},
  {{GRAY_ "STREAM-FINISH-OUTPUT", GRAY_ORDINARY, NULL, -1, MKCL_OBJNULL}},
  {{GRAY_ "STREAM-FORCE-OUTPUT", GRAY_ORDINARY, NULL, -1, MKCL_OBJNULL}},
  {{GRAY_ "STREAM-FRESH-LINE", GRAY_ORDINARY, NULL, -1, MKCL_OBJNULL}},
  {{GRAY_ "STREAM-INTERACTIVE-P", GRAY_ORDINARY, NULL, -1, MKCL_OBJNULL}},
  {{GRAY_ "STREAM-LINE-COLUMN", GRAY_ORDINARY, NULL, -1, MKCL_OBJNULL}},
  {{GRAY_ "STREAM-LISTEN", GRAY_ORDINARY, NULL, -1, MKCL_OBJNULL}},
  {{GRAY_ "STREAM-PEEK-CHAR", GRAY_ORDINARY, NULL, -1, MKCL_OBJNULL}},
  {{GRAY_ "STREAM-READ-BYTE", GRAY_ORDINARY, NULL, -1, MKCL_OBJNULL}},
  {{GRAY_ "STREAM-READ-CHAR", GRAY_ORDINARY, NULL, -1, MKCL_OBJNULL}},
  {{GRAY_ "STREAM-READ-CHAR-NO-HANG", GRAY_ORDINARY, NULL, -1, MKCL_OBJNULL}},
  {{GRAY_ "STREAM-READ-LINE", GRAY_ORDINARY, NULL, -1, MKCL_OBJNULL}},
  {{GRAY_ "STREAM-READ-SEQUENCE", GRAY_ORDINARY, NULL, -1, MKCL_OBJNULL}},
  {{GRAY_ "STREAM-START-LINE-P", GRAY_ORDINARY, NULL, -1, MKCL_OBJNULL}},
  {{GRAY_ "STREAM-TERPRI", GRAY_ORDINARY, NULL, -1, MKCL_OBJNULL}},
  {{GRAY_ "STREAM-UNREAD-CHAR", GRAY_ORDINARY, NULL, -1, MKCL_OBJNULL}},
  {{GRAY_ "STREAM-WRITE-BYTE", GRAY_ORDINARY, NULL, -1, MKCL_OBJNULL}},
  {{GRAY_ "STREAM-WRITE-CHAR", GRAY_ORDINARY, NULL, -1, MKCL_OBJNULL}},
  {{GRAY_ "STREAM-WRITE-SEQUENCE", GRAY_ORDINARY, NULL, -1, MKCL_OBJNULL}},
  {{GRAY_ "STREAM-WRITE-STRING", GRAY_ORDINARY, NULL, -1, MKCL_OBJNULL}},
  {{GRAY_ "FUNDAMENTAL-STREAM", GRAY_ORDINARY, NULL, -1, MKCL_OBJNULL}},
  {{GRAY_ "FUNDAMENTAL-INPUT-STREAM", GRAY_ORDINARY, NULL, -1, MKCL_OBJNULL}},
  {{GRAY_ "FUNDAMENTAL-OUTPUT-STREAM", GRAY_ORDINARY, NULL, -1, MKCL_OBJNULL}},
  {{GRAY_ "FUNDAMENTAL-CHARACTER-STREAM", GRAY_ORDINARY, NULL, -1, MKCL_OBJNULL}},
  {{GRAY_ "FUNDAMENTAL-BINARY-STREAM", GRAY_ORDINARY, NULL, -1, MKCL_OBJNULL}},
  {{GRAY_ "FUNDAMENTAL-CHARACTER-INPUT-STREAM", GRAY_ORDINARY, NULL, -1, MKCL_OBJNULL}},
  {{GRAY_ "FUNDAMENTAL-CHARACTER-OUTPUT-STREAM", GRAY_ORDINARY, NULL, -1, MKCL_OBJNULL}},
  {{GRAY_ "FUNDAMENTAL-BINARY-INPUT-STREAM", GRAY_ORDINARY, NULL, -1, MKCL_OBJNULL}},
  {{GRAY_ "FUNDAMENTAL-BINARY-OUTPUT-STREAM", GRAY_ORDINARY, NULL, -1, MKCL_OBJNULL}},

  {{SYS_ "LOG1P", SI_ORDINARY, mk_si_log1p, 1, MKCL_OBJNULL}},

  {{SYS_ "COMPILED-FUNCTION-FILE", SI_ORDINARY, mk_si_compiled_function_file, 1, MKCL_OBJNULL}},

  {{SYS_ "PROPERTY-LIST", SI_ORDINARY, NULL, 1, MKCL_OBJNULL}},

  {{SYS_ "BYTECODE", SI_ORDINARY, NULL, 1, MKCL_OBJNULL}},

  {{SYS_ "HASH-EQL", SI_ORDINARY, mk_si_hash_eql, -1, MKCL_OBJNULL}},
  {{SYS_ "HASH-EQUAL", SI_ORDINARY, mk_si_hash_equal, -1, MKCL_OBJNULL}},
  {{SYS_ "HASH-EQUALP", SI_ORDINARY, mk_si_hash_equalp, -1, MKCL_OBJNULL}},

  {{MKCL_EXT_ "INTERACTIVE-INTERRUPT", MKCL_EXT_ORDINARY, NULL, -1, MKCL_OBJNULL}},

  {{MKCL_EXT_ "STORAGE-EXHAUSTED", MKCL_EXT_ORDINARY, NULL, -1, MKCL_OBJNULL}},
  {{MKCL_EXT_ "STACK-OVERFLOW", MKCL_EXT_ORDINARY, NULL, -1, MKCL_OBJNULL}},
  {{MKCL_EXT_ "STACK-OVERFLOW-SIZE", MKCL_EXT_ORDINARY, NULL, -1, MKCL_OBJNULL}},
  {{MKCL_EXT_ "STACK-OVERFLOW-TYPE", MKCL_EXT_ORDINARY, NULL, -1, MKCL_OBJNULL}},
  {{SYS_ "BINDING-STACK", SI_ORDINARY, NULL, -1, MKCL_OBJNULL}},
  {{SYS_ "FRAME-STACK", SI_ORDINARY, NULL, -1, MKCL_OBJNULL}},
  {{SYS_ "LISP-TEMP-STACK", SI_ORDINARY, NULL, -1, MKCL_OBJNULL}},
  {{SYS_ "CALL-STACK", SI_ORDINARY, NULL, -1, MKCL_OBJNULL}},
  {{SYS_ "HEAP-SIZE", SI_ORDINARY, NULL, -1, MKCL_OBJNULL}},
#if 0
  {{SYS_ "SET-LIMIT", SI_ORDINARY, mk_si_set_limit, 2, MKCL_OBJNULL}},
  {{SYS_ "GET-LIMIT", SI_ORDINARY, mk_si_get_limit, 1, MKCL_OBJNULL}},
#endif
  {{MKCL_EXT_ "SEGMENTATION-VIOLATION", MKCL_EXT_ORDINARY, NULL, -1, MKCL_OBJNULL}},
  {{MKCL_EXT_ "SEGMENTATION-VIOLATION-ADDRESS", MKCL_EXT_ORDINARY, NULL, -1, MKCL_OBJNULL}},

  {{KEY_ "ADDRESS", KEYWORD, NULL, -1, MKCL_OBJNULL}},

  {{MKCL_EXT_ "EXTENDED-STRING", MKCL_EXT_ORDINARY, NULL, -1, MKCL_OBJNULL}},

  {{KEY_ "LATIN-1", KEYWORD, NULL, -1, MKCL_OBJNULL}},
  {{KEY_ "ISO-8859-1", KEYWORD, NULL, -1, MKCL_OBJNULL}},
  {{KEY_ "UTF-8", KEYWORD, NULL, -1, MKCL_OBJNULL}},
  {{KEY_ "UCS-2", KEYWORD, NULL, -1, MKCL_OBJNULL}},
  {{KEY_ "UCS-4", KEYWORD, NULL, -1, MKCL_OBJNULL}},

  {{SYS_ "CONSTANTLY-T", SI_ORDINARY, NULL, -1, MKCL_OBJNULL}},
  {{SYS_ "CONSTANTLY-NIL", SI_ORDINARY, NULL, -1, MKCL_OBJNULL}},

  {{SYS_ "MAYBE-QUOTE", SI_ORDINARY, NULL, -1, MKCL_OBJNULL}},
  {{SYS_ "MAYBE-UNQUOTE", SI_ORDINARY, NULL, -1, MKCL_OBJNULL}},

  {{KEY_ "CR", KEYWORD, NULL, -1, MKCL_OBJNULL}},
  {{KEY_ "LF", KEYWORD, NULL, -1, MKCL_OBJNULL}},
  {{KEY_ "CRLF", KEYWORD, NULL, -1, MKCL_OBJNULL}},
  {{KEY_ "UCS-2BE", KEYWORD, NULL, -1, MKCL_OBJNULL}},
  {{KEY_ "UCS-4BE", KEYWORD, NULL, -1, MKCL_OBJNULL}},
  {{KEY_ "UCS-2LE", KEYWORD, NULL, -1, MKCL_OBJNULL}},
  {{KEY_ "UCS-4LE", KEYWORD, NULL, -1, MKCL_OBJNULL}},

  {{SYS_ "LOAD-ENCODING", SI_ORDINARY, NULL, -1, MKCL_OBJNULL}},
  {{SYS_ "MAKE-ENCODING", SI_ORDINARY, NULL, -1, MKCL_OBJNULL}},
  {{SYS_ "ALL-ENCODINGS", SI_ORDINARY, NULL, -1, MKCL_OBJNULL}},

  {{KEY_ "US-ASCII", KEYWORD, NULL, -1, MKCL_OBJNULL}},
  {{KEY_ "LITTLE-ENDIAN", KEYWORD, NULL, -1, MKCL_OBJNULL}},
  {{KEY_ "BIG-ENDIAN", KEYWORD, NULL, -1, MKCL_OBJNULL}},

  {{SYS_ "+UNICODE-DATABASE+", SI_CONSTANT, NULL, -1, mk_cl_Cnil}},

  {{SYS_ "COPY-FILE", SI_ORDINARY, mk_si_copy_file, 2, MKCL_OBJNULL}},

  {{SYS_ "FILL-ARRAY-WITH-ELT", SI_ORDINARY, mk_si_fill_array_with_elt, 4, MKCL_OBJNULL}},

  {{SYS_ "+MKCL-VERSION-NUMBER+", SI_CONSTANT, NULL, -1, MKCL_MAKE_FIXNUM(MKCL_VERSION_NUMBER)}},

  {{SYS_ "*BYTECODE-COMPILER*", SI_SPECIAL, NULL, -1, mk_cl_Cnil}},

  {{MKCL_EXT_ "SHORT-FLOAT-POSITIVE-INFINITY", MKCL_EXT_CONSTANT, NULL, -1, MKCL_OBJNULL}},
  {{MKCL_EXT_ "SINGLE-FLOAT-POSITIVE-INFINITY", MKCL_EXT_CONSTANT, NULL, -1, MKCL_OBJNULL}},
  {{MKCL_EXT_ "DOUBLE-FLOAT-POSITIVE-INFINITY", MKCL_EXT_CONSTANT, NULL, -1, MKCL_OBJNULL}},
  {{MKCL_EXT_ "LONG-FLOAT-POSITIVE-INFINITY", MKCL_EXT_CONSTANT, NULL, -1, MKCL_OBJNULL}},
  {{MKCL_EXT_ "SHORT-FLOAT-NEGATIVE-INFINITY", MKCL_EXT_CONSTANT, NULL, -1, MKCL_OBJNULL}},
  {{MKCL_EXT_ "SINGLE-FLOAT-NEGATIVE-INFINITY", MKCL_EXT_CONSTANT, NULL, -1, MKCL_OBJNULL}},
  {{MKCL_EXT_ "DOUBLE-FLOAT-NEGATIVE-INFINITY", MKCL_EXT_CONSTANT, NULL, -1, MKCL_OBJNULL}},
  {{MKCL_EXT_ "LONG-FLOAT-NEGATIVE-INFINITY", MKCL_EXT_CONSTANT, NULL, -1, MKCL_OBJNULL}},
  {{SYS_ "FLOAT-NAN-P", SI_ORDINARY, mk_si_float_nan_p, 1, MKCL_OBJNULL}},
  {{SYS_ "FLOAT-INFINITY-P", SI_ORDINARY, mk_si_float_infinity_p, 1, MKCL_OBJNULL}},

  {{SYS_ "READ-OBJECT-OR-IGNORE", SI_ORDINARY, mk_si_read_object_or_ignore, 2, MKCL_OBJNULL}},

  {{SYS_ "OUTPUT-FLOAT-NAN", SI_ORDINARY, NULL, -1, MKCL_OBJNULL}},
  {{SYS_ "OUTPUT-FLOAT-INFINITY", SI_ORDINARY, NULL, -1, MKCL_OBJNULL}},

  {{SYS_ "UNBOUND-VALUE-P", SI_ORDINARY, mk_si_unbound_value_p, 1, MKCL_OBJNULL}},

  {{SYS_ "PACKAGES-IN-WAITING", SI_ORDINARY, mk_si_packages_in_waiting, 0, MKCL_OBJNULL}},

  {{SYS_ "HASH-TABLES-STATISTICS", SI_ORDINARY, mk_si_hash_tables_statistics, 0, MKCL_OBJNULL}},

  {{KEY_ "MKCL-COMPILED", KEYWORD, NULL, -1, MKCL_OBJNULL}},

  {{SYS_ "+MKCL-FASL-VERSION+", SI_CONSTANT, NULL, -1, MKCL_MAKE_FIXNUM(MKCL_FASL_VERSION)}},

  {{KEY_ "LINUX", KEYWORD, NULL, -1, MKCL_OBJNULL}},
  {{KEY_ "LINUX_2.6", KEYWORD, NULL, -1, MKCL_OBJNULL}},
  {{KEY_ "WINDOWS", KEYWORD, NULL, -1, MKCL_OBJNULL}},
  {{KEY_ "WIN32", KEYWORD, NULL, -1, MKCL_OBJNULL}},
  {{KEY_ "WIN64", KEYWORD, NULL, -1, MKCL_OBJNULL}},
  {{KEY_ "WINNT", KEYWORD, NULL, -1, MKCL_OBJNULL}},
  {{KEY_ "WIN2K", KEYWORD, NULL, -1, MKCL_OBJNULL}},
  {{KEY_ "WINXP", KEYWORD, NULL, -1, MKCL_OBJNULL}},
  {{KEY_ "WINVS", KEYWORD, NULL, -1, MKCL_OBJNULL}},
  {{KEY_ "WIN7", KEYWORD, NULL, -1, MKCL_OBJNULL}},

  {{KEY_ "X86", KEYWORD, NULL, -1, MKCL_OBJNULL}},
  {{KEY_ "X86-64", KEYWORD, NULL, -1, MKCL_OBJNULL}},

  {{SYS_ "MEM-STATS", SI_ORDINARY, mk_si_mem_stats, 0, MKCL_OBJNULL}},

  {{SYS_ "CLOSUREP", SI_ORDINARY, mk_si_closurep, 1, MKCL_OBJNULL}},
  {{SYS_ "CLOSURE-ENV", SI_ORDINARY, mk_si_closure_env, 1, MKCL_OBJNULL}},
  {{SYS_ "CLOSURE-PRODUCER", SI_ORDINARY, mk_si_closure_producer, 1, MKCL_OBJNULL}},
  {{SYS_ "SET-COMPILED-FUNCTION-NAME", SI_ORDINARY, mk_si_set_compiled_function_name, 2, MKCL_OBJNULL}},
  {{SYS_ "COMPILED-FUNCTION-OWNER", SI_ORDINARY, mk_si_compiled_function_owner, 1, MKCL_OBJNULL}},
  {{SYS_ "SET-COMPILED-FUNCTION-OWNER", SI_ORDINARY, mk_si_set_compiled_function_owner, 2, MKCL_OBJNULL}},

  {{SYS_ "SELF-TRUENAME", SI_ORDINARY, mk_si_self_truename, 0, MKCL_OBJNULL}},

  {{MKCL_EXT_ "!", MKCL_EXT_SPECIAL, NULL, -1, mk_cl_Cnil}}, /* used by inspect and the debugger. */

  {{SYS_ "GC-OFF", SI_ORDINARY, mk_si_gc_off, 0, MKCL_OBJNULL}},
  {{SYS_ "GC-ON", SI_ORDINARY, mk_si_gc_on, 0, MKCL_OBJNULL}},

  {{SYS_ "TOP-APPLY", SI_ORDINARY, MKCL_IN_LISP(mk_si_top_apply), 2, MKCL_OBJNULL}},

  {{SYS_ "CONVERT-CMP-LEXICAL-INFO", SI_ORDINARY, mk_si_convert_cmp_lexical_info, 1, MKCL_OBJNULL}},

  {{SYS_ "INSTALL-SIGSEGV-MONITOR", SI_ORDINARY, mk_si_install_sigsegv_monitor, 0, MKCL_OBJNULL}},

  {{KEY_ "DETACHED", KEYWORD, NULL, -1, MKCL_OBJNULL}},
  {{KEY_ "IMPORTED", KEYWORD, NULL, -1, MKCL_OBJNULL}},

  {{KEY_ "FOLLOW-SYMLINKS", KEYWORD, NULL, -1, MKCL_OBJNULL}},

  {{MKCL_EXT_ "BAD-FASL-FILE", MKCL_EXT_ORDINARY, NULL, -1, MKCL_OBJNULL}},
  {{KEY_ "FORMAT", KEYWORD, NULL, -1, MKCL_OBJNULL}},
  {{KEY_ "ARCHITECTURE", KEYWORD, NULL, -1, MKCL_OBJNULL}},
  {{KEY_ "OS", KEYWORD, NULL, -1, MKCL_OBJNULL}},
  {{KEY_ "STALE", KEYWORD, NULL, -1, MKCL_OBJNULL}},
  {{KEY_ "CORRUPTED", KEYWORD, NULL, -1, MKCL_OBJNULL}},

  {{KEY_ "KILLED", KEYWORD, NULL, -1, MKCL_OBJNULL}},
  {{KEY_ "KILLED-BY-DEBUGGER", KEYWORD, NULL, -1, MKCL_OBJNULL}},
  {{KEY_ "INVALID-VALUE", KEYWORD, NULL, -1, MKCL_OBJNULL}},

  {{KEY_ "READ", KEYWORD, NULL, -1, MKCL_OBJNULL}},
  {{KEY_ "WRITE", KEYWORD, NULL, -1, MKCL_OBJNULL}},

  {{KEY_ "CHANGE-DEFAULT-PATHNAME-DEFAULTS", KEYWORD, NULL, -1, MKCL_OBJNULL}},
  {{KEY_ "ALL-DRIVES", KEYWORD, NULL, -1, MKCL_OBJNULL}},
  {{KEY_ "LINENO", KEYWORD, NULL, -1, MKCL_OBJNULL}},

  {{SYS_ "LIST-LIBRARIES", SI_ORDINARY, mk_si_list_libraries, 0, MKCL_OBJNULL}},

  {{SYS_ "COMPILED-CLOSURE", SI_ORDINARY, NULL, -1, MKCL_OBJNULL}},
  {{SYS_ "COMPILED-CLOSURE-DISPLAY", SI_ORDINARY, NULL, -1, MKCL_OBJNULL}},
  {{SYS_ "COMPILED-CLOSURE-LEVEL", SI_ORDINARY, NULL, -1, MKCL_OBJNULL}},
  {{SYS_ "COMPILED-DEBUG-INFORMATION", SI_ORDINARY, NULL, -1, MKCL_OBJNULL}},
  {{SYS_ "CLOSURE-DEPTH", SI_ORDINARY, mk_si_closure_depth, 1, MKCL_OBJNULL}},
  {{SYS_ "CLOSURE-LEVEL", SI_ORDINARY, mk_si_closure_level, 2, MKCL_OBJNULL}},
  {{SYS_ "CLOSURE-LEVEL-SIZE", SI_ORDINARY, mk_si_closure_level_size, 1, MKCL_OBJNULL}},
  {{SYS_ "CLOSURE-LEVEL-VAR", SI_ORDINARY, mk_si_closure_level_var, 2, MKCL_OBJNULL}},
  {{SYS_ "CLOSURE-LEVEL-SET-VAR", SI_ORDINARY, mk_si_closure_level_set_var, 3, MKCL_OBJNULL}},
  {{SYS_ "CLOSURE-LEVEL-OUTER-LEVEL", SI_ORDINARY, mk_si_closure_level_outer_level, 1, MKCL_OBJNULL}},
  {{SYS_ "SYSTEM-PROPERTIES", SI_ORDINARY, mk_si_system_properties, 0, MKCL_OBJNULL}},
  {{SYS_ "BYTECODEP", SI_ORDINARY, mk_si_bytecodep, 1, MKCL_OBJNULL}},

  {{SYS_ "SET-CLASS-PROPER-NAME", SI_ORDINARY, mk_si_set_class_proper_name, 2, MKCL_OBJNULL}},

  {{MKCL_EXT_ "INVALID-SLOT", MKCL_EXT_ORDINARY, NULL, -1, MKCL_OBJNULL}},

  {{SYS_ "CLONE-CLOSURE", SI_ORDINARY, mk_si_clone_closure, -1, MKCL_OBJNULL}},

  {{SYS_ "UPDATE-FUNCTION-REFERENCES", SI_ORDINARY, mk_si_update_function_references, 1, MKCL_OBJNULL}},
  {{SYS_ "GET-FUN-REF-SYM", SI_ORDINARY, mk_si_get_fun_ref_sym, 2, MKCL_OBJNULL}},
  {{SYS_ "GENERATE-FORWARD-FUN-REF-HANDLER", SI_ORDINARY, NULL, -1, MKCL_OBJNULL}},

  {{MT_ "+FORWARD-REFERENCE-LOCK+", MT_CONSTANT, NULL, -1, MKCL_OBJNULL}},

  {{SYS_ "OS-FILE-ERROR", SI_ORDINARY, NULL, -1, MKCL_OBJNULL}},

  {{SYS_ "DISABLE-INTERRUPTS", SI_ORDINARY, mk_si_disable_interrupts, 0, MKCL_OBJNULL}},
  {{SYS_ "ENABLE-INTERRUPTS", SI_ORDINARY, mk_si_enable_interrupts, 0, MKCL_OBJNULL}},

  {{MKCL_EXT_ "GETUID", MKCL_EXT_ORDINARY, mk_mkcl_getuid, 0, MKCL_OBJNULL}},
  {{SYS_ "GDB", SI_ORDINARY, mk_si_gdb, 0, MKCL_OBJNULL}},

  {{SYS_ "*DYNAMIC-CONS-STACK*", SI_SPECIAL, NULL, -1, mk_cl_Cnil}},
  {{SYS_ "TRIM-DYNAMIC-CONS-STACK", SI_ORDINARY, mk_si_trim_dynamic_cons_stack, 0, MKCL_OBJNULL}},
  {{SYS_ "DYN-CONS", SI_ORDINARY, mk_si_dyn_cons, 2, MKCL_OBJNULL}},

  {{SYS_ "DISABLE-FPE", SI_ORDINARY, mk_si_disable_fpe, 1, MKCL_OBJNULL}},
  {{SYS_ "ENABLE-FPE", SI_ORDINARY, mk_si_enable_fpe, 1, MKCL_OBJNULL}},
  {{SYS_ "ALL-ENABLED-FPE", SI_ORDINARY, mk_si_all_enabled_fpe, 0, MKCL_OBJNULL}},
  {{SYS_ "FPE-ENABLED-P", SI_ORDINARY, mk_si_fpe_enabled_p, 1, MKCL_OBJNULL}},
  {{SYS_ "ALL-RAISED-FPE", SI_ORDINARY, mk_si_all_raised_fpe, 0, MKCL_OBJNULL}},
  {{SYS_ "FPE-RAISED-P", SI_ORDINARY, mk_si_fpe_raised_p, 1, MKCL_OBJNULL}},
  {{SYS_ "RAISE-FPE", SI_ORDINARY, mk_si_raise_fpe, 1, MKCL_OBJNULL}},
  {{SYS_ "CLEAR-FPE", SI_ORDINARY, mk_si_clear_fpe, 1, MKCL_OBJNULL}},
  {{SYS_ "CLEAR-ALL-FPE", SI_ORDINARY, mk_si_clear_all_fpe, 0, MKCL_OBJNULL}},
  {{SYS_ "INITIAL-FLOATING-POINT-EXCEPTION-SET", SI_ORDINARY, mk_si_initial_floating_point_exception_set, 0, MKCL_OBJNULL}},
  {{SYS_ "*DEFAULT-FLOATING-POINT-EXCEPTION-SET*", SI_SPECIAL, NULL, -1, mk_cl_Cnil}},

  {{SYS_ "OUTPUT-FLOAT", SI_ORDINARY, NULL, -1, MKCL_OBJNULL}},
  {{SYS_ "*READ-FLOAT-EXACTLY*", SI_SPECIAL, NULL, -1, mk_cl_Cnil}},
  {{SYS_ "*PRINT-FLOAT-EXACTLY*", SI_SPECIAL, NULL, -1, mk_cl_Cnil}},

  {{SYS_ "INDEX", SI_ORDINARY, NULL, -1, MKCL_OBJNULL}},

  {{MKCL_EXT_ "WITH-UNIQUE-NAMES", MKCL_EXT_ORDINARY, NULL, -1, MKCL_OBJNULL}},

  {{SYS_ "BIT-SET", SI_ORDINARY, NULL, -1, MKCL_OBJNULL}},
  {{SYS_ "SBIT-SET", SI_ORDINARY, NULL, -1, MKCL_OBJNULL}},

  {{SYS_ "CONCATENATE-STRINGS", SI_ORDINARY, mk_si_concatenate_strings, -1, MKCL_OBJNULL}},

  {{SYS_ "SIMPLE-BASE-STRING-P", SI_ORDINARY, mk_si_simple_base_string_p, 1, MKCL_OBJNULL}},

  {{SYS_ "STREAM-EXTERNAL-FORMAT-SET", SI_ORDINARY, mk_si_stream_external_format_set, 2, MKCL_OBJNULL}},
  {{SYS_ "*DEFAULT-EXTERNAL-FORMAT*", SI_SPECIAL, NULL, -1, MKCL_OBJNULL}},

  {{KEY_ "UTF-16LE", KEYWORD, NULL, -1, MKCL_OBJNULL}},
  {{KEY_ "UTF-16BE", KEYWORD, NULL, -1, MKCL_OBJNULL}},
  {{KEY_ "UTF-16", KEYWORD, NULL, -1, MKCL_OBJNULL}},
  {{KEY_ "UTF-32LE", KEYWORD, NULL, -1, MKCL_OBJNULL}},
  {{KEY_ "UTF-32BE", KEYWORD, NULL, -1, MKCL_OBJNULL}},
  {{KEY_ "UTF-32", KEYWORD, NULL, -1, MKCL_OBJNULL}},
  {{KEY_ "ASCII", KEYWORD, NULL, -1, MKCL_OBJNULL}},

  {{SYS_ "OS-STREAM-ERROR", SI_ORDINARY, NULL, -1, MKCL_OBJNULL}},
  {{SYS_ "CLOSED-STREAM-ERROR", SI_ORDINARY, NULL, -1, MKCL_OBJNULL}},

  {{SYS_ "GET-BUFFERING-MODE", SI_ORDINARY, mk_si_get_buffering_mode, 1, MKCL_OBJNULL}},

  {{KEY_ "INVALID", KEYWORD, NULL, -1, MKCL_OBJNULL}},
  {{KEY_ "RUNNING", KEYWORD, NULL, -1, MKCL_OBJNULL}},
  {{KEY_ "EXITED", KEYWORD, NULL, -1, MKCL_OBJNULL}},

  {{SYS_ "PROCESS", SI_ORDINARY, NULL, -1, MKCL_OBJNULL}},
  {{SYS_ "ENCODED-STRING", SI_ORDINARY, NULL, -1, MKCL_OBJNULL}},
  {{SYS_ "UTF-8", SI_ORDINARY, mk_si_utf_8, 1, MKCL_OBJNULL}},
  {{SYS_ "UTF-8-P", SI_ORDINARY, mk_si_utf_8_p, 1, MKCL_OBJNULL}},
  {{SYS_ "UTF-8-LENGTH", SI_ORDINARY, mk_si_utf_8_length, 1, MKCL_OBJNULL}},
  {{SYS_ "UTF-8-AS-IS", SI_ORDINARY, mk_si_utf_8_as_is, 1, MKCL_OBJNULL}},
  {{SYS_ "UTF-8-CHAR", SI_ORDINARY, mk_si_utf_8_char, 2, MKCL_OBJNULL}},
  {{SYS_ "UTF-8+", SI_ORDINARY, mk_si_utf_8Plus, -1, MKCL_OBJNULL}},
  {{SYS_ "UTF-8=", SI_ORDINARY, mk_si_utf_8E, 2, MKCL_OBJNULL}},
  {{SYS_ "UTF-8-PUSH-EXTEND", SI_ORDINARY, mk_si_utf_8_push_extend, 2, MKCL_OBJNULL}},
  {{SYS_ "UTF-8-LAST", SI_ORDINARY, mk_si_utf_8_last, 1, MKCL_OBJNULL}},
  {{SYS_ "UTF-16", SI_ORDINARY, mk_si_utf_16, 1, MKCL_OBJNULL}},
  {{SYS_ "UTF-16-P", SI_ORDINARY, mk_si_utf_16_p, 1, MKCL_OBJNULL}},
  {{SYS_ "UTF-16-LENGTH", SI_ORDINARY, mk_si_utf_16_length, 1, MKCL_OBJNULL}},
  {{SYS_ "UTF-16-AS-IS", SI_ORDINARY, mk_si_utf_16_as_is, 1, MKCL_OBJNULL}},
  {{SYS_ "UTF-16-CHAR", SI_ORDINARY, mk_si_utf_16_char, 2, MKCL_OBJNULL}},
  {{SYS_ "UTF-16+", SI_ORDINARY, mk_si_utf_16Plus, 2, MKCL_OBJNULL}},
  {{SYS_ "UTF-16=", SI_ORDINARY, mk_si_utf_16E, 1, MKCL_OBJNULL}},
  {{SYS_ "UTF-16-PUSH-EXTEND", SI_ORDINARY, mk_si_utf_16_push_extend, 2, MKCL_OBJNULL}},
  {{SYS_ "UTF-16-LAST", SI_ORDINARY, mk_si_utf_16_last, 1, MKCL_OBJNULL}},

  {{MT_ "JOIN-THREAD", MT_ORDINARY, mk_mt_thread_join, 1, MKCL_OBJNULL}},
  {{MT_ "DETACH-THREAD", MT_ORDINARY, mk_mt_thread_detach, 1, MKCL_OBJNULL}},
  {{MT_ "THREAD-PLIST", MT_ORDINARY, mk_mt_thread_plist, 1, MKCL_OBJNULL}},
  {{MT_ "SET-THREAD-PLIST", MT_ORDINARY, mk_mt_set_thread_plist, 2, MKCL_OBJNULL}},

  {{SYS_ "JOIN-PROCESS", SI_ORDINARY, mk_si_join_process, 1, MKCL_OBJNULL}},
  {{SYS_ "TERMINATE-PROCESS", SI_ORDINARY, mk_si_terminate_process, -1, MKCL_OBJNULL}},
  {{SYS_ "PROCESS-P", SI_ORDINARY, mk_si_process_p, 1, MKCL_OBJNULL}},
  {{SYS_ "PROCESS-INPUT", SI_ORDINARY, mk_si_process_input, 1, MKCL_OBJNULL}},
  {{SYS_ "PROCESS-OUTPUT", SI_ORDINARY, mk_si_process_output, 1, MKCL_OBJNULL}},
  {{SYS_ "PROCESS-ERROR", SI_ORDINARY, mk_si_process_error, 1, MKCL_OBJNULL}},
  {{SYS_ "PROCESS-PLIST", SI_ORDINARY, mk_si_process_plist, 1, MKCL_OBJNULL}},
  {{SYS_ "SET-PROCESS-PLIST", SI_ORDINARY, mk_si_set_process_plist, 2, MKCL_OBJNULL}},
  {{SYS_ "PROCESS-STATUS", SI_ORDINARY, mk_si_process_status, 1, MKCL_OBJNULL}},
  {{SYS_ "PROCESS-EXIT-CODE", SI_ORDINARY, mk_si_process_exit_code, 1, MKCL_OBJNULL}},
  {{SYS_ "PROCESS-COMMAND", SI_ORDINARY, mk_si_process_command, 1, MKCL_OBJNULL}},
  {{SYS_ "PROCESS-ARGV", SI_ORDINARY, mk_si_process_argv, 1, MKCL_OBJNULL}},
  {{SYS_ "PROCESS-ID", SI_ORDINARY, mk_si_process_id, 1, MKCL_OBJNULL}},
  {{SYS_ "PROCESS-DETACHED-P", SI_ORDINARY, mk_si_process_detached_p, 1, MKCL_OBJNULL}},
  {{SYS_ "DETACH-PROCESS", SI_ORDINARY, mk_si_detach_process, 1, MKCL_OBJNULL}},

  {{SYS_ "C-GLOBAL", SI_ORDINARY, NULL, -1, MKCL_OBJNULL}},

  {{SYS_ "BYTECODE-CLOSURE", SI_ORDINARY, NULL, -1, MKCL_OBJNULL}},

  {{SYS_ "SAMPLE-ALLOCATION-STATISTICS", SI_ORDINARY, mk_si_sample_allocation_statistics, 0, MKCL_OBJNULL}},
  {{SYS_ "RESET-ALLOCATION-STATISTICS", SI_ORDINARY, mk_si_reset_allocation_statistics, 0, MKCL_OBJNULL}},
  {{SYS_ "ROOM-REPORT", SI_ORDINARY, mk_si_room_report, 1, MKCL_OBJNULL}},

  {{MKCL_EXT_ "SIMPLE-STYLE-WARNING", MKCL_EXT_ORDINARY, NULL, -1, MKCL_OBJNULL}},
  {{MKCL_EXT_ "DOLIST!", MKCL_EXT_ORDINARY, NULL, -1, MKCL_OBJNULL}},

  {{MKCL_EXT_ "PROBE-FILE-P", MKCL_EXT_ORDINARY, mk_mkcl_probe_file_p, 1, MKCL_OBJNULL}},
  {{MKCL_EXT_ "STREAM-FILENAME", MKCL_EXT_ORDINARY, mk_mkcl_stream_filename, 1, MKCL_OBJNULL}},

  {{SYS_ "MANGLE-FUNCTION-NAME", SI_ORDINARY, mk_si_mangle_function_name, 1, MKCL_OBJNULL}},
  {{SYS_ "MANGLE-STRING", SI_ORDINARY, mk_si_mangle_string, 1, MKCL_OBJNULL}},
  {{SYS_ "MANGLE-SYMBOL", SI_ORDINARY, mk_si_mangle_symbol, 1, MKCL_OBJNULL}},

  {{KEY_ "ENCODING", KEYWORD, NULL, -1, MKCL_OBJNULL}},

  {{MKCL_EXT_ "PRIN1-TO-BASE-STRING", MKCL_EXT_ORDINARY, MKCL_IN_LISP(mk_mkcl_prin1_to_base_string), -1, MKCL_OBJNULL}},
  {{MKCL_EXT_ "PRINC-TO-BASE-STRING", MKCL_EXT_ORDINARY, MKCL_IN_LISP(mk_mkcl_princ_to_base_string), -1, MKCL_OBJNULL}},
  {{MKCL_EXT_ "WRITE-TO-BASE-STRING", MKCL_EXT_ORDINARY, MKCL_IN_LISP(mk_mkcl_write_to_base_string), -1, MKCL_OBJNULL}},

  {{SYS_ "*OS-STRING-FORMAT*", SI_SPECIAL, NULL, -1, MKCL_OBJNULL}},

  {{SYS_ "CLOSE-PACKAGE", SI_ORDINARY, mk_si_close_package, 1, MKCL_OBJNULL}},
  {{SYS_ "REOPEN-PACKAGE", SI_ORDINARY, mk_si_reopen_package, 1, MKCL_OBJNULL}},
  {{SYS_ "PACKAGE-CLOSED-P", SI_ORDINARY, mk_si_package_closed_p, 1, MKCL_OBJNULL}},

  {{SYS_ "SIMPLE-CONTROL-ERROR", SI_ORDINARY, NULL, -1, MKCL_OBJNULL}},
  {{SYS_ "SIMPLE-PACKAGE-ERROR", SI_ORDINARY, NULL, -1, MKCL_OBJNULL}},
  {{SYS_ "SIMPLE-READER-ERROR", SI_ORDINARY,  NULL, -1, MKCL_OBJNULL}},

  {{SYS_ "C-EXPORT-FNAME", SI_ORDINARY, NULL, -1, MKCL_OBJNULL}},
  {{SYS_ "NO-CHECK-TYPE", SI_ORDINARY, NULL, -1, MKCL_OBJNULL}},

  {{KEY_ "ABORTED", KEYWORD, NULL, -1, MKCL_OBJNULL}},
  {{MT_ "ABANDON-THREAD", MT_ORDINARY, mk_mt_abandon_thread, 1, MKCL_OBJNULL}},
  {{SYS_ "+SHUTDOWN-GATE+", SI_SPECIAL, NULL, -1, MKCL_OBJNULL}},
  {{SYS_ "SHUTDOWN-IN-PROGRESS-P", SI_ORDINARY, mk_si_shutdown_in_progress_p, 0, MKCL_OBJNULL}},
  {{SYS_ "REGISTER-SHUTDOWN-THREAD", SI_ORDINARY, mk_si_register_shutdown_thread, 1, MKCL_OBJNULL}},
  {{SYS_ "REGISTER-SHUTDOWN-WATCHDOG-THREAD", SI_ORDINARY, mk_si_register_shutdown_watchdog_thread, 2, MKCL_OBJNULL}},
  {{SYS_ "SHUTDOWN-WATCHDOG-THREAD", SI_ORDINARY, mk_si_shutdown_watchdog_thread, 0, MKCL_OBJNULL}},
  {{SYS_ "SHUTDOWN-MKCL", SI_ORDINARY, MKCL_IN_LISP(mk_si_shutdown_mkcl), 4, MKCL_OBJNULL}},

  {{SYS_ "SETUP-FOR-GDB", SI_ORDINARY, mk_si_setup_for_gdb, -1, MKCL_OBJNULL}},

  {{MT_ "CURRENT-THREAD", MT_ORDINARY, mk_mt_current_thread, 0, MKCL_OBJNULL}},

  {{KEY_ "FAST", KEYWORD, NULL, -1, MKCL_OBJNULL}},
  {{KEY_ "ENABLED", KEYWORD, NULL, -1, MKCL_OBJNULL}},
  {{KEY_ "DISABLED", KEYWORD, NULL, -1, MKCL_OBJNULL}},
  {{SYS_ "INTERRUPT-STATUS", SI_ORDINARY, mk_si_interrupt_status, 0, MKCL_OBJNULL}},

  {{SYS_ "*DRIBBLE-CLOSER*", SI_SPECIAL, NULL, -1, mk_cl_Cnil}},

  {{MKCL_EXT_ "STREAM-ENCODING-ERROR", MKCL_EXT_ORDINARY, NULL, -1, MKCL_OBJNULL}},
  {{MKCL_EXT_ "STREAM-DECODING-ERROR", MKCL_EXT_ORDINARY, NULL, -1, MKCL_OBJNULL}},
  {{SYS_ "STREAM-ENCODING-ERROR", SI_ORDINARY, MKCL_IN_LISP(mk_si_stream_encoding_error), 3, MKCL_OBJNULL}},
  {{SYS_ "STREAM-DECODING-ERROR", SI_ORDINARY, MKCL_IN_LISP(mk_si_stream_decoding_error), 3, MKCL_OBJNULL}},

  {{MKCL_EXT_ "BASE-CHAR-CODE-LIMIT", MKCL_EXT_CONSTANT, NULL, -1, MKCL_MAKE_FIXNUM(MKCL_BASE_CHAR_CODE_LIMIT)}},
  {{MKCL_EXT_ "BASE-CHAR-P", MKCL_EXT_ORDINARY, mk_mkcl_base_char_p, 1, MKCL_OBJNULL}},

  {{SYS_ "COPY-TO-SIMPLE-STRING", SI_ORDINARY, mk_si_copy_to_simple_string, 1, MKCL_OBJNULL}},

  {{KEY_ "MKCL-MIN", KEYWORD, NULL, -1, MKCL_OBJNULL}},

  {{SYS_ "SCRUB-VALUES", SI_ORDINARY, mk_si_scrub_values, 0, MKCL_OBJNULL}},

#if 0
  {{MT_ "SCUTTLE-THREAD", MT_ORDINARY, mk_mt_scuttle_thread, 0, MKCL_OBJNULL}},
#endif
  {{MT_ "CANCEL-THREAD", MT_ORDINARY, mk_mt_cancel_thread, 0, MKCL_OBJNULL}},
  {{KEY_ "CANCELED", KEYWORD, NULL, -1, MKCL_OBJNULL}},
  {{KEY_ "TERMINATED", KEYWORD, NULL, -1, MKCL_OBJNULL}},
  {{MT_ "TRY-TO-WAKE-UP-THREAD", MT_ORDINARY, mk_mt_try_to_wake_up_thread, 1, MKCL_OBJNULL}},
  {{MT_ "REQUEST-THREAD-SHUTDOWN", MT_ORDINARY, mk_mt_request_thread_shutdown, 1, MKCL_OBJNULL}},
  {{MT_ "THREAD-SHUTDOWN-REQUESTED-P", MT_ORDINARY, mk_mt_thread_shutdown_requested_p, 1, MKCL_OBJNULL}},

  {{KEY_ "SHUTDOWN", KEYWORD, NULL, -1, MKCL_OBJNULL}},
  {{KEY_ "SIGNAL-ERROR", KEYWORD, NULL, -1, MKCL_OBJNULL}},
  {{KEY_ "INTERRUPTED", KEYWORD, NULL, -1, MKCL_OBJNULL}},

  {{SYS_ "MAKE-FOREIGN-NULL-POINTER", SI_ORDINARY, mk_si_make_foreign_null_pointer, 0, MKCL_OBJNULL}},
  {{SYS_ "FOREIGNP", SI_ORDINARY, mk_si_foreignp, 1, MKCL_OBJNULL}},
  {{SYS_ "LIBC-ERROR-STRING", SI_ORDINARY, mk_si_libc_error_string, 1, MKCL_OBJNULL}},
  {{SYS_ "ERRNO-STRING", SI_ORDINARY, mk_si_errno_string, 0, MKCL_OBJNULL}},
  {{SYS_ "GET-LOCAL-TIME-ZONE", SI_ORDINARY, mk_si_get_local_time_zone, 0, MKCL_OBJNULL}},
  {{SYS_ "UNAME", SI_ORDINARY, mk_si_uname, 0, MKCL_OBJNULL}},

  {{MKCL_EXT_ "PATHNAME-COMPLETE-P", MKCL_EXT_ORDINARY, mk_mkcl_pathname_complete_p, 1, MKCL_OBJNULL}},
  {{MKCL_EXT_ "MELD-PATHNAMES", MKCL_EXT_ORDINARY, mk_mkcl_meld_pathnames, -1, MKCL_OBJNULL}},
  {{MKCL_EXT_ "*CURRENT-WORKING-DIRECTORY*", MKCL_EXT_SPECIAL, NULL, -1, mk_cl_Cnil}},
  {{MKCL_EXT_ "*ALL-CURRENT-WORKING-DIRECTORIES*", MKCL_EXT_SPECIAL, NULL, -1, mk_cl_Cnil}},

  {{KEY_ "REAL-NAME", KEYWORD, NULL, -1, MKCL_OBJNULL}},
  {{KEY_ "SEARCH", KEYWORD, NULL, -1, MKCL_OBJNULL}},

  {{SYS_ "NON-INTERACTIVE-THREAD-DEBUGGER-TRAP", SI_ORDINARY, mk_si_non_interactive_thread_debugger_trap, 2, MKCL_OBJNULL}},

  {{SYS_ "MKCL-VERSION", SI_ORDINARY, MKCL_IN_LISP(mk_si_mkcl_version), 0, MKCL_OBJNULL}},
  {{SYS_ "MKCL-MAJOR-VERSION", SI_ORDINARY, MKCL_IN_LISP(mk_si_mkcl_major_version), 0, MKCL_OBJNULL}},
  {{SYS_ "MKCL-MINOR-VERSION", SI_ORDINARY, MKCL_IN_LISP(mk_si_mkcl_minor_version), 0, MKCL_OBJNULL}},
  {{SYS_ "MKCL-PATCH-LEVEL", SI_ORDINARY, MKCL_IN_LISP(mk_si_mkcl_patch_level), 0, MKCL_OBJNULL}},

  {{SYS_ "*RESTART-CLUSTERS*", SI_SPECIAL, NULL, -1, mk_cl_Cnil}},
  {{SYS_ "*CONDITION-RESTARTS*", SI_SPECIAL, NULL, -1, mk_cl_Cnil}},
  {{SYS_ "*HANDLER-CLUSTERS*", SI_SPECIAL, NULL, -1, mk_cl_Cnil}},

  {{SYS_ "SET-BINDING-STACK-LIMIT", SI_ORDINARY, mk_si_set_binding_stack_limit, 1, MKCL_OBJNULL}},
  {{SYS_ "GET-BINDING-STACK-LIMIT", SI_ORDINARY, mk_si_get_binding_stack_limit, 0, MKCL_OBJNULL}},
  {{SYS_ "SET-FRAME-STACK-LIMIT", SI_ORDINARY, mk_si_set_frame_stack_limit, 1, MKCL_OBJNULL}},
  {{SYS_ "GET-FRAME-STACK-LIMIT", SI_ORDINARY, mk_si_get_frame_stack_limit, 0, MKCL_OBJNULL}},
  {{SYS_ "SET-LISP-TEMP-STACK-LIMIT", SI_ORDINARY, mk_si_set_lisp_temp_stack_limit, 1, MKCL_OBJNULL}},
  {{SYS_ "GET-LISP-TEMP-STACK-LIMIT", SI_ORDINARY, mk_si_get_lisp_temp_stack_limit, 0, MKCL_OBJNULL}},
  {{SYS_ "SET-HEAP-SIZE-LIMIT", SI_ORDINARY, mk_si_set_heap_size_limit, 1, MKCL_OBJNULL}},
  {{SYS_ "GET-HEAP-SIZE-LIMIT", SI_ORDINARY, mk_si_get_heap_size_limit, 0, MKCL_OBJNULL}},
  {{SYS_ "GET-CALL-STACK-LIMIT", SI_ORDINARY, mk_si_get_call_stack_limit, 0, MKCL_OBJNULL}},

  {{KEY_ "CALL-STACK-SIZE", KEYWORD, NULL, -1, MKCL_OBJNULL}},
  {{KEY_ "LISP-TEMP-STACK-INITIAL-SIZE", KEYWORD, NULL, -1, MKCL_OBJNULL}},
  {{KEY_ "LISP-TEMP-STACK-SIZE-LIMIT", KEYWORD, NULL, -1, MKCL_OBJNULL}},
  {{KEY_ "BINDING-STACK-INITIAL-SIZE", KEYWORD, NULL, -1, MKCL_OBJNULL}},
  {{KEY_ "BINDING-STACK-SIZE-LIMIT", KEYWORD, NULL, -1, MKCL_OBJNULL}},
  {{KEY_ "FRAME-STACK-INITIAL-SIZE", KEYWORD, NULL, -1, MKCL_OBJNULL}},
  {{KEY_ "FRAME-STACK-SIZE-LIMIT", KEYWORD, NULL, -1, MKCL_OBJNULL}},
  {{KEY_ "SIGALTSTACK-SIZE", KEYWORD, NULL, -1, MKCL_OBJNULL}},
  {{KEY_ "UNLIMITED", KEYWORD, NULL, -1, MKCL_OBJNULL}},

  {{KEY_ "GC-ABORT", KEYWORD, NULL, -1, MKCL_OBJNULL}},
  {{KEY_ "GC-EXIT", KEYWORD, NULL, -1, MKCL_OBJNULL}},

  {{KEY_ "ACTIVE", KEYWORD, NULL, -1, MKCL_OBJNULL}},
  {{KEY_ "SET", KEYWORD, NULL, -1, MKCL_OBJNULL}},
  {{KEY_ "INITIALIZED", KEYWORD, NULL, -1, MKCL_OBJNULL}},
  {{KEY_ "DONE", KEYWORD, NULL, -1, MKCL_OBJNULL}},
  {{KEY_ "UNKNOWN", KEYWORD, NULL, -1, MKCL_OBJNULL}},
  {{MT_ "THREAD-STATUS", MT_ORDINARY, mk_mt_thread_status, 1, MKCL_OBJNULL}},

  {{CLOS_ "*REDEFINE-CLASS-IN-PLACE*", CLOS_SPECIAL, NULL, -1, mk_cl_Cnil}},

  {{KEY_ "FOREIGN", KEYWORD, NULL, -1, MKCL_OBJNULL}},
  {{SYS_ "TRIM-FFI-ARGUMENTS-STAGING-AREA", SI_ORDINARY, mk_si_trim_ffi_arguments_staging_area, 0, MKCL_OBJNULL}},
  {{SYS_ "RELEASE-FFI-AREA", SI_ORDINARY, mk_si_release_ffi_area, 0, MKCL_OBJNULL}},

  {{SYS_ "LIST-ALL-CHILDREN", SI_ORDINARY, mk_si_list_all_children, 0, MKCL_OBJNULL}}, /* debug only */
  {{SYS_ "TRACE-SPECIALS", SI_ORDINARY, mk_si_trace_specials, 0, MKCL_OBJNULL}}, /* debug only */
  {{SYS_ "UNTRACE-SPECIALS", SI_ORDINARY, mk_si_untrace_specials, 0, MKCL_OBJNULL}}, /* debug only */

  {{MT_ "ABORT-THREAD", MT_ORDINARY, mk_mt_abort_thread, 0, MKCL_OBJNULL}},

  {{MKCL_EXT_ "NATURAL8", MKCL_EXT_ORDINARY, NULL, -1, MKCL_OBJNULL}},
  {{MKCL_EXT_ "NATURAL16", MKCL_EXT_ORDINARY, NULL, -1, MKCL_OBJNULL}},
  {{MKCL_EXT_ "NATURAL32", MKCL_EXT_ORDINARY, NULL, -1, MKCL_OBJNULL}},
  {{MKCL_EXT_ "NATURAL64", MKCL_EXT_ORDINARY, NULL, -1, MKCL_OBJNULL}},
  {{MKCL_EXT_ "OCTET", MKCL_EXT_ORDINARY, NULL, -1, MKCL_OBJNULL}},
  {{MKCL_EXT_ "DOUBLE-OCTET", MKCL_EXT_ORDINARY, NULL, -1, MKCL_OBJNULL}},
  {{MKCL_EXT_ "OCTETS", MKCL_EXT_ORDINARY, mk_mkcl_octets, 1, MKCL_OBJNULL}},
  {{MKCL_EXT_ "DOUBLE-OCTETS", MKCL_EXT_ORDINARY, mk_mkcl_double_octets, 1, MKCL_OBJNULL}},

  /* High water mark for MKCL 1.1.0 */

  {{KEY_ "IMPORTED-AND-GC-REGISTERED", KEYWORD, NULL, -1, MKCL_OBJNULL}},

  /* High water mark for MKCL 1.1.1 */

  /* Tag for end of list!
     This entry, with a first field of NULL value,
     must be the very last of this array.
     Anything following it will be ignored. JCB
  */
  {{NULL, CL_ORDINARY, NULL, -1, MKCL_OBJNULL}}};


